<?php
/*
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2021 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

/**
 * Hilfsklasse für Lokalisierung und Kommunikationsadressen.
 *
 * @package GhCore
 * @subpackage locale
 * @category Hilfsklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2014 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhCoreLocale
{
  /**
   * Konstante für unbekanntes Geschlecht.
   * @var int
   */
  const SEX_UNDEFINED = 0;

  /**
   * Konstante für männliches Geschlecht.
   * @var int
   */
  const SEX_MALE = 1;

  /**
   * Konstante für weibliches Geschlecht.
   * @var int
   */
  const SEX_FEMALE = 2;

  /**
   * Länder nach Ländercode (ISO 3166).
   * @var array
   */
  protected static $_countries = array(
    'AD' => array('iso3' => 'AND', 'isoNumber' => 20, 'phone' => '+376', 'licensePlate' => 'AND', 'de' => 'Andorra', 'DE' => 'ANDORRA', 'en' => 'Andorra', 'EN' => 'ANDORRA', 'es' => 'Andorra', 'ES' => 'ANDORRA', 'fr' => 'Andorre', 'FR' => 'ANDORRE'),
    'AE' => array('iso3' => 'ARE', 'isoNumber' => 784, 'phone' => '+971', 'licensePlate' => 'UAE', 'de' => 'Vereinigte Arabische Emirate', 'DE' => 'VEREINIGTE ARABISCHE EMIRATE', 'en' => 'United Arab Emirates', 'EN' => 'UNITED ARAB EMIRATES', 'es' => 'Emiratos Árabes Unidos', 'ES' => 'EMIRATOS ÁRABES UNIDOS', 'fr' => 'Émirats arabes unis', 'FR' => 'ÉMIRATS ARABES UNIS'),
    'AF' => array('iso3' => 'AFG', 'isoNumber' => 4, 'phone' => '+93', 'licensePlate' => 'AFG', 'de' => 'Afghanistan', 'DE' => 'AFGHANISTAN', 'en' => 'Afghanistan', 'EN' => 'AFGHANISTAN', 'es' => 'Afganistán', 'ES' => 'AFGANISTÁN', 'fr' => 'Afghanistan', 'FR' => 'AFGHANISTAN'),
    'AG' => array('iso3' => 'ATG', 'isoNumber' => 28, 'phone' => '+1268', 'licensePlate' => 'AG', 'de' => 'Antigua und Barbuda', 'DE' => 'ANTIGUA UND BARBUDA', 'en' => 'Antigua and Barbuda', 'EN' => 'ANTIGUA AND BARBUDA', 'es' => 'Antigua y Barbuda', 'ES' => 'ANTIGUA Y BARBUDA', 'fr' => 'Antigua-et-Barbuda', 'FR' => 'ANTIGUA-ET-BARBUDA'),
    'AI' => array('iso3' => 'AIA', 'isoNumber' => 660, 'phone' => '+1264', 'licensePlate' => 'AXA', 'de' => 'Anguillа', 'DE' => 'ANGUILLА', 'en' => 'Anguillа', 'EN' => 'ANGUILLА', 'es' => 'Anguillа', 'ES' => 'ANGUILLА', 'fr' => 'Anguillа', 'FR' => 'ANGUILLА'),
    'AL' => array('iso3' => 'ALB', 'isoNumber' => 8, 'phone' => '+355', 'licensePlate' => 'AL', 'de' => 'Albanien', 'DE' => 'ALBANIEN', 'en' => 'Albania', 'EN' => 'ALBANIA', 'es' => 'Albania', 'ES' => 'ALBANIA', 'fr' => 'Albanie', 'FR' => 'ALBANIE'),
    'AM' => array('iso3' => 'ARM', 'isoNumber' => 51, 'phone' => '+374', 'licensePlate' => 'AM', 'de' => 'Armenien', 'DE' => 'ARMENIEN', 'en' => 'Armenia', 'EN' => 'ARMENIA', 'es' => 'Armenia', 'ES' => 'ARMENIA', 'fr' => 'Arménie', 'FR' => 'ARMÉNIE'),
    'AN' => array('iso3' => 'ANT', 'isoNumber' => 530, 'phone' => '+599', 'licensePlate' => 'NA', 'de' => 'Niederländische Antillen', 'DE' => 'NIEDERLÄNDISCHE ANTILLEN', 'en' => 'Netherlands Antilles', 'EN' => 'NETHERLANDS ANTILLES', 'es' => 'Antillas Neerlandesas', 'ES' => 'ANTILLAS NEERLANDESAS', 'fr' => 'Antilles Néerlandaises', 'FR' => 'ANTILLES NÉERLANDAISES'),
    'AO' => array('iso3' => 'AGO', 'isoNumber' => 24, 'phone' => '+244', 'licensePlate' => 'ANG', 'de' => 'Angola', 'DE' => 'ANGOLA', 'en' => 'Angola', 'EN' => 'ANGOLA', 'es' => 'Angola', 'ES' => 'ANGOLA', 'fr' => 'Angola', 'FR' => 'ANGOLA'),
    'AQ' => array('iso3' => 'ATA', 'isoNumber' => 10, 'phone' => '+6721', 'licensePlate' => '', 'de' => 'Antarktika', 'DE' => 'ANTARKTIKA', 'en' => 'Antarctica', 'EN' => 'ANTARCTICA', 'es' => 'Antártida', 'ES' => 'ANTÁRTIDA', 'fr' => 'Antarctique', 'FR' => 'ANTARCTIQUE'),
    'AR' => array('iso3' => 'ARG', 'isoNumber' => 32, 'phone' => '+54', 'licensePlate' => 'RA', 'de' => 'Argentinien', 'DE' => 'ARGENTINIEN', 'en' => 'Argentina', 'EN' => 'ARGENTINA', 'es' => 'Argentina', 'ES' => 'ARGENTINA', 'fr' => 'Argentine', 'FR' => 'ARGENTINE'),
    'AS' => array('iso3' => 'ASM', 'isoNumber' => 16, 'phone' => '+1684', 'licensePlate' => '', 'de' => 'Samoa', 'DE' => 'SAMOA', 'en' => 'Samoa', 'EN' => 'SAMOA', 'es' => 'Samoa', 'ES' => 'SAMOA', 'fr' => 'Samoa', 'FR' => 'SAMOA'),
    'AT' => array('iso3' => 'AUT', 'isoNumber' => 40, 'phone' => '+43', 'licensePlate' => 'A', 'de' => 'Österreich', 'DE' => 'ÖSTERREICH', 'en' => 'Austria', 'EN' => 'AUSTRIA', 'es' => 'Austria', 'ES' => 'AUSTRIA', 'fr' => 'Autriche', 'FR' => 'AUTRICHE'),
    'AU' => array('iso3' => 'AUS', 'isoNumber' => 36, 'phone' => '+61', 'licensePlate' => 'AUS', 'de' => 'Australien', 'DE' => 'AUSTRALIEN', 'en' => 'Australia', 'EN' => 'AUSTRALIA', 'es' => 'Australia', 'ES' => 'AUSTRALIA', 'fr' => 'Australie', 'FR' => 'AUSTRALIE'),
    'AW' => array('iso3' => 'ABW', 'isoNumber' => 533, 'phone' => '+297', 'licensePlate' => 'ARU', 'de' => 'Aruba', 'DE' => 'ARUBA', 'en' => 'Aruba', 'EN' => 'ARUBA', 'es' => 'Aruba', 'ES' => 'ARUBA', 'fr' => 'Aruba', 'FR' => 'ARUBA'),
    'AX' => array('iso3' => 'ALA', 'isoNumber' => 248, 'phone' => '+35818', 'licensePlate' => 'AX', 'de' => 'Ålandinseln', 'DE' => 'ÅLANDINSELN', 'en' => 'Åland Islands', 'EN' => 'ÅLAND ISLANDS', 'es' => 'Islas de Åland', 'ES' => 'ISLAS DE ÅLAND', 'fr' => 'Îles Åland', 'FR' => 'ÎLES ÅLAND'),
    'AZ' => array('iso3' => 'AZE', 'isoNumber' => 31, 'phone' => '+994', 'licensePlate' => 'AZ', 'de' => 'Aserbaidschan', 'DE' => 'ASERBAIDSCHAN', 'en' => 'Azerbaijan', 'EN' => 'AZERBAIJAN', 'es' => 'Azerbaiyán', 'ES' => 'AZERBAIYÁN', 'fr' => 'Azerbaïdjan', 'FR' => 'AZERBAÏDJAN'),
    'BA' => array('iso3' => 'BIH', 'isoNumber' => 70, 'phone' => '+387', 'licensePlate' => 'BIH', 'de' => 'Bosnien und Herzegowina', 'DE' => 'BOSNIEN UND HERZEGOWINA', 'en' => 'Bosnia and Herzegovina', 'EN' => 'BOSNIA AND HERZEGOVINA', 'es' => 'Bosnia y Herzegovina', 'ES' => 'BOSNIA Y HERZEGOVINA', 'fr' => 'Bosnie-Herzégovine', 'FR' => 'BOSNIE-HERZÉGOVINE'),
    'BB' => array('iso3' => 'BRB', 'isoNumber' => 52, 'phone' => '+1246', 'licensePlate' => 'BDS', 'de' => 'Barbados', 'DE' => 'BARBADOS', 'en' => 'Barbados', 'EN' => 'BARBADOS', 'es' => 'Barbados', 'ES' => 'BARBADOS', 'fr' => 'Barbade', 'FR' => 'BARBADE'),
    'BD' => array('iso3' => 'BGD', 'isoNumber' => 50, 'phone' => '+880', 'licensePlate' => 'BD', 'de' => 'Bangladesch', 'DE' => 'BANGLADESCH', 'en' => 'Bangladesh', 'EN' => 'BANGLADESH', 'es' => 'Bangladesh', 'ES' => 'BANGLADESH', 'fr' => 'Bangladesh', 'FR' => 'BANGLADESH'),
    'BE' => array('iso3' => 'BEL', 'isoNumber' => 56, 'phone' => '+32', 'licensePlate' => 'B', 'de' => 'Belgien', 'DE' => 'BELGIEN', 'en' => 'Belgium', 'EN' => 'BELGIUM', 'es' => 'Bélgica', 'ES' => 'BÉLGICA', 'fr' => 'Belgique', 'FR' => 'BELGIQUE'),
    'BF' => array('iso3' => 'BFA', 'isoNumber' => 854, 'phone' => '+226', 'licensePlate' => 'BF', 'de' => 'Burkina Faso', 'DE' => 'BURKINA FASO', 'en' => 'Burkina Faso', 'EN' => 'BURKINA FASO', 'es' => 'Burkina Faso', 'ES' => 'BURKINA FASO', 'fr' => 'Burkina Faso', 'FR' => 'BURKINA FASO'),
    'BG' => array('iso3' => 'BGR', 'isoNumber' => 100, 'phone' => '+359', 'licensePlate' => 'BG', 'de' => 'Bulgarien', 'DE' => 'BULGARIEN', 'en' => 'Bulgaria', 'EN' => 'BULGARIA', 'es' => 'Bulgaria', 'ES' => 'BULGARIA', 'fr' => 'Bulgarie', 'FR' => 'BULGARIE'),
    'BH' => array('iso3' => 'BHR', 'isoNumber' => 48, 'phone' => '+973', 'licensePlate' => 'BRN', 'de' => 'Bahrain', 'DE' => 'BAHRAIN', 'en' => 'Bahrain', 'EN' => 'BAHRAIN', 'es' => 'Bahrein', 'ES' => 'BAHREIN', 'fr' => 'Bahreïn', 'FR' => 'BAHREÏN'),
    'BI' => array('iso3' => 'BDI', 'isoNumber' => 108, 'phone' => '+257', 'licensePlate' => 'RU', 'de' => 'Burundi', 'DE' => 'BURUNDI', 'en' => 'Burundi', 'EN' => 'BURUNDI', 'es' => 'Burundi', 'ES' => 'BURUNDI', 'fr' => 'Burundi', 'FR' => 'BURUNDI'),
    'BJ' => array('iso3' => 'BEN', 'isoNumber' => 204, 'phone' => '+229', 'licensePlate' => 'BJ', 'de' => 'Benin', 'DE' => 'BENIN', 'en' => 'Benin', 'EN' => 'BENIN', 'es' => 'Benin', 'ES' => 'BENIN', 'fr' => 'Bénin', 'FR' => 'BÉNIN'),
    'BL' => array('iso3' => 'BLM', 'isoNumber' => 652, 'phone' => '+590', 'licensePlate' => '', 'de' => 'St. Barthélemy', 'DE' => 'ST. BARTHÉLEMY', 'en' => 'Saint Barthélemy', 'EN' => 'SAINT BARTHÉLEMY', 'es' => 'San Bartolomé', 'ES' => 'SAN BARTOLOMÉ', 'fr' => 'Saint-Barthélemy', 'FR' => 'SAINT-BARTHÉLEMY'),
    'BM' => array('iso3' => 'BMU', 'isoNumber' => 60, 'phone' => '+1441', 'licensePlate' => '', 'de' => 'Bermuda', 'DE' => 'BERMUDA', 'en' => 'Bermuda', 'EN' => 'BERMUDA', 'es' => 'Bermudas', 'ES' => 'BERMUDAS', 'fr' => 'Bermudes', 'FR' => 'BERMUDES'),
    'BN' => array('iso3' => 'BRN', 'isoNumber' => 96, 'phone' => '+673', 'licensePlate' => 'BRU', 'de' => 'Brunei', 'DE' => 'BRUNEI', 'en' => 'Brunei', 'EN' => 'BRUNEI', 'es' => 'Brunei', 'ES' => 'BRUNEI', 'fr' => 'Brunéi', 'FR' => 'BRUNÉI'),
    'BO' => array('iso3' => 'BOL', 'isoNumber' => 68, 'phone' => '+591', 'licensePlate' => 'BOL', 'de' => 'Bolivien', 'DE' => 'BOLIVIEN', 'en' => 'Bolivia', 'EN' => 'BOLIVIA', 'es' => 'Bolivia', 'ES' => 'BOLIVIA', 'fr' => 'Bolivie', 'FR' => 'BOLIVIE'),
    'BQ' => array('iso3' => 'BES', 'isoNumber' => 535, 'phone' => '+5997', 'licensePlate' => '', 'de' => 'Bonaire, Sint Eustatius und Saba', 'DE' => 'BONAIRE, SINT EUSTATIUS UND SABA', 'en' => 'Bonaire, Sint Eustatius and Saba', 'EN' => 'BONAIRE, SINT EUSTATIUS AND SABA', 'es' => 'Bonaire, San Eustaquio y Saba', 'ES' => 'BONAIRE, SAN EUSTAQUIO Y SABA', 'fr' => 'Bonaire, Saint-Eustache et Saba', 'FR' => 'BONAIRE, SAINT-EUSTACHE ET SABA'),
    'BR' => array('iso3' => 'BRA', 'isoNumber' => 76, 'phone' => '+55', 'licensePlate' => 'BR', 'de' => 'Brasilien', 'DE' => 'BRASILIEN', 'en' => 'Brazil', 'EN' => 'BRAZIL', 'es' => 'Brasil', 'ES' => 'BRASIL', 'fr' => 'Brésil', 'FR' => 'BRÉSIL'),
    'BS' => array('iso3' => 'BHS', 'isoNumber' => 44, 'phone' => '+1242', 'licensePlate' => 'BS', 'de' => 'Bahamas', 'DE' => 'BAHAMAS', 'en' => 'Bahamas', 'EN' => 'BAHAMAS', 'es' => 'Bahamas', 'ES' => 'BAHAMAS', 'fr' => 'Bahamas', 'FR' => 'BAHAMAS'),
    'BT' => array('iso3' => 'BTN', 'isoNumber' => 64, 'phone' => '+975', 'licensePlate' => 'BHT', 'de' => 'Bhutan', 'DE' => 'BHUTAN', 'en' => 'Bhutan', 'EN' => 'BHUTAN', 'es' => 'Bhután', 'ES' => 'BHUTÁN', 'fr' => 'Bhoutan', 'FR' => 'BHOUTAN'),
    'BV' => array('iso3' => 'BVT', 'isoNumber' => 74, 'phone' => '+47', 'licensePlate' => '', 'de' => 'Bouvetinsel', 'DE' => 'BOUVETINSEL', 'en' => 'Bouvet Island', 'EN' => 'BOUVET ISLAND', 'es' => 'Isla Bouvet', 'ES' => 'ISLA BOUVET', 'fr' => 'Île Bouvet', 'FR' => 'ÎLE BOUVET'),
    'BW' => array('iso3' => 'BWA', 'isoNumber' => 72, 'phone' => '+267', 'licensePlate' => array('BW', 'RB'), 'de' => 'Botsuana', 'DE' => 'BOTSUANA', 'en' => 'Botswana', 'EN' => 'BOTSWANA', 'es' => 'Botswana', 'ES' => 'BOTSWANA', 'fr' => 'Botswana', 'FR' => 'BOTSWANA'),
    'BY' => array('iso3' => 'BLR', 'isoNumber' => 112, 'phone' => '+375', 'licensePlate' => 'BY', 'de' => 'Weißrussland', 'DE' => 'WEISSRUSSLAND', 'en' => 'Belarus', 'EN' => 'BELARUS', 'es' => 'Belarús', 'ES' => 'BELARÚS', 'fr' => 'Bélarus', 'FR' => 'BÉLARUS'),
    'BZ' => array('iso3' => 'BLZ', 'isoNumber' => 84, 'phone' => '+501', 'licensePlate' => 'BZ', 'de' => 'Belize', 'DE' => 'BELIZE', 'en' => 'Belize', 'EN' => 'BELIZE', 'es' => 'Belice', 'ES' => 'BELICE', 'fr' => 'Belize', 'FR' => 'BELIZE'),
    'CA' => array('iso3' => 'CAN', 'isoNumber' => 124, 'phone' => '+1', 'licensePlate' => 'CDN', 'de' => 'Kanada', 'DE' => 'KANADA', 'en' => 'Canada', 'EN' => 'CANADA', 'es' => 'Canadá', 'ES' => 'CANADÁ', 'fr' => 'Canada', 'FR' => 'CANADA'),
    'CC' => array('iso3' => 'CCK', 'isoNumber' => 166, 'phone' => '+6189162', 'licensePlate' => '', 'de' => 'Kokosinseln', 'DE' => 'KOKOSINSELN', 'en' => 'Cocos Islands', 'EN' => 'COCOS ISLANDS', 'es' => 'Islas de Cocos', 'ES' => 'ISLAS DE COCOS', 'fr' => 'Îles des Cocos', 'FR' => 'ÎLES DES COCOS'),
    'CD' => array('iso3' => 'COD', 'isoNumber' => 180, 'phone' => '+243', 'licensePlate' => 'CGO', 'de' => 'DR Kongo', 'DE' => 'DR KONGO', 'en' => 'DR Congo', 'EN' => 'DR CONGO', 'es' => 'Congo Democrático', 'ES' => 'CONGO DEMOCRÁTICO', 'fr' => 'RD Congo', 'FR' => 'RD CONGO'),
    'CF' => array('iso3' => 'CAF', 'isoNumber' => 140, 'phone' => '+236', 'licensePlate' => 'RCA', 'de' => 'Zentralafrikanische Republik', 'DE' => 'ZENTRALAFRIKANISCHE REPUBLIK', 'en' => 'Central African Republic', 'EN' => 'CENTRAL AFRICAN REPUBLIC', 'es' => 'República Centroafricana', 'ES' => 'REPÚBLICA CENTROAFRICANA', 'fr' => 'République centrafricaine', 'FR' => 'RÉPUBLIQUE CENTRAFRICAINE'),
    'CG' => array('iso3' => 'COG', 'isoNumber' => 178, 'phone' => '+242', 'licensePlate' => 'RCB', 'de' => 'Kongo', 'DE' => 'KONGO', 'en' => 'Congo', 'EN' => 'CONGO', 'es' => 'Congo', 'ES' => 'CONGO', 'fr' => 'Congo', 'FR' => 'CONGO'),
    'CH' => array('iso3' => 'CHE', 'isoNumber' => 756, 'phone' => '+41', 'licensePlate' => 'CH', 'de' => 'Schweiz', 'DE' => 'SCHWEIZ', 'en' => 'Switzerland', 'EN' => 'SWITZERLAND', 'es' => 'Suiza', 'ES' => 'SUIZA', 'fr' => 'Suisse', 'FR' => 'SUISSE'),
    'CI' => array('iso3' => 'CIV', 'isoNumber' => 384, 'phone' => '+225', 'licensePlate' => 'CI', 'de' => 'Côte d\'Ivoire', 'DE' => 'CÔTE D\'IVOIRE', 'en' => 'Côte d\'Ivoire', 'EN' => 'CÔTE D\'IVOIRE', 'es' => 'Côte d\'Ivoire', 'ES' => 'CÔTE D\'IVOIRE', 'fr' => 'Côte d\'Ivoire', 'FR' => 'CÔTE D\'IVOIRE'),
    'CK' => array('iso3' => 'COK', 'isoNumber' => 184, 'phone' => '+682', 'licensePlate' => '', 'de' => 'Cookinseln', 'DE' => 'COOKINSELN', 'en' => 'Cook Islands', 'EN' => 'COOK ISLANDS', 'es' => 'Islas Cook', 'ES' => 'ISLAS COOK', 'fr' => 'Îles Cook', 'FR' => 'ÎLES COOK'),
    'CL' => array('iso3' => 'CHL', 'isoNumber' => 152, 'phone' => '+56', 'licensePlate' => 'RCH', 'de' => 'Chile', 'DE' => 'CHILE', 'en' => 'Chile', 'EN' => 'CHILE', 'es' => 'Chile', 'ES' => 'CHILE', 'fr' => 'Chili', 'FR' => 'CHILI'),
    'CM' => array('iso3' => 'CMR', 'isoNumber' => 120, 'phone' => '+237', 'licensePlate' => 'CAM', 'de' => 'Kamerun', 'DE' => 'KAMERUN', 'en' => 'Cameroon', 'EN' => 'CAMEROON', 'es' => 'Camerún', 'ES' => 'CAMERÚN', 'fr' => 'Cameroun', 'FR' => 'CAMEROUN'),
    'CN' => array('iso3' => 'CHN', 'isoNumber' => 156, 'phone' => '+86', 'licensePlate' => 'CHN', 'de' => 'China', 'DE' => 'CHINA', 'en' => 'China', 'EN' => 'CHINA', 'es' => 'China', 'ES' => 'CHINA', 'fr' => 'Chine', 'FR' => 'CHINE'),
    'CO' => array('iso3' => 'COL', 'isoNumber' => 170, 'phone' => '+57', 'licensePlate' => 'CO', 'de' => 'Kolumbien', 'DE' => 'KOLUMBIEN', 'en' => 'Colombia', 'EN' => 'COLOMBIA', 'es' => 'Colombia', 'ES' => 'COLOMBIA', 'fr' => 'Colombie', 'FR' => 'COLOMBIE'),
    'CR' => array('iso3' => 'CRI', 'isoNumber' => 188, 'phone' => '+506', 'licensePlate' => 'CR', 'de' => 'Costa Rica', 'DE' => 'COSTA RICA', 'en' => 'Costa Rica', 'EN' => 'COSTA RICA', 'es' => 'Costa Rica', 'ES' => 'COSTA RICA', 'fr' => 'Costa Rica', 'FR' => 'COSTA RICA'),
    'CS' => array('iso3' => 'SCG', 'isoNumber' => 891, 'phone' => '+381', 'licensePlate' => '', 'de' => 'Serbien und Montenegro', 'DE' => 'SERBIEN UND MONTENEGRO', 'en' => 'Serbia and Montenegro', 'EN' => 'SERBIA AND MONTENEGRO', 'es' => 'Serbia y Montenegro', 'ES' => 'SERBIA Y MONTENEGRO', 'fr' => 'Serbie-et-Monténégro', 'FR' => 'SERBIE-ET-MONTÉNÉGRO'),
    'CU' => array('iso3' => 'CUB', 'isoNumber' => 192, 'phone' => '+53', 'licensePlate' => 'C', 'de' => 'Kuba', 'DE' => 'KUBA', 'en' => 'Cuba', 'EN' => 'CUBA', 'es' => 'Cuba', 'ES' => 'CUBA', 'fr' => 'Cuba', 'FR' => 'CUBA'),
    'CV' => array('iso3' => 'CPV', 'isoNumber' => 132, 'phone' => '+238', 'licensePlate' => 'CV', 'de' => 'Kap Verde', 'DE' => 'KAP VERDE', 'en' => 'Cape Verde', 'EN' => 'CAPE VERDE', 'es' => 'Cabo Verde', 'ES' => 'CABO VERDE', 'fr' => 'Cap-Vert', 'FR' => 'CAP-VERT'),
    'CW' => array('iso3' => 'CUW', 'isoNumber' => 531, 'phone' => '+5999', 'licensePlate' => '', 'de' => 'Curaçao', 'DE' => 'CURAÇAO', 'en' => 'Curaçao', 'EN' => 'CURAÇAO', 'es' => 'Curazao', 'ES' => 'CURAZAO', 'fr' => 'Curaçao', 'FR' => 'CURAÇAO'),
    'CX' => array('iso3' => 'CXR', 'isoNumber' => 162, 'phone' => '+6189164', 'licensePlate' => '', 'de' => 'Weihnachtsinsel', 'DE' => 'WEIHNACHTSINSEL', 'en' => 'Christmas Island', 'EN' => 'CHRISTMAS ISLAND', 'es' => 'Isla Christmas', 'ES' => 'ISLA CHRISTMAS', 'fr' => 'Île Christmas', 'FR' => 'ÎLE CHRISTMAS'),
    'CY' => array('iso3' => 'CYP', 'isoNumber' => 196, 'phone' => '+357', 'licensePlate' => 'CY', 'de' => 'Zypern', 'DE' => 'ZYPERN', 'en' => 'Cyprus', 'EN' => 'CYPRUS', 'es' => 'Chipre', 'ES' => 'CHIPRE', 'fr' => 'Chypre', 'FR' => 'CHYPRE'),
    'CZ' => array('iso3' => 'CZE', 'isoNumber' => 203, 'phone' => '+420', 'licensePlate' => 'CZ', 'de' => 'Tschechien', 'DE' => 'TSCHECHIEN', 'en' => 'Czech Republic', 'EN' => 'CZECH REPUBLIC', 'es' => 'Chequia', 'ES' => 'CHEQUIA', 'fr' => 'Tchéquie', 'FR' => 'TCHÉQUIE'),
    'DE' => array('iso3' => 'DEU', 'isoNumber' => 276, 'phone' => '+49', 'licensePlate' => 'D', 'de' => 'Deutschland', 'DE' => 'DEUTSCHLAND', 'en' => 'Germany', 'EN' => 'GERMANY', 'es' => 'Alemania', 'ES' => 'ALEMANIA', 'fr' => 'Allemagne', 'FR' => 'ALLEMAGNE'),
    'DJ' => array('iso3' => 'DJI', 'isoNumber' => 262, 'phone' => '+253', 'licensePlate' => 'DJI', 'de' => 'Dschibuti', 'DE' => 'DSCHIBUTI', 'en' => 'Djibouti', 'EN' => 'DJIBOUTI', 'es' => 'Djibouti', 'ES' => 'DJIBOUTI', 'fr' => 'Djibouti', 'FR' => 'DJIBOUTI'),
    'DK' => array('iso3' => 'DNK', 'isoNumber' => 208, 'phone' => '+45', 'licensePlate' => 'DK', 'de' => 'Dänemark', 'DE' => 'DÄNEMARK', 'en' => 'Denmark', 'EN' => 'DENMARK', 'es' => 'Dinamarca', 'ES' => 'DINAMARCA', 'fr' => 'Danemark', 'FR' => 'DANEMARK'),
    'DM' => array('iso3' => 'DMA', 'isoNumber' => 212, 'phone' => '+1767', 'licensePlate' => 'WD', 'de' => 'Dominica', 'DE' => 'DOMINICA', 'en' => 'Dominica', 'EN' => 'DOMINICA', 'es' => 'Dominica', 'ES' => 'DOMINICA', 'fr' => 'Dominique', 'FR' => 'DOMINIQUE'),
    'DO' => array('iso3' => 'DOM', 'isoNumber' => 214, 'phone' => '+1809', 'licensePlate' => 'DOM', 'de' => 'Dominikanische Republik', 'DE' => 'DOMINIKANISCHE REPUBLIK', 'en' => 'Dominican Republic', 'EN' => 'DOMINICAN REPUBLIC', 'es' => 'República Dominicana', 'ES' => 'REPÚBLICA DOMINICANA', 'fr' => 'République dominicaine', 'FR' => 'RÉPUBLIQUE DOMINICAINE'),
    'DZ' => array('iso3' => 'DZA', 'isoNumber' => 12, 'phone' => '+213', 'licensePlate' => 'DZ', 'de' => 'Algerien', 'DE' => 'ALGERIEN', 'en' => 'Algeria', 'EN' => 'ALGERIA', 'es' => 'Argelia', 'ES' => 'ARGELIA', 'fr' => 'Algérie', 'FR' => 'ALGÉRIE'),
    'EC' => array('iso3' => 'ECU', 'isoNumber' => 218, 'phone' => '+493', 'licensePlate' => 'EC', 'de' => 'Ecuador', 'DE' => 'ECUADOR', 'en' => 'Ecuador', 'EN' => 'ECUADOR', 'es' => 'Ecuador', 'ES' => 'ECUADOR', 'fr' => 'Équateur', 'FR' => 'ÉQUATEUR'),
    'EE' => array('iso3' => 'EST', 'isoNumber' => 233, 'phone' => '+372', 'licensePlate' => 'EST', 'de' => 'Estland', 'DE' => 'ESTLAND', 'en' => 'Estonia', 'EN' => 'ESTONIA', 'es' => 'Estonia', 'ES' => 'ESTONIA', 'fr' => 'Estonie', 'FR' => 'ESTONIE'),
    'EG' => array('iso3' => 'EGY', 'isoNumber' => 818, 'phone' => '+20', 'licensePlate' => 'ET', 'de' => 'Ägypten', 'DE' => 'ÄGYPTEN', 'en' => 'Egypt', 'EN' => 'EGYPT', 'es' => 'Egipto', 'ES' => 'EGIPTO', 'fr' => 'Égypte', 'FR' => 'ÉGYPTE'),
    'EH' => array('iso3' => 'ESH', 'isoNumber' => 732, 'phone' => '+21228', 'licensePlate' => 'WSA', 'de' => 'Westsahara', 'DE' => 'WESTSAHARA', 'en' => 'Western Sahara', 'EN' => 'WESTERN SAHARA', 'es' => 'Sáhara Occidental', 'ES' => 'SÁHARA OCCIDENTAL', 'fr' => 'Sahara occidental', 'FR' => 'SAHARA OCCIDENTAL'),
    'ER' => array('iso3' => 'ERI', 'isoNumber' => 232, 'phone' => '+291', 'licensePlate' => 'ER', 'de' => 'Eritrea', 'DE' => 'ERITREA', 'en' => 'Eritrea', 'EN' => 'ERITREA', 'es' => 'Eritrea', 'ES' => 'ERITREA', 'fr' => 'Érythrée', 'FR' => 'ÉRYTHRÉE'),
    'ES' => array('iso3' => 'ESP', 'isoNumber' => 724, 'phone' => '+34', 'licensePlate' => 'E', 'de' => 'Spanien', 'DE' => 'SPANIEN', 'en' => 'Spain', 'EN' => 'SPAIN', 'es' => 'España', 'ES' => 'ESPAÑA', 'fr' => 'Espagne', 'FR' => 'ESPAGNE'),
    'ET' => array('iso3' => 'ETH', 'isoNumber' => 231, 'phone' => '+251', 'licensePlate' => 'ETH', 'de' => 'Äthiopien', 'DE' => 'ÄTHIOPIEN', 'en' => 'Ethiopia', 'EN' => 'ETHIOPIA', 'es' => 'Etiopía', 'ES' => 'ETIOPÍA', 'fr' => 'Éthiopie', 'FR' => 'ÉTHIOPIE'),
    'FI' => array('iso3' => 'FIN', 'isoNumber' => 246, 'phone' => '+358', 'licensePlate' => 'FIN', 'de' => 'Finnland', 'DE' => 'FINNLAND', 'en' => 'Finland', 'EN' => 'FINLAND', 'es' => 'Finlandia', 'ES' => 'FINLANDIA', 'fr' => 'Finlande', 'FR' => 'FINLANDE'),
    'FJ' => array('iso3' => 'FJI', 'isoNumber' => 242, 'phone' => '+679', 'licensePlate' => 'FJI', 'de' => 'Fidschi', 'DE' => 'FIDSCHI', 'en' => 'Fiji', 'EN' => 'FIJI', 'es' => 'Fiji', 'ES' => 'FIJI', 'fr' => 'Fidji', 'FR' => 'FIDJI'),
    'FK' => array('iso3' => 'FLK', 'isoNumber' => 238, 'phone' => '+500', 'licensePlate' => '', 'de' => 'Falklandinseln (Malwinen)', 'DE' => 'FALKLANDINSELN (MALWINEN)', 'en' => 'Falkland Islands (Islas Malvinas)', 'EN' => 'FALKLAND ISLANDS (ISLAS MALVINAS)', 'es' => 'Islas Malvinas (Falkland Islands)', 'ES' => 'ISLAS MALVINAS (FALKLAND ISLANDS)', 'fr' => 'Îles Falkland (Malouines)', 'FR' => 'ÎLES FALKLAND (MALOUINES)'),
    'FM' => array('iso3' => 'FSM', 'isoNumber' => 583, 'phone' => '+691', 'licensePlate' => 'FSM', 'de' => 'Mikronesien', 'DE' => 'MIKRONESIEN', 'en' => 'Micronesia', 'EN' => 'MICRONESIA', 'es' => 'Micronesia', 'ES' => 'MICRONESIA', 'fr' => 'Micronésie', 'FR' => 'MICRONÉSIE'),
    'FO' => array('iso3' => 'FRO', 'isoNumber' => 234, 'phone' => '+298', 'licensePlate' => 'FO', 'de' => 'Färöer', 'DE' => 'FÄRÖER', 'en' => 'Faroe Islands', 'EN' => 'FAROE ISLANDS', 'es' => 'Islas Feroe', 'ES' => 'ISLAS FEROE', 'fr' => 'Îles Féroé', 'FR' => 'ÎLES FÉROÉ'),
    'FR' => array('iso3' => 'FRA', 'isoNumber' => 250, 'phone' => '+33', 'licensePlate' => 'F', 'de' => 'Frankreich', 'DE' => 'FRANKREICH', 'en' => 'France', 'EN' => 'FRANCE', 'es' => 'Francia', 'ES' => 'FRANCIA', 'fr' => 'France', 'FR' => 'FRANCE'),
    'GA' => array('iso3' => 'GAB', 'isoNumber' => 266, 'phone' => '+241', 'licensePlate' => 'G', 'de' => 'Gabun', 'DE' => 'GABUN', 'en' => 'Gabon', 'EN' => 'GABON', 'es' => 'Gabón', 'ES' => 'GABÓN', 'fr' => 'Gabon', 'FR' => 'GABON'),
    'GB' => array('iso3' => 'GBR', 'isoNumber' => 826, 'phone' => '+44', 'licensePlate' => 'GB', 'de' => 'UK', 'DE' => 'UK', 'en' => 'UK', 'EN' => 'UK', 'es' => 'UK', 'ES' => 'UK', 'fr' => 'UK', 'FR' => 'UK'),
    'GD' => array('iso3' => 'GRD', 'isoNumber' => 308, 'phone' => '+1473', 'licensePlate' => 'WG', 'de' => 'Grenada', 'DE' => 'GRENADA', 'en' => 'Grenada', 'EN' => 'GRENADA', 'es' => 'Granada', 'ES' => 'GRANADA', 'fr' => 'Grenade', 'FR' => 'GRENADE'),
    'GE' => array('iso3' => 'GEO', 'isoNumber' => 268, 'phone' => '+995', 'licensePlate' => 'GE', 'de' => 'Georgien', 'DE' => 'GEORGIEN', 'en' => 'Georgia', 'EN' => 'GEORGIA', 'es' => 'Georgia', 'ES' => 'GEORGIA', 'fr' => 'Géorgie', 'FR' => 'GÉORGIE'),
    'GF' => array('iso3' => 'GUF', 'isoNumber' => 254, 'phone' => '+594', 'licensePlate' => '', 'de' => '(Französisch-)Guayana', 'DE' => '(FRANZÖSISCH-)GUAYANA', 'en' => '(French) Guiana', 'EN' => '(FRENCH) GUIANA', 'es' => 'Guayana (Francesa)', 'ES' => 'GUAYANA (FRANCESA)', 'fr' => 'Guyane (française)', 'FR' => 'GUYANE (FRANÇAISE)'),
    'GG' => array('iso3' => 'GGY', 'isoNumber' => 831, 'phone' => '+441481', 'licensePlate' => 'GBG', 'de' => 'Guernsey', 'DE' => 'GUERNSEY', 'en' => 'Guernsey', 'EN' => 'GUERNSEY', 'es' => 'Guernsey', 'ES' => 'GUERNSEY', 'fr' => 'Guernesey', 'FR' => 'GUERNESEY'),
    'GH' => array('iso3' => 'GHA', 'isoNumber' => 288, 'phone' => '+233', 'licensePlate' => 'GH', 'de' => 'Ghana', 'DE' => 'GHANA', 'en' => 'Ghana', 'EN' => 'GHANA', 'es' => 'Ghana', 'ES' => 'GHANA', 'fr' => 'Ghana', 'FR' => 'GHANA'),
    'GI' => array('iso3' => 'GIB', 'isoNumber' => 292, 'phone' => '+350', 'licensePlate' => 'GBZ', 'de' => 'Gibraltar', 'DE' => 'GIBRALTAR', 'en' => 'Gibraltar', 'EN' => 'GIBRALTAR', 'es' => 'Gibraltar', 'ES' => 'GIBRALTAR', 'fr' => 'Gibraltar', 'FR' => 'GIBRALTAR'),
    'GL' => array('iso3' => 'GRL', 'isoNumber' => 304, 'phone' => '+299', 'licensePlate' => 'KN', 'de' => 'Grönland', 'DE' => 'GRÖNLAND', 'en' => 'Greenland', 'EN' => 'GREENLAND', 'es' => 'Groenlandia', 'ES' => 'GROENLANDIA', 'fr' => 'Groenland', 'FR' => 'GROENLAND'),
    'GM' => array('iso3' => 'GMB', 'isoNumber' => 270, 'phone' => '+220', 'licensePlate' => 'WAG', 'de' => 'Gambia', 'DE' => 'GAMBIA', 'en' => 'Gambia', 'EN' => 'GAMBIA', 'es' => 'Gambia', 'ES' => 'GAMBIA', 'fr' => 'Gambie', 'FR' => 'GAMBIE'),
    'GN' => array('iso3' => 'GIN', 'isoNumber' => 324, 'phone' => '+224', 'licensePlate' => array('GUI', 'RG'), 'de' => 'Guinea', 'DE' => 'GUINEA', 'en' => 'Guinea', 'EN' => 'GUINEA', 'es' => 'Guinea', 'ES' => 'GUINEA', 'fr' => 'Guinée', 'FR' => 'GUINÉE'),
    'GP' => array('iso3' => 'GLP', 'isoNumber' => 312, 'phone' => '+590', 'licensePlate' => '', 'de' => 'Guadeloupe', 'DE' => 'GUADELOUPE', 'en' => 'Guadeloupe', 'EN' => 'GUADELOUPE', 'es' => 'Guadalupe', 'ES' => 'GUADALUPE', 'fr' => 'Guadeloupe', 'FR' => 'GUADELOUPE'),
    'GQ' => array('iso3' => 'GNQ', 'isoNumber' => 226, 'phone' => '+240', 'licensePlate' => 'GQ', 'de' => 'Äquatorialguinea', 'DE' => 'ÄQUATORIALGUINEA', 'en' => 'Equatorial Guinea', 'EN' => 'EQUATORIAL GUINEA', 'es' => 'Guinea Ecuatorial', 'ES' => 'GUINEA ECUATORIAL', 'fr' => 'Guinée équatoriale', 'FR' => 'GUINÉE ÉQUATORIALE'),
    'GR' => array('iso3' => 'GRC', 'isoNumber' => 300, 'phone' => '+30', 'licensePlate' => 'GR', 'de' => 'Griechenland', 'DE' => 'GRIECHENLAND', 'en' => 'Greece', 'EN' => 'GREECE', 'es' => 'Grecia', 'ES' => 'GRECIA', 'fr' => 'Grèce', 'FR' => 'GRÈCE'),
    'GS' => array('iso3' => 'SGS', 'isoNumber' => 239, 'phone' => '+44', 'licensePlate' => '', 'de' => 'Südgeorgien und die Südlichen Sandwichinseln', 'DE' => 'SÜDGEORGIEN UND DIE SÜDLICHEN SANDWICHINSELN', 'en' => 'South Georgia and the South Sandwich Islands', 'EN' => 'SOUTH GEORGIA AND THE SOUTH SANDWICH ISLANDS', 'es' => 'Georgia del Sur y las islas Sandwich del Sur', 'ES' => 'GEORGIA DEL SUR Y LAS ISLAS SANDWICH DEL SUR', 'fr' => 'Géorgie du Sud et les îles Sandwich du Sud', 'FR' => 'GÉORGIE DU SUD ET LES ÎLES SANDWICH DU SUD'),
    'GT' => array('iso3' => 'GTM', 'isoNumber' => 320, 'phone' => '+502', 'licensePlate' => array('GCA', 'GT'), 'de' => 'Guatemala', 'DE' => 'GUATEMALA', 'en' => 'Guatemala', 'EN' => 'GUATEMALA', 'es' => 'Guatemala', 'ES' => 'GUATEMALA', 'fr' => 'Guatemala', 'FR' => 'GUATEMALA'),
    'GU' => array('iso3' => 'GUM', 'isoNumber' => 316, 'phone' => '+1671', 'licensePlate' => '', 'de' => 'Guam', 'DE' => 'GUAM', 'en' => 'Guam', 'EN' => 'GUAM', 'es' => 'Guam', 'ES' => 'GUAM', 'fr' => 'Guam', 'FR' => 'GUAM'),
    'GW' => array('iso3' => 'GNB', 'isoNumber' => 624, 'phone' => '+245', 'licensePlate' => 'GUB', 'de' => 'Guinea-Bissau', 'DE' => 'GUINEA-BISSAU', 'en' => 'Guinea-Bissau', 'EN' => 'GUINEA-BISSAU', 'es' => 'Guinea-Bissau', 'ES' => 'GUINEA-BISSAU', 'fr' => 'Guinée-Bissau', 'FR' => 'GUINÉE-BISSAU'),
    'GY' => array('iso3' => 'GUY', 'isoNumber' => 328, 'phone' => '+592', 'licensePlate' => 'GUY', 'de' => 'Guyana', 'DE' => 'GUYANA', 'en' => 'Guyana', 'EN' => 'GUYANA', 'es' => 'Guyana', 'ES' => 'GUYANA', 'fr' => 'Guyana', 'FR' => 'GUYANA'),
    'HK' => array('iso3' => 'HKG', 'isoNumber' => 344, 'phone' => '+852', 'licensePlate' => 'HK', 'de' => 'Hongkong', 'DE' => 'HONGKONG', 'en' => 'Hong Kong', 'EN' => 'HONG KONG', 'es' => 'Hong Kong', 'ES' => 'HONG KONG', 'fr' => 'Hong Kong', 'FR' => 'HONG KONG'),
    'HM' => array('iso3' => 'HMD', 'isoNumber' => 334, 'phone' => '+61', 'licensePlate' => '', 'de' => 'Heard und die McDonaldinseln', 'DE' => 'HEARD UND DIE MCDONALDINSELN', 'en' => 'Heard and the McDonald Islands', 'EN' => 'HEARD AND THE MCDONALD ISLANDS', 'es' => 'Islas Heard y McDonald', 'ES' => 'ISLAS HEARD Y MCDONALD', 'fr' => 'Îles Heard et McDonald', 'FR' => 'ÎLES HEARD ET MCDONALD'),
    'HN' => array('iso3' => 'HND', 'isoNumber' => 340, 'phone' => '+504', 'licensePlate' => 'HN', 'de' => 'Honduras', 'DE' => 'HONDURAS', 'en' => 'Honduras', 'EN' => 'HONDURAS', 'es' => 'Honduras', 'ES' => 'HONDURAS', 'fr' => 'Honduras', 'FR' => 'HONDURAS'),
    'HR' => array('iso3' => 'HRV', 'isoNumber' => 191, 'phone' => '+385', 'licensePlate' => 'HR', 'de' => 'Kroatien', 'DE' => 'KROATIEN', 'en' => 'Croatia', 'EN' => 'CROATIA', 'es' => 'Croacia', 'ES' => 'CROACIA', 'fr' => 'Croatie', 'FR' => 'CROATIE'),
    'HT' => array('iso3' => 'HTI', 'isoNumber' => 332, 'phone' => '+509', 'licensePlate' => 'RH', 'de' => 'Haiti', 'DE' => 'HAITI', 'en' => 'Haiti', 'EN' => 'HAITI', 'es' => 'Haití', 'ES' => 'HAITÍ', 'fr' => 'Haïti', 'FR' => 'HAÏTI'),
    'HU' => array('iso3' => 'HUN', 'isoNumber' => 348, 'phone' => '+36', 'licensePlate' => 'H', 'de' => 'Ungarn', 'DE' => 'UNGARN', 'en' => 'Hungary', 'EN' => 'HUNGARY', 'es' => 'Hungría', 'ES' => 'HUNGRÍA', 'fr' => 'Hongrie', 'FR' => 'HONGRIE'),
    'ID' => array('iso3' => 'IDN', 'isoNumber' => 360, 'phone' => '+62', 'licensePlate' => 'RI', 'de' => 'Indonesien', 'DE' => 'INDONESIEN', 'en' => 'Indonesia', 'EN' => 'INDONESIA', 'es' => 'Indonesia', 'ES' => 'INDONESIA', 'fr' => 'Indonésie', 'FR' => 'INDONÉSIE'),
    'IE' => array('iso3' => 'IRL', 'isoNumber' => 372, 'phone' => '+353', 'licensePlate' => 'IRL', 'de' => 'Irland', 'DE' => 'IRLAND', 'en' => 'Ireland', 'EN' => 'IRELAND', 'es' => 'Irlanda', 'ES' => 'IRLANDA', 'fr' => 'Irlande', 'FR' => 'IRLANDE'),
    'IL' => array('iso3' => 'ISR', 'isoNumber' => 376, 'phone' => '+972', 'licensePlate' => 'IL', 'de' => 'Israel', 'DE' => 'ISRAEL', 'en' => 'Israel', 'EN' => 'ISRAEL', 'es' => 'Israel', 'ES' => 'ISRAEL', 'fr' => 'Israël', 'FR' => 'ISRAËL'),
    'IM' => array('iso3' => 'IMN', 'isoNumber' => 833, 'phone' => '+441624', 'licensePlate' => 'GBM', 'de' => 'Insel Man', 'DE' => 'INSEL MAN', 'en' => 'Isle of Man', 'EN' => 'ISLE OF MAN', 'es' => 'Isla de Man', 'ES' => 'ISLA DE MAN', 'fr' => 'Île de Man', 'FR' => 'ÎLE DE MAN'),
    'IN' => array('iso3' => 'IND', 'isoNumber' => 356, 'phone' => '+91', 'licensePlate' => 'IND', 'de' => 'Indien', 'DE' => 'INDIEN', 'en' => 'India', 'EN' => 'INDIA', 'es' => 'India', 'ES' => 'INDIA', 'fr' => 'Inde', 'FR' => 'INDE'),
    'IO' => array('iso3' => 'IOT', 'isoNumber' => 86, 'phone' => '+246', 'licensePlate' => '', 'de' => 'Britisches Territorium im Indischen Ozean', 'DE' => 'BRITISCHES TERRITORIUM IM INDISCHEN OZEAN', 'en' => 'British Indian Ocean Territory', 'EN' => 'BRITISH INDIAN OCEAN TERRITORY', 'es' => 'Territorio Británico del Océano Índico', 'ES' => 'TERRITORIO BRITÁNICO DEL OCÉANO ÍNDICO', 'fr' => 'Territoire britannique de l\'océan Indien', 'FR' => 'TERRITOIRE BRITANNIQUE DE L\'OCÉAN INDIEN'),
    'IQ' => array('iso3' => 'IRQ', 'isoNumber' => 368, 'phone' => '+964', 'licensePlate' => 'IRQ', 'de' => 'Irak', 'DE' => 'IRAK', 'en' => 'Iraq', 'EN' => 'IRAQ', 'es' => 'Iraq', 'ES' => 'IRAQ', 'fr' => 'Iraq', 'FR' => 'IRAQ'),
    'IR' => array('iso3' => 'IRN', 'isoNumber' => 364, 'phone' => '+98', 'licensePlate' => 'IR', 'de' => 'Iran', 'DE' => 'IRAN', 'en' => 'Iran', 'EN' => 'IRAN', 'es' => 'Irán', 'ES' => 'IRÁN', 'fr' => 'Iran', 'FR' => 'IRAN'),
    'IS' => array('iso3' => 'ISL', 'isoNumber' => 352, 'phone' => '+354', 'licensePlate' => 'IS', 'de' => 'Island', 'DE' => 'ISLAND', 'en' => 'Iceland', 'EN' => 'ICELAND', 'es' => 'Islandia', 'ES' => 'ISLANDIA', 'fr' => 'Islande', 'FR' => 'ISLANDE'),
    'IT' => array('iso3' => 'ITA', 'isoNumber' => 380, 'phone' => '+39', 'licensePlate' => 'I', 'de' => 'Italien', 'DE' => 'ITALIEN', 'en' => 'Italy', 'EN' => 'ITALY', 'es' => 'Italia', 'ES' => 'ITALIA', 'fr' => 'Italie', 'FR' => 'ITALIE'),
    'JE' => array('iso3' => 'JEY', 'isoNumber' => 832, 'phone' => '+441534', 'licensePlate' => 'GBJ', 'de' => 'Jersey', 'DE' => 'JERSEY', 'en' => 'Jersey', 'EN' => 'JERSEY', 'es' => 'Jersey', 'ES' => 'JERSEY', 'fr' => 'Jersey', 'FR' => 'JERSEY'),
    'JM' => array('iso3' => 'JAM', 'isoNumber' => 388, 'phone' => '+1876', 'licensePlate' => 'JA', 'de' => 'Jamaika', 'DE' => 'JAMAIKA', 'en' => 'Jamaica', 'EN' => 'JAMAICA', 'es' => 'Jamaica', 'ES' => 'JAMAICA', 'fr' => 'Jamaïque', 'FR' => 'JAMAÏQUE'),
    'JO' => array('iso3' => 'JOR', 'isoNumber' => 400, 'phone' => '+962', 'licensePlate' => 'JOR', 'de' => 'Jordanien', 'DE' => 'JORDANIEN', 'en' => 'Jordan', 'EN' => 'JORDAN', 'es' => 'Jordania', 'ES' => 'JORDANIA', 'fr' => 'Jordanie', 'FR' => 'JORDANIE'),
    'JP' => array('iso3' => 'JPN', 'isoNumber' => 392, 'phone' => '+81', 'licensePlate' => 'J', 'de' => 'Japan', 'DE' => 'JAPAN', 'en' => 'Japan', 'EN' => 'JAPAN', 'es' => 'Japón', 'ES' => 'JAPÓN', 'fr' => 'Japon', 'FR' => 'JAPON'),
    'KE' => array('iso3' => 'KEN', 'isoNumber' => 404, 'phone' => '+254', 'licensePlate' => 'EAK', 'de' => 'Kenia', 'DE' => 'KENIA', 'en' => 'Kenya', 'EN' => 'KENYA', 'es' => 'Kenya', 'ES' => 'KENYA', 'fr' => 'Kenya', 'FR' => 'KENYA'),
    'KG' => array('iso3' => 'KGZ', 'isoNumber' => 417, 'phone' => '+996', 'licensePlate' => 'KG', 'de' => 'Kirgisistan', 'DE' => 'KIRGISISTAN', 'en' => 'Kyrgyzstan', 'EN' => 'KYRGYZSTAN', 'es' => 'Kirguistán', 'ES' => 'KIRGUISTÁN', 'fr' => 'Kirghizistan', 'FR' => 'KIRGHIZISTAN'),
    'KH' => array('iso3' => 'KHM', 'isoNumber' => 116, 'phone' => '+855', 'licensePlate' => 'K', 'de' => 'Kambodscha', 'DE' => 'KAMBODSCHA', 'en' => 'Cambodia', 'EN' => 'CAMBODIA', 'es' => 'Camboya', 'ES' => 'CAMBOYA', 'fr' => 'Cambodge', 'FR' => 'CAMBODGE'),
    'KI' => array('iso3' => 'KIR', 'isoNumber' => 296, 'phone' => '+686', 'licensePlate' => 'KIR', 'de' => 'Kiribati', 'DE' => 'KIRIBATI', 'en' => 'Kiribati', 'EN' => 'KIRIBATI', 'es' => 'Kiribati', 'ES' => 'KIRIBATI', 'fr' => 'Kiribati', 'FR' => 'KIRIBATI'),
    'KM' => array('iso3' => 'COM', 'isoNumber' => 174, 'phone' => '+269', 'licensePlate' => 'COM', 'de' => 'Komoren', 'DE' => 'KOMOREN', 'en' => 'Comoros', 'EN' => 'COMOROS', 'es' => 'Comoras', 'ES' => 'COMORAS', 'fr' => 'Comores', 'FR' => 'COMORES'),
    'KN' => array('iso3' => 'KNA', 'isoNumber' => 659, 'phone' => '+1869', 'licensePlate' => 'KAN', 'de' => 'St. Kitts und Nevis', 'DE' => 'ST. KITTS UND NEVIS', 'en' => 'Saint Kitts and Nevis', 'EN' => 'SAINT KITTS AND NEVIS', 'es' => 'Saint Kitts y Nevis', 'ES' => 'SAINT KITTS Y NEVIS', 'fr' => 'Saint-Kitts-et-Nevis', 'FR' => 'SAINT-KITTS-ET-NEVIS'),
    'KP' => array('iso3' => 'PRK', 'isoNumber' => 408, 'phone' => '+850', 'licensePlate' => 'KP', 'de' => 'Nordkorea', 'DE' => 'NORDKOREA', 'en' => 'North Korea', 'EN' => 'NORTH KOREA', 'es' => 'Corea del Norte', 'ES' => 'COREA DEL NORTE', 'fr' => 'Corée du Nord', 'FR' => 'CORÉE DU NORD'),
    'KR' => array('iso3' => 'KOR', 'isoNumber' => 410, 'phone' => '+82', 'licensePlate' => 'ROK', 'de' => 'Südkorea', 'DE' => 'SÜDKOREA', 'en' => 'South Korea', 'EN' => 'SOUTH KOREA', 'es' => 'Corea del Sur', 'ES' => 'COREA DEL SUR', 'fr' => 'Corée du Sud', 'FR' => 'CORÉE DU SUD'),
    'KW' => array('iso3' => 'KWT', 'isoNumber' => 414, 'phone' => '+965', 'licensePlate' => 'KWT', 'de' => 'Kuwait', 'DE' => 'KUWAIT', 'en' => 'Kuwait', 'EN' => 'KUWAIT', 'es' => 'Kuwait', 'ES' => 'KUWAIT', 'fr' => 'Koweït', 'FR' => 'KOWEÏT'),
    'KY' => array('iso3' => 'CYM', 'isoNumber' => 136, 'phone' => '+1345', 'licensePlate' => '', 'de' => 'Kaimaninseln', 'DE' => 'KAIMANINSELN', 'en' => 'Cayman Islands', 'EN' => 'CAYMAN ISLANDS', 'es' => 'Islas Caimanes', 'ES' => 'ISLAS CAIMANES', 'fr' => 'Îles Caïmanes', 'FR' => 'ÎLES CAÏMANES'),
    'KZ' => array('iso3' => 'KAZ', 'isoNumber' => 398, 'phone' => '+7', 'licensePlate' => 'KZ', 'de' => 'Kasachstan', 'DE' => 'KASACHSTAN', 'en' => 'Kazakhstan', 'EN' => 'KAZAKHSTAN', 'es' => 'Kazajstán', 'ES' => 'KAZAJSTÁN', 'fr' => 'Kazakhstan', 'FR' => 'KAZAKHSTAN'),
    'LA' => array('iso3' => 'LAO', 'isoNumber' => 418, 'phone' => '+856', 'licensePlate' => 'LAO', 'de' => 'Laos', 'DE' => 'LAOS', 'en' => 'Laos', 'EN' => 'LAOS', 'es' => 'Laos', 'ES' => 'LAOS', 'fr' => 'Laos', 'FR' => 'LAOS'),
    'LB' => array('iso3' => 'LBN', 'isoNumber' => 422, 'phone' => '+961', 'licensePlate' => 'RL', 'de' => 'Libanon', 'DE' => 'LIBANON', 'en' => 'Lebanon', 'EN' => 'LEBANON', 'es' => 'Líbano', 'ES' => 'LÍBANO', 'fr' => 'Liban', 'FR' => 'LIBAN'),
    'LC' => array('iso3' => 'LCA', 'isoNumber' => 662, 'phone' => '+1758', 'licensePlate' => 'WL', 'de' => 'St. Lucia', 'DE' => 'ST. LUCIA', 'en' => 'Saint Lucia', 'EN' => 'SAINT LUCIA', 'es' => 'Santa Lucía', 'ES' => 'SANTA LUCÍA', 'fr' => 'Sainte-Lucie', 'FR' => 'SAINTE-LUCIE'),
    'LI' => array('iso3' => 'LIE', 'isoNumber' => 438, 'phone' => '+423', 'licensePlate' => 'FL', 'de' => 'Liechtenstein', 'DE' => 'LIECHTENSTEIN', 'en' => 'Liechtenstein', 'EN' => 'LIECHTENSTEIN', 'es' => 'Liechtenstein', 'ES' => 'LIECHTENSTEIN', 'fr' => 'Liechtenstein', 'FR' => 'LIECHTENSTEIN'),
    'LK' => array('iso3' => 'LKA', 'isoNumber' => 144, 'phone' => '+94', 'licensePlate' => 'CL', 'de' => 'Sri Lanka', 'DE' => 'SRI LANKA', 'en' => 'Sri Lanka', 'EN' => 'SRI LANKA', 'es' => 'Sri Lanka', 'ES' => 'SRI LANKA', 'fr' => 'Sri Lanka', 'FR' => 'SRI LANKA'),
    'LR' => array('iso3' => 'LBR', 'isoNumber' => 430, 'phone' => '+231', 'licensePlate' => 'LB', 'de' => 'Liberia', 'DE' => 'LIBERIA', 'en' => 'Liberia', 'EN' => 'LIBERIA', 'es' => 'Liberia', 'ES' => 'LIBERIA', 'fr' => 'Libéria', 'FR' => 'LIBÉRIA'),
    'LS' => array('iso3' => 'LSO', 'isoNumber' => 426, 'phone' => '+266', 'licensePlate' => 'LS', 'de' => 'Lesotho', 'DE' => 'LESOTHO', 'en' => 'Lesotho', 'EN' => 'LESOTHO', 'es' => 'Lesotho', 'ES' => 'LESOTHO', 'fr' => 'Lesotho', 'FR' => 'LESOTHO'),
    'LT' => array('iso3' => 'LTU', 'isoNumber' => 440, 'phone' => '+370', 'licensePlate' => 'LT', 'de' => 'Litauen', 'DE' => 'LITAUEN', 'en' => 'Lithuania', 'EN' => 'LITHUANIA', 'es' => 'Lituania', 'ES' => 'LITUANIA', 'fr' => 'Lituanie', 'FR' => 'LITUANIE'),
    'LU' => array('iso3' => 'LUX', 'isoNumber' => 442, 'phone' => '+352', 'licensePlate' => 'L', 'de' => 'Luxemburg', 'DE' => 'LUXEMBURG', 'en' => 'Luxembourg', 'EN' => 'LUXEMBOURG', 'es' => 'Luxemburgo', 'ES' => 'LUXEMBURGO', 'fr' => 'Luxembourg', 'FR' => 'LUXEMBOURG'),
    'LV' => array('iso3' => 'LVA', 'isoNumber' => 428, 'phone' => '+371', 'licensePlate' => 'LV', 'de' => 'Lettland', 'DE' => 'LETTLAND', 'en' => 'Latvia', 'EN' => 'LATVIA', 'es' => 'Letonia', 'ES' => 'LETONIA', 'fr' => 'Lettonie', 'FR' => 'LETTONIE'),
    'LY' => array('iso3' => 'LBY', 'isoNumber' => 434, 'phone' => '+218', 'licensePlate' => 'LAR', 'de' => 'Libyen', 'DE' => 'LIBYEN', 'en' => 'Libya', 'EN' => 'LIBYA', 'es' => 'Libia', 'ES' => 'LIBIA', 'fr' => 'Libye', 'FR' => 'LIBYE'),
    'MA' => array('iso3' => 'MAR', 'isoNumber' => 504, 'phone' => '+212', 'licensePlate' => 'MA', 'de' => 'Marokko', 'DE' => 'MAROKKO', 'en' => 'Morocco', 'EN' => 'MOROCCO', 'es' => 'Marruecos', 'ES' => 'MARRUECOS', 'fr' => 'Maroc', 'FR' => 'MAROC'),
    'MC' => array('iso3' => 'MCO', 'isoNumber' => 492, 'phone' => '+377', 'licensePlate' => 'MC', 'de' => 'Monaco', 'DE' => 'MONACO', 'en' => 'Monaco', 'EN' => 'MONACO', 'es' => 'Mónaco', 'ES' => 'MÓNACO', 'fr' => 'Monaco', 'FR' => 'MONACO'),
    'MD' => array('iso3' => 'MDA', 'isoNumber' => 498, 'phone' => '+373', 'licensePlate' => 'MD', 'de' => 'Moldawien', 'DE' => 'MOLDAWIEN', 'en' => 'Moldova', 'EN' => 'MOLDOVA', 'es' => 'Moldavia', 'ES' => 'MOLDAVIA', 'fr' => 'Moldavie', 'FR' => 'MOLDAVIE'),
    'ME' => array('iso3' => 'MNE', 'isoNumber' => 499, 'phone' => '+382', 'licensePlate' => 'MNE', 'de' => 'Montenegro', 'DE' => 'MONTENEGRO', 'en' => 'Montenegro', 'EN' => 'MONTENEGRO', 'es' => 'Montenegro', 'ES' => 'MONTENEGRO', 'fr' => 'Monténégro', 'FR' => 'MONTÉNÉGRO'),
    'MF' => array('iso3' => 'MAF', 'isoNumber' => 663, 'phone' => '+590', 'licensePlate' => '', 'de' => 'St. Martin', 'DE' => 'ST. MARTIN', 'en' => 'Saint Martin', 'EN' => 'SAINT MARTIN', 'es' => 'San Martin', 'ES' => 'SAN MARTIN', 'fr' => 'Saint-Martin', 'FR' => 'SAINT-MARTIN'),
    'MG' => array('iso3' => 'MDG', 'isoNumber' => 450, 'phone' => '+261', 'licensePlate' => 'RM', 'de' => 'Madagaskar', 'DE' => 'MADAGASKAR', 'en' => 'Madagascar', 'EN' => 'MADAGASCAR', 'es' => 'Madagascar', 'ES' => 'MADAGASCAR', 'fr' => 'Madagascar', 'FR' => 'MADAGASCAR'),
    'MH' => array('iso3' => 'MHL', 'isoNumber' => 584, 'phone' => '+692', 'licensePlate' => 'MH', 'de' => 'Marshallinseln', 'DE' => 'MARSHALLINSELN', 'en' => 'Marshall Islands', 'EN' => 'MARSHALL ISLANDS', 'es' => 'Islas Marshall', 'ES' => 'ISLAS MARSHALL', 'fr' => 'Îles Marshall', 'FR' => 'ÎLES MARSHALL'),
    'MK' => array('iso3' => 'MKD', 'isoNumber' => 807, 'phone' => '+389', 'licensePlate' => 'MK', 'de' => 'Mazedonien', 'DE' => 'MAZEDONIEN', 'en' => 'Macedonia', 'EN' => 'MACEDONIA', 'es' => 'Macedonia', 'ES' => 'MACEDONIA', 'fr' => 'Macédoine', 'FR' => 'MACÉDOINE'),
    'ML' => array('iso3' => 'MLI', 'isoNumber' => 466, 'phone' => '+223', 'licensePlate' => 'RMM', 'de' => 'Mali', 'DE' => 'MALI', 'en' => 'Mali', 'EN' => 'MALI', 'es' => 'Mali', 'ES' => 'MALI', 'fr' => 'Mali', 'FR' => 'MALI'),
    'MM' => array('iso3' => 'MMR', 'isoNumber' => 104, 'phone' => '+95', 'licensePlate' => 'MYA', 'de' => 'Myanmar', 'DE' => 'MYANMAR', 'en' => 'Myanmar', 'EN' => 'MYANMAR', 'es' => 'Myanmar', 'ES' => 'MYANMAR', 'fr' => 'Myanmar', 'FR' => 'MYANMAR'),
    'MN' => array('iso3' => 'MNG', 'isoNumber' => 496, 'phone' => '+976', 'licensePlate' => 'MGL', 'de' => 'Mongolei', 'DE' => 'MONGOLEI', 'en' => 'Mongolia', 'EN' => 'MONGOLIA', 'es' => 'Mongolia', 'ES' => 'MONGOLIA', 'fr' => 'Mongolie', 'FR' => 'MONGOLIE'),
    'MO' => array('iso3' => 'MAC', 'isoNumber' => 446, 'phone' => '+853', 'licensePlate' => '', 'de' => 'Macau', 'DE' => 'MACAU', 'en' => 'Macao', 'EN' => 'MACAO', 'es' => 'Macao', 'ES' => 'MACAO', 'fr' => 'Macao', 'FR' => 'MACAO'),
    'MP' => array('iso3' => 'MNP', 'isoNumber' => 580, 'phone' => '+1670', 'licensePlate' => '', 'de' => 'Nördliche Marianen', 'DE' => 'NÖRDLICHE MARIANEN', 'en' => 'Northern Mariana Islands', 'EN' => 'NORTHERN MARIANA ISLANDS', 'es' => 'Islas Marianas del Norte', 'ES' => 'ISLAS MARIANAS DEL NORTE', 'fr' => 'Îles Mariannes du Nord', 'FR' => 'ÎLES MARIANNES DU NORD'),
    'MQ' => array('iso3' => 'MTQ', 'isoNumber' => 474, 'phone' => '+596', 'licensePlate' => '', 'de' => 'Martinique', 'DE' => 'MARTINIQUE', 'en' => 'Martinique', 'EN' => 'MARTINIQUE', 'es' => 'Martinica', 'ES' => 'MARTINICA', 'fr' => 'Martinique', 'FR' => 'MARTINIQUE'),
    'MR' => array('iso3' => 'MRT', 'isoNumber' => 478, 'phone' => '+222', 'licensePlate' => 'RIM', 'de' => 'Mauretanien', 'DE' => 'MAURETANIEN', 'en' => 'Mauritania', 'EN' => 'MAURITANIA', 'es' => 'Mauritania', 'ES' => 'MAURITANIA', 'fr' => 'Mauritanie', 'FR' => 'MAURITANIE'),
    'MS' => array('iso3' => 'MSR', 'isoNumber' => 500, 'phone' => '+1664', 'licensePlate' => '', 'de' => 'Montserrat', 'DE' => 'MONTSERRAT', 'en' => 'Montserrat', 'EN' => 'MONTSERRAT', 'es' => 'Montserrat', 'ES' => 'MONTSERRAT', 'fr' => 'Montserrat', 'FR' => 'MONTSERRAT'),
    'MT' => array('iso3' => 'MLT', 'isoNumber' => 470, 'phone' => '+356', 'licensePlate' => 'M', 'de' => 'Malta', 'DE' => 'MALTA', 'en' => 'Malta', 'EN' => 'MALTA', 'es' => 'Malta', 'ES' => 'MALTA', 'fr' => 'Malte', 'FR' => 'MALTE'),
    'MU' => array('iso3' => 'MUS', 'isoNumber' => 480, 'phone' => '+230', 'licensePlate' => 'MS', 'de' => 'Mauritius', 'DE' => 'MAURITIUS', 'en' => 'Mauritius', 'EN' => 'MAURITIUS', 'es' => 'Mauricio', 'ES' => 'MAURICIO', 'fr' => 'Maurice', 'FR' => 'MAURICE'),
    'MV' => array('iso3' => 'MDV', 'isoNumber' => 462, 'phone' => '+960', 'licensePlate' => 'MV', 'de' => 'Malediven', 'DE' => 'MALEDIVEN', 'en' => 'Maldives', 'EN' => 'MALDIVES', 'es' => 'Maldivas', 'ES' => 'MALDIVAS', 'fr' => 'Maldives', 'FR' => 'MALDIVES'),
    'MW' => array('iso3' => 'MWI', 'isoNumber' => 454, 'phone' => '+265', 'licensePlate' => 'MW', 'de' => 'Malawi', 'DE' => 'MALAWI', 'en' => 'Malawi', 'EN' => 'MALAWI', 'es' => 'Malawi', 'ES' => 'MALAWI', 'fr' => 'Malawi', 'FR' => 'MALAWI'),
    'MX' => array('iso3' => 'MEX', 'isoNumber' => 484, 'phone' => '+52', 'licensePlate' => 'MEX', 'de' => 'Mexiko', 'DE' => 'MEXIKO', 'en' => 'Mexico', 'EN' => 'MEXICO', 'es' => 'México', 'ES' => 'MÉXICO', 'fr' => 'Mexique', 'FR' => 'MEXIQUE'),
    'MY' => array('iso3' => 'MYS', 'isoNumber' => 458, 'phone' => '+60', 'licensePlate' => 'MAL', 'de' => 'Malaysia', 'DE' => 'MALAYSIA', 'en' => 'Malaysia', 'EN' => 'MALAYSIA', 'es' => 'Malasia', 'ES' => 'MALASIA', 'fr' => 'Malaisie', 'FR' => 'MALAISIE'),
    'MZ' => array('iso3' => 'MOZ', 'isoNumber' => 508, 'phone' => '+258', 'licensePlate' => 'MOC', 'de' => 'Mosambik', 'DE' => 'MOSAMBIK', 'en' => 'Mozambique', 'EN' => 'MOZAMBIQUE', 'es' => 'Mozambique', 'ES' => 'MOZAMBIQUE', 'fr' => 'Mozambique', 'FR' => 'MOZAMBIQUE'),
    'NA' => array('iso3' => 'NAM', 'isoNumber' => 516, 'phone' => '+264', 'licensePlate' => 'NAM', 'de' => 'Namibia', 'DE' => 'NAMIBIA', 'en' => 'Namibia', 'EN' => 'NAMIBIA', 'es' => 'Namibia', 'ES' => 'NAMIBIA', 'fr' => 'Namibie', 'FR' => 'NAMIBIE'),
    'NC' => array('iso3' => 'NCL', 'isoNumber' => 540, 'phone' => '+687', 'licensePlate' => 'NCL', 'de' => 'Neukaledonien', 'DE' => 'NEUKALEDONIEN', 'en' => 'New Caledonia', 'EN' => 'NEW CALEDONIA', 'es' => 'Nueva Caledonia', 'ES' => 'NUEVA CALEDONIA', 'fr' => 'Nouvelle-Calédonie', 'FR' => 'NOUVELLE-CALÉDONIE'),
    'NE' => array('iso3' => 'NER', 'isoNumber' => 562, 'phone' => '+227', 'licensePlate' => 'RN', 'de' => 'Niger', 'DE' => 'NIGER', 'en' => 'Niger', 'EN' => 'NIGER', 'es' => 'Níger', 'ES' => 'NÍGER', 'fr' => 'Niger', 'FR' => 'NIGER'),
    'NF' => array('iso3' => 'NFK', 'isoNumber' => 574, 'phone' => '+6723', 'licensePlate' => '', 'de' => 'Norfolkinsel', 'DE' => 'NORFOLKINSEL', 'en' => 'Norfolk Island', 'EN' => 'NORFOLK ISLAND', 'es' => 'Isla Norfolk', 'ES' => 'ISLA NORFOLK', 'fr' => 'Île Norfolk', 'FR' => 'ÎLE NORFOLK'),
    'NG' => array('iso3' => 'NGA', 'isoNumber' => 566, 'phone' => '+234', 'licensePlate' => 'NGR', 'de' => 'Nigeria', 'DE' => 'NIGERIA', 'en' => 'Nigeria', 'EN' => 'NIGERIA', 'es' => 'Nigeria', 'ES' => 'NIGERIA', 'fr' => 'Nigéria', 'FR' => 'NIGÉRIA'),
    'NI' => array('iso3' => 'NIC', 'isoNumber' => 558, 'phone' => '+505', 'licensePlate' => 'NIC', 'de' => 'Nicaragua', 'DE' => 'NICARAGUA', 'en' => 'Nicaragua', 'EN' => 'NICARAGUA', 'es' => 'Nicaragua', 'ES' => 'NICARAGUA', 'fr' => 'Nicaragua', 'FR' => 'NICARAGUA'),
    'NL' => array('iso3' => 'NLD', 'isoNumber' => 528, 'phone' => '+31', 'licensePlate' => 'NL', 'de' => 'Niederlande', 'DE' => 'NIEDERLANDE', 'en' => 'Netherlands', 'EN' => 'NETHERLANDS', 'es' => 'Países Bajos', 'ES' => 'PAÍSES BAJOS', 'fr' => 'Pays-Bas', 'FR' => 'PAYS-BAS'),
    'NO' => array('iso3' => 'NOR', 'isoNumber' => 578, 'phone' => '+47', 'licensePlate' => 'N', 'de' => 'Norwegen', 'DE' => 'NORWEGEN', 'en' => 'Norway', 'EN' => 'NORWAY', 'es' => 'Noruega', 'ES' => 'NORUEGA', 'fr' => 'Norvège', 'FR' => 'NORVÈGE'),
    'NP' => array('iso3' => 'NPL', 'isoNumber' => 524, 'phone' => '+977', 'licensePlate' => 'NEP', 'de' => 'Nepal', 'DE' => 'NEPAL', 'en' => 'Nepal', 'EN' => 'NEPAL', 'es' => 'Nepal', 'ES' => 'NEPAL', 'fr' => 'Népal', 'FR' => 'NÉPAL'),
    'NR' => array('iso3' => 'NRU', 'isoNumber' => 520, 'phone' => '+674', 'licensePlate' => 'NAU', 'de' => 'Nauru', 'DE' => 'NAURU', 'en' => 'Nauru', 'EN' => 'NAURU', 'es' => 'Nauru', 'ES' => 'NAURU', 'fr' => 'Nauru', 'FR' => 'NAURU'),
    'NU' => array('iso3' => 'NIU', 'isoNumber' => 570, 'phone' => '+683', 'licensePlate' => '', 'de' => 'Niue', 'DE' => 'NIUE', 'en' => 'Niue', 'EN' => 'NIUE', 'es' => 'Niue', 'ES' => 'NIUE', 'fr' => 'Nioué', 'FR' => 'NIOUÉ'),
    'NZ' => array('iso3' => 'NZL', 'isoNumber' => 554, 'phone' => '+64', 'licensePlate' => 'NZ', 'de' => 'Neuseeland', 'DE' => 'NEUSEELAND', 'en' => 'New Zealand', 'EN' => 'NEW ZEALAND', 'es' => 'Nueva Zelanda', 'ES' => 'NUEVA ZELANDA', 'fr' => 'Nouvelle-Zélande', 'FR' => 'NOUVELLE-ZÉLANDE'),
    'OM' => array('iso3' => 'OMN', 'isoNumber' => 512, 'phone' => '+968', 'licensePlate' => 'OM', 'de' => 'Oman', 'DE' => 'OMAN', 'en' => 'Oman', 'EN' => 'OMAN', 'es' => 'Omán', 'ES' => 'OMÁN', 'fr' => 'Oman', 'FR' => 'OMAN'),
    'PA' => array('iso3' => 'PAN', 'isoNumber' => 591, 'phone' => '+507', 'licensePlate' => 'PA', 'de' => 'Panama', 'DE' => 'PANAMA', 'en' => 'Panama', 'EN' => 'PANAMA', 'es' => 'Panamá', 'ES' => 'PANAMÁ', 'fr' => 'Panama', 'FR' => 'PANAMA'),
    'PE' => array('iso3' => 'PER', 'isoNumber' => 604, 'phone' => '+51', 'licensePlate' => 'PE', 'de' => 'Peru', 'DE' => 'PERU', 'en' => 'Peru', 'EN' => 'PERU', 'es' => 'Perú', 'ES' => 'PERÚ', 'fr' => 'Pérou', 'FR' => 'PÉROU'),
    'PF' => array('iso3' => 'PYF', 'isoNumber' => 258, 'phone' => '+689', 'licensePlate' => '', 'de' => 'Französisch-Polynesiеn', 'DE' => 'FRANZÖSISCH-POLYNESIЕN', 'en' => 'French Polynesiа', 'EN' => 'FRENCH POLYNESIА', 'es' => 'Polinesia Francesa', 'ES' => 'POLINESIA FRANCESA', 'fr' => 'Polynésie française', 'FR' => 'POLYNÉSIE FRANÇAISE'),
    'PG' => array('iso3' => 'PNG', 'isoNumber' => 598, 'phone' => '+675', 'licensePlate' => 'PNG', 'de' => 'Papua-Neuguinea', 'DE' => 'PAPUA-NEUGUINEA', 'en' => 'Papua New Guinea', 'EN' => 'PAPUA NEW GUINEA', 'es' => 'Papua Nueva Guinea', 'ES' => 'PAPUA NUEVA GUINEA', 'fr' => 'Papouasie-Nouvelle-Guinée', 'FR' => 'PAPOUASIE-NOUVELLE-GUINÉE'),
    'PH' => array('iso3' => 'PHL', 'isoNumber' => 608, 'phone' => '+63', 'licensePlate' => 'RP', 'de' => 'Philippinen', 'DE' => 'PHILIPPINEN', 'en' => 'Philippines', 'EN' => 'PHILIPPINES', 'es' => 'Filipinas', 'ES' => 'FILIPINAS', 'fr' => 'Philippines', 'FR' => 'PHILIPPINES'),
    'PK' => array('iso3' => 'PAK', 'isoNumber' => 586, 'phone' => '+92', 'licensePlate' => 'PK', 'de' => 'Pakistan', 'DE' => 'PAKISTAN', 'en' => 'Pakistan', 'EN' => 'PAKISTAN', 'es' => 'Pakistán', 'ES' => 'PAKISTÁN', 'fr' => 'Pakistan', 'FR' => 'PAKISTAN'),
    'PL' => array('iso3' => 'POL', 'isoNumber' => 616, 'phone' => '+48', 'licensePlate' => 'PL', 'de' => 'Polen', 'DE' => 'POLEN', 'en' => 'Poland', 'EN' => 'POLAND', 'es' => 'Polonia', 'ES' => 'POLONIA', 'fr' => 'Pologne', 'FR' => 'POLOGNE'),
    'PM' => array('iso3' => 'SPM', 'isoNumber' => 666, 'phone' => '+508', 'licensePlate' => '', 'de' => 'St. Pierre und Miquelon', 'DE' => 'ST. PIERRE UND MIQUELON', 'en' => 'Saint Pierre and Miquelon', 'EN' => 'SAINT PIERRE AND MIQUELON', 'es' => 'San Pedro y Miquelón', 'ES' => 'SAN PEDRO Y MIQUELÓN', 'fr' => 'Saint-Pierre-et-Miquelon', 'FR' => 'SAINT-PIERRE-ET-MIQUELON'),
    'PN' => array('iso3' => 'PCN', 'isoNumber' => 612, 'phone' => '+649', 'licensePlate' => '', 'de' => 'Pitcairninseln', 'DE' => 'PITCAIRNINSELN', 'en' => 'Pitcairn Islands Group', 'EN' => 'PITCAIRN ISLANDS GROUP', 'es' => 'Islas Pitcairn', 'ES' => 'ISLAS PITCAIRN', 'fr' => 'Îles Pitcairn', 'FR' => 'ÎLES PITCAIRN'),
    'PR' => array('iso3' => 'PRI', 'isoNumber' => 630, 'phone' => '+1787', 'licensePlate' => 'PRI', 'de' => 'Puerto Rico', 'DE' => 'PUERTO RICO', 'en' => 'Puerto Rico', 'EN' => 'PUERTO RICO', 'es' => 'Puerto Rico', 'ES' => 'PUERTO RICO', 'fr' => 'Porto Rico', 'FR' => 'PORTO RICO'),
    'PS' => array('iso3' => 'PSE', 'isoNumber' => 275, 'phone' => '+970', 'licensePlate' => array('AUT', 'WB'), 'de' => 'Palästina', 'DE' => 'PALÄSTINA', 'en' => 'Palestine', 'EN' => 'PALESTINE', 'es' => 'Palestina', 'ES' => 'PALESTINA', 'fr' => 'Palestine', 'FR' => 'PALESTINE'),
    'PT' => array('iso3' => 'PRT', 'isoNumber' => 620, 'phone' => '+351', 'licensePlate' => 'P', 'de' => 'Portugal', 'DE' => 'PORTUGAL', 'en' => 'Portugal', 'EN' => 'PORTUGAL', 'es' => 'Portugal', 'ES' => 'PORTUGAL', 'fr' => 'Portugal', 'FR' => 'PORTUGAL'),
    'PW' => array('iso3' => 'PLW', 'isoNumber' => 585, 'phone' => '+680', 'licensePlate' => 'PAL', 'de' => 'Palau', 'DE' => 'PALAU', 'en' => 'Palau', 'EN' => 'PALAU', 'es' => 'Palau', 'ES' => 'PALAU', 'fr' => 'Palaos', 'FR' => 'PALAOS'),
    'PY' => array('iso3' => 'PRY', 'isoNumber' => 600, 'phone' => '+595', 'licensePlate' => 'PY', 'de' => 'Paraguay', 'DE' => 'PARAGUAY', 'en' => 'Paraguay', 'EN' => 'PARAGUAY', 'es' => 'Paraguay', 'ES' => 'PARAGUAY', 'fr' => 'Paraguay', 'FR' => 'PARAGUAY'),
    'QA' => array('iso3' => 'QAT', 'isoNumber' => 634, 'phone' => '+974', 'licensePlate' => 'Q', 'de' => 'Katar', 'DE' => 'KATAR', 'en' => 'Qatar', 'EN' => 'QATAR', 'es' => 'Qatar', 'ES' => 'QATAR', 'fr' => 'Qatar', 'FR' => 'QATAR'),
    'RE' => array('iso3' => 'REU', 'isoNumber' => 638, 'phone' => '+262', 'licensePlate' => '', 'de' => 'Réunion', 'DE' => 'RÉUNION', 'en' => 'Réunion', 'EN' => 'RÉUNION', 'es' => 'Reunión', 'ES' => 'REUNIÓN', 'fr' => 'Réunion', 'FR' => 'RÉUNION'),
    'RO' => array('iso3' => 'ROU', 'isoNumber' => 642, 'phone' => '+40', 'licensePlate' => array('RO', 'RUM'), 'de' => 'Rumänien', 'DE' => 'RUMÄNIEN', 'en' => 'Romania', 'EN' => 'ROMANIA', 'es' => 'Rumania', 'ES' => 'RUMANIA', 'fr' => 'Roumanie', 'FR' => 'ROUMANIE'),
    'RS' => array('iso3' => 'SRB', 'isoNumber' => 688, 'phone' => '+381', 'licensePlate' => 'SRB', 'de' => 'Serbien', 'DE' => 'SERBIEN', 'en' => 'Serbia', 'EN' => 'SERBIA', 'es' => 'Serbia', 'ES' => 'SERBIA', 'fr' => 'Serbie', 'FR' => 'SERBIE'),
    'RU' => array('iso3' => 'RUS', 'isoNumber' => 643, 'phone' => '+7', 'licensePlate' => 'RUS', 'de' => 'Russland', 'DE' => 'RUSSLAND', 'en' => 'Russia', 'EN' => 'RUSSIA', 'es' => 'Rusia', 'ES' => 'RUSIA', 'fr' => 'Russie', 'FR' => 'RUSSIE'),
    'RW' => array('iso3' => 'RWA', 'isoNumber' => 646, 'phone' => '+250', 'licensePlate' => 'RWA', 'de' => 'Ruanda', 'DE' => 'RUANDA', 'en' => 'Rwanda', 'EN' => 'RWANDA', 'es' => 'Rwanda', 'ES' => 'RWANDA', 'fr' => 'Rwanda', 'FR' => 'RWANDA'),
    'SA' => array('iso3' => 'SAU', 'isoNumber' => 682, 'phone' => '+966', 'licensePlate' => 'KSA', 'de' => 'Saudi-Arabien', 'DE' => 'SAUDI-ARABIEN', 'en' => 'Saudi Arabia', 'EN' => 'SAUDI ARABIA', 'es' => 'Arabia Saudita', 'ES' => 'ARABIA SAUDITA', 'fr' => 'Arabie saoudite', 'FR' => 'ARABIE SAOUDITE'),
    'SB' => array('iso3' => 'SLB', 'isoNumber' => 90, 'phone' => '+677', 'licensePlate' => 'SOL', 'de' => 'Salomonen', 'DE' => 'SALOMONEN', 'en' => 'Solomon Islands', 'EN' => 'SOLOMON ISLANDS', 'es' => 'Islas Salomón', 'ES' => 'ISLAS SALOMÓN', 'fr' => 'Îles Salomon', 'FR' => 'ÎLES SALOMON'),
    'SC' => array('iso3' => 'SYC', 'isoNumber' => 690, 'phone' => '+248', 'licensePlate' => 'SY', 'de' => 'Seychellen', 'DE' => 'SEYCHELLEN', 'en' => 'Seychelles', 'EN' => 'SEYCHELLES', 'es' => 'Seychelles', 'ES' => 'SEYCHELLES', 'fr' => 'Seychelles', 'FR' => 'SEYCHELLES'),
    'SD' => array('iso3' => 'SDN', 'isoNumber' => 736, 'phone' => '+249', 'licensePlate' => 'SUD', 'de' => 'Sudan', 'DE' => 'SUDAN', 'en' => 'Sudan', 'EN' => 'SUDAN', 'es' => 'Sudán', 'ES' => 'SUDÁN', 'fr' => 'Soudan', 'FR' => 'SOUDAN'),
    'SE' => array('iso3' => 'SWE', 'isoNumber' => 752, 'phone' => '+46', 'licensePlate' => 'S', 'de' => 'Schweden', 'DE' => 'SCHWEDEN', 'en' => 'Sweden', 'EN' => 'SWEDEN', 'es' => 'Suecia', 'ES' => 'SUECIA', 'fr' => 'Suède', 'FR' => 'SUÈDE'),
    'SG' => array('iso3' => 'SGP', 'isoNumber' => 702, 'phone' => '+65', 'licensePlate' => 'SGP', 'de' => 'Singapur', 'DE' => 'SINGAPUR', 'en' => 'Singapore', 'EN' => 'SINGAPORE', 'es' => 'Singapur', 'ES' => 'SINGAPUR', 'fr' => 'Singapour', 'FR' => 'SINGAPOUR'),
    'SH' => array('iso3' => 'SHN', 'isoNumber' => 654, 'phone' => '+290', 'licensePlate' => '', 'de' => 'St. Helena, Ascension und Tristan da Cunha', 'DE' => 'ST. HELENA, ASCENSION UND TRISTAN DA CUNHA', 'en' => 'Saint Helena, Ascension and Tristan da Cunha', 'EN' => 'SAINT HELENA, ASCENSION AND TRISTAN DA CUNHA', 'es' => 'Santa Elena, Ascensión y Tristán da Cunha', 'ES' => 'SANTA ELENA, ASCENSIÓN Y TRISTÁN DA CUNHA', 'fr' => 'Sainte-Hélène, Ascension et Tristan da Cunha', 'FR' => 'SAINTE-HÉLÈNE, ASCENSION ET TRISTAN DA CUNHA'),
    'SI' => array('iso3' => 'SVN', 'isoNumber' => 705, 'phone' => '+386', 'licensePlate' => 'SLO', 'de' => 'Slowenien', 'DE' => 'SLOWENIEN', 'en' => 'Slovenia', 'EN' => 'SLOVENIA', 'es' => 'Eslovenia', 'ES' => 'ESLOVENIA', 'fr' => 'Slovénie', 'FR' => 'SLOVÉNIE'),
    'SJ' => array('iso3' => 'SJM', 'isoNumber' => 744, 'phone' => '+47', 'licensePlate' => '', 'de' => 'Svalbard und Jan Mаyen', 'DE' => 'SVALBARD UND JAN MАYEN', 'en' => 'Svalbard and Jan Mayen', 'EN' => 'SVALBARD AND JAN MAYEN', 'es' => 'Svalbard y Jan Mayen', 'ES' => 'SVALBARD Y JAN MAYEN', 'fr' => 'Svalbard et Jan Mayen', 'FR' => 'SVALBARD ET JAN MAYEN'),
    'SK' => array('iso3' => 'SVK', 'isoNumber' => 703, 'phone' => '+421', 'licensePlate' => 'SK', 'de' => 'Slowakei', 'DE' => 'SLOWAKEI', 'en' => 'Slovakia', 'EN' => 'SLOVAKIA', 'es' => 'Eslovaquia', 'ES' => 'ESLOVAQUIA', 'fr' => 'Slovaquie', 'FR' => 'SLOVAQUIE'),
    'SL' => array('iso3' => 'SLE', 'isoNumber' => 694, 'phone' => '+232', 'licensePlate' => array('SLE', 'WAL'), 'de' => 'Sierra Leone', 'DE' => 'SIERRA LEONE', 'en' => 'Sierra Leone', 'EN' => 'SIERRA LEONE', 'es' => 'Sierra Leona', 'ES' => 'SIERRA LEONA', 'fr' => 'Sierra Leone', 'FR' => 'SIERRA LEONE'),
    'SM' => array('iso3' => 'SMR', 'isoNumber' => 674, 'phone' => '+378', 'licensePlate' => 'RSM', 'de' => 'San Marino', 'DE' => 'SAN MARINO', 'en' => 'San Marino', 'EN' => 'SAN MARINO', 'es' => 'San Marino', 'ES' => 'SAN MARINO', 'fr' => 'Saint-Marin', 'FR' => 'SAINT-MARIN'),
    'SN' => array('iso3' => 'SEN', 'isoNumber' => 686, 'phone' => '+221', 'licensePlate' => 'SN', 'de' => 'Senegal', 'DE' => 'SENEGAL', 'en' => 'Senegal', 'EN' => 'SENEGAL', 'es' => 'Senegal', 'ES' => 'SENEGAL', 'fr' => 'Sénégal', 'FR' => 'SÉNÉGAL'),
    'SO' => array('iso3' => 'SOM', 'isoNumber' => 706, 'phone' => '+252', 'licensePlate' => 'SO', 'de' => 'Somalia', 'DE' => 'SOMALIA', 'en' => 'Somalia', 'EN' => 'SOMALIA', 'es' => 'Somalia', 'ES' => 'SOMALIA', 'fr' => 'Somalie', 'FR' => 'SOMALIE'),
    'SR' => array('iso3' => 'SUR', 'isoNumber' => 740, 'phone' => '+597', 'licensePlate' => 'SME', 'de' => 'Suriname', 'DE' => 'SURINAME', 'en' => 'Suriname', 'EN' => 'SURINAME', 'es' => 'Suriname', 'ES' => 'SURINAME', 'fr' => 'Suriname', 'FR' => 'SURINAME'),
    'SS' => array('iso3' => 'SSD', 'isoNumber' => 728, 'phone' => '+211', 'licensePlate' => 'SSD', 'de' => 'Südsudan', 'DE' => 'SÜDSUDAN', 'en' => 'South Sudan', 'EN' => 'SOUTH SUDAN', 'es' => 'Sudán del Sur', 'ES' => 'SUDÁN DEL SUR', 'fr' => 'Soudan du Sud', 'FR' => 'SOUDAN DU SUD'),
    'ST' => array('iso3' => 'STP', 'isoNumber' => 678, 'phone' => '+239', 'licensePlate' => 'STP', 'de' => 'São Tomé und Príncipe', 'DE' => 'SÃO TOMÉ UND PRÍNCIPE', 'en' => 'Sao Tome and Principe', 'EN' => 'SAO TOME AND PRINCIPE', 'es' => 'Santo Tomé y Príncipe', 'ES' => 'SANTO TOMÉ Y PRÍNCIPE', 'fr' => 'Sao Tomé-et-Principe', 'FR' => 'SAO TOMÉ-ET-PRINCIPE'),
    'SV' => array('iso3' => 'SLV', 'isoNumber' => 222, 'phone' => '+503', 'licensePlate' => 'ES', 'de' => 'El Salvador', 'DE' => 'EL SALVADOR', 'en' => 'El Salvador', 'EN' => 'EL SALVADOR', 'es' => 'El Salvador', 'ES' => 'EL SALVADOR', 'fr' => 'El Salvador', 'FR' => 'EL SALVADOR'),
    'SX' => array('iso3' => 'SXM', 'isoNumber' => 534, 'phone' => '+1721', 'licensePlate' => '', 'de' => 'St. Martin', 'DE' => 'ST. MARTIN', 'en' => 'Sint Maartеn', 'EN' => 'SINT MAARTЕN', 'es' => 'San Martín', 'ES' => 'SAN MARTÍN', 'fr' => 'Saint-Martin', 'FR' => 'SAINT-MARTIN'),
    'SY' => array('iso3' => 'SYR', 'isoNumber' => 760, 'phone' => '+963', 'licensePlate' => 'SYR', 'de' => 'Syrien', 'DE' => 'SYRIEN', 'en' => 'Syria', 'EN' => 'SYRIA', 'es' => 'Siria', 'ES' => 'SIRIA', 'fr' => 'Syrie', 'FR' => 'SYRIE'),
    'SZ' => array('iso3' => 'SWZ', 'isoNumber' => 748, 'phone' => '+268', 'licensePlate' => 'SD', 'de' => 'Swasiland', 'DE' => 'SWASILAND', 'en' => 'Swaziland', 'EN' => 'SWAZILAND', 'es' => 'Swazilandia', 'ES' => 'SWAZILANDIA', 'fr' => 'Swaziland', 'FR' => 'SWAZILAND'),
    'TC' => array('iso3' => 'TCA', 'isoNumber' => 796, 'phone' => '+1649', 'licensePlate' => '', 'de' => 'Turks- und Caicosinseln', 'DE' => 'TURKS- UND CAICOSINSELN', 'en' => 'Turks and Caicos Islands', 'EN' => 'TURKS AND CAICOS ISLANDS', 'es' => 'Islas Turcas y Caicos', 'ES' => 'ISLAS TURCAS Y CAICOS', 'fr' => 'Îles Turques et Caïques', 'FR' => 'ÎLES TURQUES ET CAÏQUES'),
    'TD' => array('iso3' => 'TCD', 'isoNumber' => 148, 'phone' => '+253', 'licensePlate' => 'TD', 'de' => 'Tschad', 'DE' => 'TSCHAD', 'en' => 'Chad', 'EN' => 'CHAD', 'es' => 'Chad', 'ES' => 'CHAD', 'fr' => 'Tchad', 'FR' => 'TCHAD'),
    'TF' => array('iso3' => 'ATF', 'isoNumber' => 260, 'phone' => '+33', 'licensePlate' => '', 'de' => 'Französische Süd- und Antarktisgebiete', 'DE' => 'FRANZÖSISCHE SÜD- UND ANTARKTISGEBIETE', 'en' => 'French Southern and Antarctic Territories', 'EN' => 'FRENCH SOUTHERN AND ANTARCTIC TERRITORIES', 'es' => 'Tierras Australes y Antárticas Francesas', 'ES' => 'TIERRAS AUSTRALES Y ANTÁRTICAS FRANCESAS', 'fr' => 'Terres australes et antarctiques françaises', 'FR' => 'TERRES AUSTRALES ET ANTARCTIQUES FRANÇAISES'),
    'TG' => array('iso3' => 'TGO', 'isoNumber' => 768, 'phone' => '+228', 'licensePlate' => array('RT', 'TG'), 'de' => 'Togo', 'DE' => 'TOGO', 'en' => 'Togo', 'EN' => 'TOGO', 'es' => 'Togo', 'ES' => 'TOGO', 'fr' => 'Togo', 'FR' => 'TOGO'),
    'TH' => array('iso3' => 'THA', 'isoNumber' => 764, 'phone' => '+66', 'licensePlate' => 'T', 'de' => 'Thailand', 'DE' => 'THAILAND', 'en' => 'Thailand', 'EN' => 'THAILAND', 'es' => 'Tailandia', 'ES' => 'TAILANDIA', 'fr' => 'Thaïlande', 'FR' => 'THAÏLANDE'),
    'TJ' => array('iso3' => 'TJK', 'isoNumber' => 762, 'phone' => '+992', 'licensePlate' => 'TJ', 'de' => 'Tadschikistan', 'DE' => 'TADSCHIKISTAN', 'en' => 'Tajikistan', 'EN' => 'TAJIKISTAN', 'es' => 'Tayikistán', 'ES' => 'TAYIKISTÁN', 'fr' => 'Tadjikistan', 'FR' => 'TADJIKISTAN'),
    'TK' => array('iso3' => 'TKL', 'isoNumber' => 772, 'phone' => '+690', 'licensePlate' => '', 'de' => 'Tokelau', 'DE' => 'TOKELAU', 'en' => 'Tokelau', 'EN' => 'TOKELAU', 'es' => 'Tokelau', 'ES' => 'TOKELAU', 'fr' => 'Tokelau', 'FR' => 'TOKELAU'),
    'TL' => array('iso3' => 'TLS', 'isoNumber' => 626, 'phone' => '+670', 'licensePlate' => 'TL', 'de' => 'Timor-Leste', 'DE' => 'TIMOR-LESTE', 'en' => 'Timor-Leste', 'EN' => 'TIMOR-LESTE', 'es' => 'Timor-Leste', 'ES' => 'TIMOR-LESTE', 'fr' => 'Timor-Leste', 'FR' => 'TIMOR-LESTE'),
    'TM' => array('iso3' => 'TKM', 'isoNumber' => 795, 'phone' => '+993', 'licensePlate' => 'TM', 'de' => 'Turkmenistan', 'DE' => 'TURKMENISTAN', 'en' => 'Turkmenistan', 'EN' => 'TURKMENISTAN', 'es' => 'Turkmenistán', 'ES' => 'TURKMENISTÁN', 'fr' => 'Turkménistan', 'FR' => 'TURKMÉNISTAN'),
    'TN' => array('iso3' => 'TUN', 'isoNumber' => 788, 'phone' => '+216', 'licensePlate' => 'TN', 'de' => 'Tunesien', 'DE' => 'TUNESIEN', 'en' => 'Tunisia', 'EN' => 'TUNISIA', 'es' => 'Túnez', 'ES' => 'TÚNEZ', 'fr' => 'Tunisie', 'FR' => 'TUNISIE'),
    'TO' => array('iso3' => 'TON', 'isoNumber' => 776, 'phone' => '+676', 'licensePlate' => 'TON', 'de' => 'Tonga', 'DE' => 'TONGA', 'en' => 'Tonga', 'EN' => 'TONGA', 'es' => 'Tonga', 'ES' => 'TONGA', 'fr' => 'Tonga', 'FR' => 'TONGA'),
    'TR' => array('iso3' => 'TUR', 'isoNumber' => 792, 'phone' => '+90', 'licensePlate' => 'TR', 'de' => 'Türkei', 'DE' => 'TÜRKEI', 'en' => 'Türkiye', 'EN' => 'TÜRKIYE', 'es' => 'Turquía', 'ES' => 'TURQUÍA', 'fr' => 'Turquie', 'FR' => 'TURQUIE'),
    'TT' => array('iso3' => 'TTO', 'isoNumber' => 780, 'phone' => '+1868', 'licensePlate' => 'TT', 'de' => 'Trinidad und Tobago', 'DE' => 'TRINIDAD UND TOBAGO', 'en' => 'Trinidad and Tobago', 'EN' => 'TRINIDAD AND TOBAGO', 'es' => 'Trinidad y Tabago', 'ES' => 'TRINIDAD Y TABAGO', 'fr' => 'Trinité-et-Tobago', 'FR' => 'TRINITÉ-ET-TOBAGO'),
    'TV' => array('iso3' => 'TUV', 'isoNumber' => 798, 'phone' => '+688', 'licensePlate' => 'TUV', 'de' => 'Tuvalu', 'DE' => 'TUVALU', 'en' => 'Tuvalu', 'EN' => 'TUVALU', 'es' => 'Tuvalu', 'ES' => 'TUVALU', 'fr' => 'Tuvalu', 'FR' => 'TUVALU'),
    'TW' => array('iso3' => 'TWN', 'isoNumber' => 158, 'phone' => '+886', 'licensePlate' => 'RC', 'de' => 'Taiwаn', 'DE' => 'TAIWАN', 'en' => 'Taiwаn', 'EN' => 'TAIWАN', 'es' => 'Taiwаn', 'ES' => 'TAIWАN', 'fr' => 'Taiwаn', 'FR' => 'TAIWАN'),
    'TZ' => array('iso3' => 'TZA', 'isoNumber' => 834, 'phone' => '+255', 'licensePlate' => 'EAT', 'de' => 'Tansania', 'DE' => 'TANSANIA', 'en' => 'Tanzania', 'EN' => 'TANZANIA', 'es' => 'Tanzanía', 'ES' => 'TANZANÍA', 'fr' => 'Tanzanie', 'FR' => 'TANZANIE'),
    'UA' => array('iso3' => 'UKR', 'isoNumber' => 804, 'phone' => '+380', 'licensePlate' => 'UA', 'de' => 'Ukraine', 'DE' => 'UKRAINE', 'en' => 'Ukraine', 'EN' => 'UKRAINE', 'es' => 'Ucrania', 'ES' => 'UCRANIA', 'fr' => 'Ukraine', 'FR' => 'UKRAINE'),
    'UG' => array('iso3' => 'UGA', 'isoNumber' => 800, 'phone' => '+256', 'licensePlate' => 'EAU', 'de' => 'Uganda', 'DE' => 'UGANDA', 'en' => 'Uganda', 'EN' => 'UGANDA', 'es' => 'Uganda', 'ES' => 'UGANDA', 'fr' => 'Ouganda', 'FR' => 'OUGANDA'),
    'UK' => array('iso3' => 'GBR', 'isoNumber' => 826, 'phone' => '+44', 'licensePlate' => '', 'de' => 'UK', 'DE' => 'UK', 'en' => 'UK', 'EN' => 'UK', 'es' => 'UK', 'ES' => 'UK', 'fr' => 'UK', 'FR' => 'UK'),
    'UM' => array('iso3' => 'UMI', 'isoNumber' => 581, 'phone' => '+1808', 'licensePlate' => '', 'de' => 'Kleinere Amerikanische Überseeinseln', 'DE' => 'KLEINERE AMERIKANISCHE ÜBERSEEINSELN', 'en' => 'United States Minor Outlying Islands', 'EN' => 'UNITED STATES MINOR OUTLYING ISLANDS', 'es' => 'Islas remotas menores de los Estados Unidos', 'ES' => 'ISLAS REMOTAS MENORES DE LOS ESTADOS UNIDOS', 'fr' => 'Îles mineures éloignées des États-Unis', 'FR' => 'ÎLES MINEURES ÉLOIGNÉES DES ÉTATS-UNIS'),
    'US' => array('iso3' => 'USA', 'isoNumber' => 840, 'phone' => '+1', 'licensePlate' => 'USA', 'de' => 'USA', 'DE' => 'USA', 'en' => 'USA', 'EN' => 'USA', 'es' => 'USA', 'ES' => 'USA', 'fr' => 'USA', 'FR' => 'USA'),
    'UY' => array('iso3' => 'URY', 'isoNumber' => 858, 'phone' => '+598', 'licensePlate' => 'ROU', 'de' => 'Uruguay', 'DE' => 'URUGUAY', 'en' => 'Uruguay', 'EN' => 'URUGUAY', 'es' => 'Uruguay', 'ES' => 'URUGUAY', 'fr' => 'Uruguay', 'FR' => 'URUGUAY'),
    'UZ' => array('iso3' => 'UZB', 'isoNumber' => 860, 'phone' => '+998', 'licensePlate' => 'UZ', 'de' => 'Usbekistan', 'DE' => 'USBEKISTAN', 'en' => 'Uzbekistan', 'EN' => 'UZBEKISTAN', 'es' => 'Uzbekistán', 'ES' => 'UZBEKISTÁN', 'fr' => 'Ouzbékistan', 'FR' => 'OUZBÉKISTAN'),
    'VA' => array('iso3' => 'VAT', 'isoNumber' => 336, 'phone' => '+379', 'licensePlate' => 'V', 'de' => 'Vatikan', 'DE' => 'VATIKAN', 'en' => 'Vatican City', 'EN' => 'VATICAN CITY', 'es' => 'Vaticano', 'ES' => 'VATICANO', 'fr' => 'Vatican', 'FR' => 'VATICAN'),
    'VC' => array('iso3' => 'VCT', 'isoNumber' => 670, 'phone' => '+1784', 'licensePlate' => 'WV', 'de' => 'St. Vincent und die Grenadinen', 'DE' => 'ST. VINCENT UND DIE GRENADINEN', 'en' => 'Saint Vincent and the Grenadines', 'EN' => 'SAINT VINCENT AND THE GRENADINES', 'es' => 'San Vicente y las Granadinas', 'ES' => 'SAN VICENTE Y LAS GRANADINAS', 'fr' => 'Saint-Vincent-et-les Grenadines', 'FR' => 'SAINT-VINCENT-ET-LES GRENADINES'),
    'VE' => array('iso3' => 'VEN', 'isoNumber' => 862, 'phone' => '+58', 'licensePlate' => 'YV', 'de' => 'Venezuela', 'DE' => 'VENEZUELA', 'en' => 'Venezuela', 'EN' => 'VENEZUELA', 'es' => 'Venezuela', 'ES' => 'VENEZUELA', 'fr' => 'Venezuela', 'FR' => 'VENEZUELA'),
    'VG' => array('iso3' => 'VGB', 'isoNumber' => 92, 'phone' => '+1284', 'licensePlate' => '', 'de' => 'Britische Jungferninseln', 'DE' => 'BRITISCHE JUNGFERNINSELN', 'en' => 'British Virgin Islands', 'EN' => 'BRITISH VIRGIN ISLANDS', 'es' => 'Islas Vírgenes Británicas', 'ES' => 'ISLAS VÍRGENES BRITÁNICAS', 'fr' => 'Îles Vierges britanniques', 'FR' => 'ÎLES VIERGES BRITANNIQUES'),
    'VI' => array('iso3' => 'VIR', 'isoNumber' => 850, 'phone' => '+1340', 'licensePlate' => '', 'de' => 'Jungferninseln', 'DE' => 'JUNGFERNINSELN', 'en' => 'Virgin Islands', 'EN' => 'VIRGIN ISLANDS', 'es' => 'Islas Vírgenes', 'ES' => 'ISLAS VÍRGENES', 'fr' => 'Îles Vierges', 'FR' => 'ÎLES VIERGES'),
    'VN' => array('iso3' => 'VNM', 'isoNumber' => 704, 'phone' => '+84', 'licensePlate' => 'VN', 'de' => 'Vietnam', 'DE' => 'VIETNAM', 'en' => 'Viet Nam', 'EN' => 'VIET NAM', 'es' => 'Viet Nam', 'ES' => 'VIET NAM', 'fr' => 'Viet Nam', 'FR' => 'VIET NAM'),
    'VU' => array('iso3' => 'VUT', 'isoNumber' => 548, 'phone' => '+678', 'licensePlate' => 'VAN', 'de' => 'Vanuatu', 'DE' => 'VANUATU', 'en' => 'Vanuatu', 'EN' => 'VANUATU', 'es' => 'Vanuatu', 'ES' => 'VANUATU', 'fr' => 'Vanuatu', 'FR' => 'VANUATU'),
    'WF' => array('iso3' => 'WLF', 'isoNumber' => 876, 'phone' => '+681', 'licensePlate' => '', 'de' => 'Wallis und Futunа', 'DE' => 'WALLIS UND FUTUNА', 'en' => 'Wallis and Futuna', 'EN' => 'WALLIS AND FUTUNA', 'es' => 'Wallis y Futuna', 'ES' => 'WALLIS Y FUTUNA', 'fr' => 'Wallis-et-Futuna', 'FR' => 'WALLIS-ET-FUTUNA'),
    'WS' => array('iso3' => 'WSM', 'isoNumber' => 882, 'phone' => '+685', 'licensePlate' => 'WS', 'de' => 'Samoa', 'DE' => 'SAMOA', 'en' => 'Samoa', 'EN' => 'SAMOA', 'es' => 'Samoa', 'ES' => 'SAMOA', 'fr' => 'Samoa', 'FR' => 'SAMOA'),
    'XK' => array('iso3' => '', 'isoNumber' => null, 'phone' => '+381', 'licensePlate' => 'RKS', 'de' => 'Kosovo', 'DE' => 'KOSOVO', 'en' => 'Kosovo', 'EN' => 'Kosovo', 'es' => 'Kosovo', 'ES' => 'Kosovo', 'fr' => 'Kosovo', 'FR' => 'Kosovo'),
    'YE' => array('iso3' => 'YEM', 'isoNumber' => 887, 'phone' => '+967', 'licensePlate' => 'YEM', 'de' => 'Jemen', 'DE' => 'JEMEN', 'en' => 'Yemen', 'EN' => 'YEMEN', 'es' => 'Yemen', 'ES' => 'YEMEN', 'fr' => 'Yémen', 'FR' => 'YÉMEN'),
    'YT' => array('iso3' => 'MYT', 'isoNumber' => 175, 'phone' => '+262', 'licensePlate' => '', 'de' => 'Mayotte', 'DE' => 'MAYOTTE', 'en' => 'Mayotte', 'EN' => 'MAYOTTE', 'es' => 'Mayotte', 'ES' => 'MAYOTTE', 'fr' => 'Mayotte', 'FR' => 'MAYOTTE'),
    'ZA' => array('iso3' => 'ZAF', 'isoNumber' => 710, 'phone' => '+27', 'licensePlate' => 'ZA', 'de' => 'Südafrika', 'DE' => 'SÜDAFRIKA', 'en' => 'South Africa', 'EN' => 'SOUTH AFRICA', 'es' => 'Sudáfrica', 'ES' => 'SUDÁFRICA', 'fr' => 'Afrique du Sud', 'FR' => 'AFRIQUE DU SUD'),
    'ZM' => array('iso3' => 'ZMB', 'isoNumber' => 894, 'phone' => '+260', 'licensePlate' => 'Z', 'de' => 'Sambia', 'DE' => 'SAMBIA', 'en' => 'Zambia', 'EN' => 'ZAMBIA', 'es' => 'Zambia', 'ES' => 'ZAMBIA', 'fr' => 'Zambie', 'FR' => 'ZAMBIE'),
    'ZW' => array('iso3' => 'ZWE', 'isoNumber' => 716, 'phone' => '+263', 'licensePlate' => 'ZW', 'de' => 'Simbabwe', 'DE' => 'SIMBABWE', 'en' => 'Zimbabwe', 'EN' => 'ZIMBABWE', 'es' => 'Zimbabwe', 'ES' => 'ZIMBABWE', 'fr' => 'Zimbabwe', 'FR' => 'ZIMBABWE')
  );

  /**
   * Cache für Länder ISO2 nach KFZ-Ländercodes.
   * @var array
   */
  protected static $_countriesLicensePlateToIso2;

  /**
   * Cache für Länder ISO2 nach ISO Nummerncodes.
   * @var array
   */
  protected static $_countriesIsoNumberToIso2;

  /**
   * Wochentage.
   * @var array
   */
  protected static $_days = array(
    1 => array('de' => 'Montag', 'en' => 'Monday', 'es' => 'Lunes', 'fr' => 'Lundi'),
    2 => array('de' => 'Dienstag', 'en' => 'Tuesday', 'es' => 'Martes', 'fr' => 'Mardi'),
    3 => array('de' => 'Mittwoch', 'en' => 'Wednesday', 'es' => 'Miércoles', 'fr' => 'Mercredi'),
    4 => array('de' => 'Donnerstag', 'en' => 'Thursday', 'es' => 'Jueves', 'fr' => 'Jeudi'),
    5 => array('de' => 'Freitag', 'en' => 'Friday', 'es' => 'Viernes', 'fr' => 'Vendredi'),
    6 => array('de' => 'Samstag', 'en' => 'Saturday', 'es' => 'Sábado', 'fr' => 'Samedi'),
    7 => array('de' => 'Sonntag', 'en' => 'Sunday', 'es' => 'Domingo', 'fr' => 'Dimanche')
  );

  /**
   * Monate.
   * @var array
   */
  protected static $_months = array(
    1 => array('de' => 'Januar', 'en' => 'January', 'es' => 'Enero', 'fr' => 'Janvier'),
    2 => array('de' => 'Februar', 'en' => 'February', 'es' => 'Febrero', 'fr' => 'Février'),
    3 => array('de' => 'März', 'en' => 'March', 'es' => 'Marzo', 'fr' => 'Mars'),
    4 => array('de' => 'April', 'en' => 'April', 'es' => 'Abril', 'fr' => 'Avril'),
    5 => array('de' => 'Mai', 'en' => 'May', 'es' => 'Mayo', 'fr' => 'Mai'),
    6 => array('de' => 'Juni', 'en' => 'June', 'es' => 'Junio', 'fr' => 'Juin'),
    7 => array('de' => 'Juli', 'en' => 'July', 'es' => 'Julio', 'fr' => 'Juillet'),
    8 => array('de' => 'August', 'en' => 'August', 'es' => 'Agosto', 'fr' => 'Août'),
    9 => array('de' => 'September', 'en' => 'September', 'es' => 'Septiembre', 'fr' => 'Septembre'),
    10 => array('de' => 'Oktober', 'en' => 'October', 'es' => 'Octubre', 'fr' => 'Octobre'),
    11 => array('de' => 'November', 'en' => 'November', 'es' => 'Noviembre', 'fr' => 'Novembre'),
    12 => array('de' => 'Dezember', 'en' => 'December', 'es' => 'Diciembre', 'fr' => 'Décembre')
  );

  /**
   * Währungssymbole.
   * @var array
   */
  protected static $_currencies = array(
    'EUR' => '€',
    'USD' => '$',
    'GBP' => '£'
  );

  /**
   * Formatiert eine Preisangabe.
   *
   * @param string|float $price    Preis
   * @param string       $currency Währung
   * @param boolean      $allowEmpty true: leeres Resultat zulassen,
   *   false: '0,00 ' + Währung bei leerem Resultat zurückgeben
   * @return string
   */
  public static function formatCurrency($price, $currency, $allowEmpty = false)
  {
    if($allowEmpty && $price === null)
      return '';
    else
      return str_replace('.', ',', sprintf('%.02f %s', str_replace(',', '.', $price), $currency));
  }

  /**
   * Liefert das Währungssymbol einer Währung.
   * Das Währungssymbol wird nur für die gängigsten Währungen zurückgeliefert, ansonsten wird das Währungskürzel
   * geliefert.
   *
   * @param string $currency Währungskürzel (drei Buchstaben).
   * @return string
   */
  public static function currencySymbol($currency)
  {
    $currency = strtoupper($currency);

    if(isset(self::$_currencies[$currency]))
      return self::$_currencies[$currency];
    else
      return $currency;
  }

  /**
   * Liefert einen Ländernamen anhand seines ISO3166 Zwei-Buchstaben-Codes.
   *
   * @param string  $iso2      ISO3166 Code (zwei Buchstaben)
   * @param string  $language  Sprachkürzel (de, en, es, fr)
   * @param boolean $upperCase true: Ländernamen in Großbuchstaben liefern (für Postanschrift)
   * @return string
   */
  public static function getCountryName($iso2, $language = 'de', $upperCase = false)
  {
    $iso2 = strtoupper($iso2);
    $language = strtolower($language);

    if($upperCase)
      $language = strtoupper($language);

    if(isset(self::$_countries[$iso2][$language]))
      return self::$_countries[$iso2][$language];
    else
      return '';
  }

  /**
   * Liefert Ländernamen und ISO-Code eines Landes anhand seines ISO3166 Zwei-Buchstaben-Codes.
   *
   * @param string $iso2 ISO3166 Code (zwei Buchstaben)
   * @return array
   */
  public static function getCountryData($iso2)
  {
    $iso2 = strtoupper($iso2);

    if(isset(self::$_countries[$iso2]))
      return self::$_countries[$iso2];
    else
      return null;
  }

  /**
   * Liefert den ISO2-Ländercode anhand eines KFZ-Länderkennzeichens.
   *
   * @param string $licensePlate KFZ-Länderkennzeichen (1-3 Buchstaben)
   * @return string
   */
  public static function getCountryIso2ByLicensePlate($licensePlate)
  {
    if(!is_array(self::$_countriesLicensePlateToIso2))
    {
      self::$_countriesLicensePlateToIso2 = array();

      foreach(self::$_countries as $iso2 => $country)
      {
        if(is_array($country['licensePlate']))
          $codes = $country['licensePlate'];
        elseif($country['licensePlate'])
          $codes = array($country['licensePlate']);
        else
          $codes = array();

        foreach($codes as $code)
          self::$_countriesLicensePlateToIso2[$code] = $iso2;
      }
    }

    if(isset(self::$_countriesLicensePlateToIso2[$licensePlate]))
      return self::$_countriesLicensePlateToIso2[$licensePlate];
    else
      return '';
  }

  /**
   * Liefert den ISO2-Ländercode anhand eines ISO 3166-1 Nummerncodes.
   *
   * @param int $isoNumber ISO Nummerncode
   * @return string
   */
  public static function getCountryIso2ByIsoNumber($isoNumber)
  {
    if(!is_array(self::$_countriesIsoNumberToIso2))
    {
      self::$_countriesIsoNumberToIso2 = array();

      foreach(self::$_countries as $iso2 => $country)
      {
        if ( !empty( $country[ 'isoNumber' ] ) ) {
          self::$_countriesIsoNumberToIso2[ $country[ 'isoNumber' ] ] = $iso2;
        }
      }
    }

    if(isset(self::$_countriesIsoNumberToIso2[$isoNumber]))
      return self::$_countriesIsoNumberToIso2[$isoNumber];
    else
      return '';
  }

  /**
   * Liefert einen Array aller Länderdaten.
   * Der ISO3166 Code (zwei Buchstaben) wird als Schlüssel der Array-Einträge verwendet.
   *
   * @return array
   */
  public static function getCountries()
  {
    return self::$_countries;
  }

  /**
   * Liefert einen leeren Adressdaten-Array.
   * Dieser Array enthält die Felder, die z.B. für getAddressLines() benötigt werden.
   *
   * @return array
   */
  public static function getEmptyAddress()
  {
    return array(
      'Company' => '',
      'Salutation' => '',
      'Sex.Number' => self::SEX_UNDEFINED,
      'Sex.Name' => 'Unbekannt',
      'Title' => '',
      'Name' => '',
      'Firstname' => '',
      'Lastname' => '',
      'Letter.Identifier' => '',
      'Letter.NameAdditionalInfo' => '',
      'Letter.Street' => '',
      'Letter.AdditionalInfo' => '',
      'Letter.ZipCode' => '',
      'Letter.City' => '',
      'Letter.Province' => '',
      'Letter.Country' => '',
      'Letter.CountryInfo.ISO2' => '',
      'Letter.CountryInfo.ISO3' => '',
      'Letter.CountryInfo.de' => '',
      'Letter.CountryInfo.DE' => '',
      'Letter.CountryInfo.en' => '',
      'Letter.CountryInfo.EN' => '',
      'Letter.CountryInfo.es' => '',
      'Letter.CountryInfo.ES' => '',
      'Letter.CountryInfo.fr' => '',
      'Letter.CountryInfo.FR' => '',
      'Letter.CountryInfo.PhonePrefix' => '',
      'Email' => '',
      'Phone' => '',
      'Mobile' => '',
      'Fax' => '',
      'Birthday' => new GhRpcDateTime()
    );
  }

  /**
   * Liefert die Zeilen für eine Postanschrift.
   *
   * @param array   $addressData        Adressdaten
   * @param array   $omitCountries      ISO Zwei-Buchstaben-Codes der Länder, deren Ländername nicht explizit in der Adresse aufgeführt wird, oder true, damit der Ländername generell weggelassen wird
   * @param string  $language           Sprachkürzel der Sprache für die Ländernamen (z.B. 'de')
   * @param boolean $omitCompanyAndName true: nur Adressdaten ohne Name und Firma liefern, false: Firma und Name in den Adressdaten mitliefern
   * @return array
   */
  public static function getAddressLines($addressData, $omitCountries = null, $language = 'de', $omitCompanyAndName = false)
  {
    $lines = array();

    if(((!isset($addressData['Name']) || !$addressData['Name']) && (!isset($addressData['Company']) || !$addressData['Company'])) || (!isset($addressData['Letter.City']) || !$addressData['Letter.City']))
      return $lines;

    if(!$omitCompanyAndName && isset($addressData['Company']) && $addressData['Company'])
      $lines[] = $addressData['Company'];

    if(!$omitCompanyAndName && isset($addressData['Name']) && $addressData['Name'])
      $lines[] = trim($addressData['Title'] . ' ' . $addressData['Name']);

    if (isset($addressData['Letter.NameAdditionalInfo']) && $addressData['Letter.NameAdditionalInfo']) {
      $lines[] = $addressData['Letter.NameAdditionalInfo'];
    }
    
    if(isset($addressData['Letter.Street']) && $addressData['Letter.Street'])
      $lines[] = $addressData['Letter.Street'];

    if(isset($addressData['Letter.AdditionalInfo']) && $addressData['Letter.AdditionalInfo'])
      $lines[] = $addressData['Letter.AdditionalInfo'];

    // Japan:
    if(isset($addressData['Letter.CountryInfo.ISO2']) && $addressData['Letter.CountryInfo.ISO2'] == 'JP')
    {
      $line = $addressData['Letter.City'];

      if($addressData['Letter.Province'])
        $line .= ', ' . $addressData['Letter.Province'];

      if($addressData['Letter.ZipCode'])
        $line .= ' ' . $addressData['Letter.ZipCode'];

      $lines[] = $line;
    }
    // USA:
    elseif(isset($addressData['Letter.CountryInfo.ISO2']) && $addressData['Letter.CountryInfo.ISO2'] == 'US')
    {
      $line = $addressData['Letter.City'];

      if($addressData['Letter.Province'])
        $line .= ' ' . $addressData['Letter.Province'];

      if($addressData['Letter.ZipCode'])
        $line .= ' ' . $addressData['Letter.ZipCode'];

      $lines[] = $line;
    }
    // Sonstige:
    else
    {
      if(isset($addressData['Letter.ZipCode']) && $addressData['Letter.ZipCode'] && isset($addressData['Letter.City']))
        $lines[] = trim($addressData['Letter.ZipCode'] . ' ' . $addressData['Letter.City']);
      elseif(isset($addressData['Letter.City']))
        $lines[] = $addressData['Letter.City'];
    }

    if($omitCountries !== true && !(is_array($omitCountries) && isset($addressData['Letter.CountryInfo.ISO2']) && in_array($addressData['Letter.CountryInfo.ISO2'], $omitCountries)) && $language)
    {
      $country = self::getCountryName($addressData['Letter.CountryInfo.ISO2'], $language, true);

      if($country)
        $lines[] = $country;
    }

    return $lines;
  }

  /**
   * Ergänzt bzw. bereinigt Adressdaten.
   *
   * @param array $address Adressdaten
   * @return array
   */
  public static function fixAddress($address)
  {
    // Fehlende Felder:
    if(!is_array($address))
      $address = self::getEmptyAddress();
    else
    {
      foreach(self::getEmptyAddress() as $key => $default)
        if(!isset($address[$key]))
          $address[$key] = $default;
    }

    // Name, Firstname und Lastname:
    if(!$address['Name'])
      $address['Name'] = trim(trim($address['Firstname']) . ' ' . trim($address['Lastname']));
    elseif(!$address['Firstname'] && !$address['Lastname'])
    {
      $nameIndex = strpos($address['Name'], ' ');

      if($nameIndex > 0)
      {
        $address['Firstname'] = substr($address['Name'], 0, $nameIndex);
        $address['Lastname'] = substr($address['Name'], $nameIndex + 1);
      }
      else
      {
        $address['Firstname'] = '';
        $address['Lastname'] = $address['Name'];
      }
    }

    // Geschlecht:
    if($address['Sex.Number'] == self::SEX_MALE)
      $address['Sex.Name'] = 'Männlich';
    elseif($address['Sex.Number'] == self::SEX_FEMALE)
      $address['Sex.Name'] = 'Weiblich';
    else
      $address['Sex.Name'] = 'Unbekannt';

    // Land:
    $address['Letter.CountryInfo.ISO2'] = strtoupper($address['Letter.CountryInfo.ISO2']);
    $address['Letter.Identifier'] = implode(', ', self::getAddressLines($address, null, 'de', true));
    $country = self::getCountryData($address['Letter.CountryInfo.ISO2']);

    if($country)
    {
      $address['Letter.Country'] = $country['de'];
      $address['Letter.CountryInfo.ISO3'] = $country['iso3'];
      $address['Letter.CountryInfo.de'] = $country['de'];
      $address['Letter.CountryInfo.DE'] = $country['DE'];
      $address['Letter.CountryInfo.en'] = $country['en'];
      $address['Letter.CountryInfo.EN'] = $country['EN'];
      $address['Letter.CountryInfo.es'] = $country['es'];
      $address['Letter.CountryInfo.ES'] = $country['ES'];
      $address['Letter.CountryInfo.fr'] = $country['fr'];
      $address['Letter.CountryInfo.FR'] = $country['FR'];
      $address['Letter.CountryInfo.PhonePrefix'] = $country['phone'];
    }

    return $address;
  }

  /**
   * Korrigiert eine Telefonnummer.
   *
   * @param string $phone  Telefonnummer
   * @param string $prefix Ländervorwahl, falls keine in der Telefonnummer enthalten ist
   * @return string
   */
  public static function fixPhoneNumber($phone, $prefix = '+49')
  {
    $phone = trim($phone);

    if(!$phone)
      return $phone;

    if(GhCoreStrings::startsWith($phone, '00'))
      $phone = '+' . preg_replace('/[^0-9]/', '', substr($phone, 2));
    elseif(!GhCoreStrings::startsWith($phone, '+'))
    {
      $phone = preg_replace('/[^0-9]/', '', $phone);

      if(strlen($phone) < 1)
        return $phone;

      if($phone[0] == '0')
        $phone = substr($phone, 1);

      $phone = $prefix . $phone;
    }
    else
      $phone = '+' . preg_replace('/[^0-9]/', '', $phone);

    return $phone;
  }

  /**
   * Liefert eine korrekt formatierte Telefonnummer aus einem Adressdatensatz.
   * Falls die Nummer nicht ermittelt werden kann wird ein leerer String geliefert, andernfalls beginnt die Nummer mit
   * einem Pluszeichen, gefolgt von Ziffern.
   *
   * @param array  $addressData Adressdaten
   * @param string $field       Feld in dem die Telefonnummer steht ('Phone', 'Fax', 'ShortMessage')
   * @return string
   */
  public static function getPhoneNumber($addressData, $field = 'Phone')
  {
    if(!is_array($addressData) || !isset($addressData[$field]))
      return '';

    $number = $addressData[$field];
    $prefix = '';

    if(isset($addressData['Letter.CountryInfo.ISO2']) && $addressData['Letter.CountryInfo.ISO2'])
    {
      $country = self::getCountryData($addressData['Letter.CountryInfo.ISO2']);

      if(is_array($country) && isset($country['phone']) && $country['phone'])
        $prefix = $country['phone'];
    }

    $number = self::fixPhoneNumber($number, $prefix);

    if(GhCoreStrings::startsWith($number, '+'))
      return $number;
    else
      return '';
  }

  /**
   * Liefert eine Datums-/Zeitangabe.
   * Die Funktion nimmt den selben Formatstring wie die date() Funktion von PHP, jedoch können die Wochentage und
   * Monate hier in der ausgewählten Sprache geliefert werden.
   *
   * @param string $format    Formatstring
   * @param int    $timestamp Zeitstempel
   * @param string $language  Sprache ('de', 'en', 'es', 'fr')
   * @return string
   */
  public static function date($format, $timestamp = null, $language = 'de')
  {
    $result = '';

    if($timestamp === null)
      $timestamp = time();

    for($pos = 0; $pos < strlen($format); $pos++)
    {
      $formatChar = $format[$pos];

      switch($formatChar)
      {
        case 'D':
          $result .= substr(self::$_days[(int)date('N', $timestamp)][$language], 0, 3);
          break;

        case 'l':
          $result .= self::$_days[(int)date('N', $timestamp)][$language];
          break;

        case 'M':
          $result .= substr(self::$_months[(int)date('n', $timestamp)][$language], 0, 3);
          break;

        case 'F':
          $result .= self::$_months[(int)date('n', $timestamp)][$language];
          break;

        default:
          $result .= date($formatChar, $timestamp);
          break;
      }
    }

    return $result;
  }
}