<?php
/*
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2021 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

/**
 * Beschriftungs-Komponente.
 *
 * @package GhGui
 * @subpackage component
 * @category PHP-GUI-Einzelkomponenten
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhGuiLabel extends GhGuiComponent
{
  /**
   * Name/Typ des HTML-Knotens der für diese Komponente erzeugt wird.
   * @var string
   */
  protected $_htmlTag = 'label';

  /**
   * Widget Klassenname dieser Komponente.
   * @var string
   */
  protected $_widgetClass = 'greyhound.dojo.Label';

  /**
   * CSS Klassen für den Haupt-DOM-Knoten dieser Komponente.
   * @var array
   */
  protected $_classes = array('GhGuiLabel');

  /**
   * Beschriftung.
   * @var string
   */
  protected $_caption;

  /**
   * Zielkomponente oder ID der Zielkomponente.
   * @var string
   */
  protected $_target;

  /**
   * Konstruktor.
   *
   * Optional kann die Beschriftung und die Zielkomponente (oder deren ID)
   * angegeben werden.
   *
   * @param string                $caption Beschriftung
   * @param GhGuiComponent|string $target  Zielkomponente oder ID der Zielkomponenten
   */
  public function __construct($caption = null, $target = null)
  {
    parent::__construct();

    if($caption !== null)
      $this->setCaption($caption);
    if($target !== null)
      $this->setTarget($target);
  }

  /**
   * Setzt die Beschriftung.
   *
   * @param string $caption Beschriftung
   * @return GhGuiLabel liefert die Komponente zurück um verkettete Aufrufe zu ermöglichen
   */
  public function setCaption($caption)
  {
    $this->_caption = $caption;

    return $this;
  }

  /**
   * Liefert die Beschriftung.
   *
   * @return string
   */
  public function getCaption()
  {
    return $this->_caption;
  }

  /**
   * Setzt die Zielkomponente (oder deren ID) für die Beschriftung.
   *
   * @param GhGuiComponent|string $target Zielkomponente oder ID der Zielkomponenten
   * @return GhGuiLabel liefert die Komponente zurück um verkettete Aufrufe zu ermöglichen
   */
  public function setTarget($target)
  {
    $this->_target = $target;

    return $this;
  }

  /**
   * Liefert die Zielkomponente oder deren ID.
   *
   * @return GhGuiComponent|string
   */
  public function getTarget()
  {
    return $this->_target;
  }

  /**
   * Liefert den HTML Code für diese Komponente.
   *
   * @return string
   */
  protected function _getHtml()
  {
    $attributes = $this->_getAllAttributes();

    if ($this->_target instanceof GhGuiComponent)
      $attributes['for'] = $this->_target->getId();
    else
      $attributes['for'] = $this->_target;

    return GhGui::createHtml('label', $attributes, $this->getCaption());
  }
}
