<?php
/*
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2021 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

/**
 * Zahleneingabe (mit Buttons zum Hoch- und Runterzählen).
 * 
 * @package GhGui
 * @subpackage component
 * @category PHP-GUI-Einzelkomponenten
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhGuiNumberSpinner extends GhGuiFormComponent
{
  /**
   * Name/Typ des HTML-Knotens der für diese Komponente erzeugt wird.
   * @var string
   */
  protected $_htmlTag = 'input';

  /**
   * Attribute für den Haupt-DOM-Knoten dieser Komponente.
   * @var array
   */
  protected $_attributes = array('type' => 'text');

  /**
   * Widget Klassenname dieser Komponente.
   * @var string
   */
  protected $_widgetClass = 'dijit.form.NumberSpinner';

  /**
   * Events, die ein automatisches Absenden des Formulars auslösen.
   * @var array
   */
  protected $_autoSubmitEvents = array('onChange');

  /**
   * Konstruktor.
   *
   * Optional kann der Name des Eingabefeldes (siehe setName()) und der
   * Vorgabewert (siehe setDefaultValue()) festgelegt werden.
   *
   * @param string  $name         Name des Formularfeldes
   * @param string  $defaultValue Vorgabewert für das Formularfeld
   */
  public function __construct($name = null, $defaultValue = null)
  {
    parent::__construct($name, null, $defaultValue);
  }

  /**
   * Initialisiert die Komponente für das Abrufen des HTML-Codes.
   */
  protected function _initHtml()
  {
    if(!parent::_initHtml())
      return false;

    $value = $this->getCurrentValue();
    $this->setWidgetProperty('value', (int)$value);

    return true;
  }
}
