<?php
/*
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2021 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

/**
 * Event-Handler Basisklasse.
 *
 * @package GhGui
 * @subpackage core
 * @category PHP-GUI-Kernklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
abstract class GhGuiEvent
{
  /**
   * Konstante für das 'onBlur' Javascript Event.
   * @var const
   */
  const EVENT_BLUR = 'onBlur';

  /**
   * Konstante für das 'onChange' Javascript Event.
   * @var const
   */
  const EVENT_CHANGE = 'onChange';

  /**
   * Konstante für das 'onClick' Javascript Event.
   * @var const
   */
  const EVENT_CLICK = 'onClick';

  /**
   * Konstante für das 'onClose' Javascript Event.
   * @var const
   */
  const EVENT_CLOSE = 'onClose';

  /**
   * Konstante für das 'onDeselected' Javascript Event.
   * @var const
   */
  const EVENT_DESELECTED = 'onDeselected';

  /**
   * Konstante für das 'onDblClick' Javascript Event.
   * @var const
   */
  const EVENT_DOUBLE_CLICK = 'onDblClick';

  /**
   * Konstante für das 'onFocus' Javascript Event.
   * @var const
   */
  const EVENT_FOCUS = 'onFocus';

  /**
   * Konstante für das 'onHide' Javascript Event.
   * @var const
   */
  const EVENT_HIDE = 'onHide';

  /**
   * Konstante für das 'onKeyDown' Javascript Event.
   * @var const
   */
  const EVENT_KEY_DOWN = 'onKeyDown';

  /**
   * Konstante für das 'onKeyPress' Javascript Event.
   * @var const
   */
  const EVENT_KEY_PRESS = 'onKeyPress';

  /**
   * Konstante für das 'onKeyUp' Javascript Event.
   * @var const
   */
  const EVENT_KEY_UP = 'onKeyUp';

  /**
   * Konstante für das 'onMouseDown' Javascript Event.
   * @var const
   */
  const EVENT_MOUSE_DOWN = 'onMouseDown';

  /**
   * Konstante für das 'onMouseEnter' Javascript Event.
   * @var const
   */
  const EVENT_MOUSE_ENTER = 'onMouseEnter';

  /**
   * Konstante für das 'onMouseLeave' Javascript Event.
   * @var const
   */
  const EVENT_MOUSE_LEAVE = 'onMouseLeave';

  /**
   * Konstante für das 'onMouseMove' Javascript Event.
   * @var const
   */
  const EVENT_MOUSE_MOVE = 'onMouseMove';

  /**
   * Konstante für das 'onMouseOut' Javascript Event.
   * @var const
   */
  const EVENT_MOUSE_OUT = 'onMouseOut';

  /**
   * Konstante für das 'onMouseOver' Javascript Event.
   * @var const
   */
  const EVENT_MOUSE_OVER = 'onMouseOver';

  /**
   * Konstante für das 'onMouseUp' Javascript Event.
   * @var const
   */
  const EVENT_MOUSE_UP = 'onMouseUp';

  /**
   * Konstante für das 'onReset' Javascript Event.
   * Dieses tritt auf, wenn die Werte eines Formulars zurückgesetzt werden.
   * @var const
   */
  const EVENT_RESET = 'onReset';

  /**
   * Konstante für das 'onSelected' Javascript Event.
   * @var const
   */
  const EVENT_SELECTED = 'onSelected';

  /**
   * Konstante für das 'onSelectionChanged' Javascript Event.
   * @var const
   */
  const EVENT_SELECTION_CHANGED = 'onSelectionChanged';

  /**
   * Konstante für das 'onShow' Javascript Event.
   * @var const
   */
  const EVENT_SHOW = 'onShow';

  /**
   * Konstante für das 'onSubmit' Javascript Event.
   * Dieses tritt auf, wenn ein Formular abgesendet wird.
   * @var const
   */
  const EVENT_SUBMIT = 'onSubmit';

  /**
   * Konstante für Tastenkombinationen (Alt Taste).
   * @var const
   */
  const MODIFIER_ALT = 2;

  /**
   * Konstante für Tastenkombinationen (Alt-Graph Taste).
   * @var const
   */
  const MODIFIER_ALT_GRAPH = 4;

  /**
   * Konstante für Tastenkombinationen (Strg Taste).
   * @var const
   */
  const MODIFIER_CTRL = 8;

  /**
   * Konstante für Tastenkombinationen (Meta Taste, browser-/systemabhängig).
   * @var const
   */
  const MODIFIER_META = 16;

  /**
   * Konstante für Tastenkombinationen (Umschalt/Shift Taste).
   * @var const
   */
  const MODIFIER_SHIFT = 32;

  /**
   * Konstante für Sondertasten (Alt Taste).
   * @var const
   */
  const KEY_ALT = 'dojo.keys.ALT';

  /**
   * Konstante für Sondertasten (Backspace/Löschen Taste).
   * @var const
   */
  const KEY_BACKSPACE = 'dojo.keys.BACKSPACE';

  /**
   * Konstante für Sondertasten (Umschalt-Feststellen Taste).
   * @var const
   */
  const KEY_CAPS_LOCK = 'dojo.keys.CAPS_LOCK';

  /**
   * Konstante für Sondertasten (Clear Taste).
   * @var const
   */
  const KEY_CLEAR = 'dojo.keys.CLEAR';

  /**
   * Konstante für Sondertasten (Strg Taste).
   * @var const
   */
  const KEY_CTRL = 'dojo.keys.CTRL';

  /**
   * Konstante für Sondertasten (Entfernen Taste).
   * @var const
   */
  const KEY_DELETE = 'dojo.keys.DELETE';

  /**
   * Konstante für Sondertasten (Cursor-unten Taste).
   * @var const
   */
  const KEY_DOWN_ARROW = 'dojo.keys.DOWN_ARROW';

  /**
   * Konstante für Sondertasten (Ende Taste).
   * @var const
   */
  const KEY_END = 'dojo.keys.END';

  /**
   * Konstante für Sondertasten (Enter Taste).
   * @var const
   */
  const KEY_ENTER = 'dojo.keys.ENTER';

  /**
   * Konstante für Sondertasten (Escape Taste).
   * @var const
   */
  const KEY_ESCAPE = 'dojo.keys.ESCAPE';

  /**
   * Konstante für Sondertasten (F1 Taste).
   * @var const
   */
  const KEY_F1 = 'dojo.keys.F1';

  /**
   * Konstante für Sondertasten (F2 Taste).
   * @var const
   */
  const KEY_F2 = 'dojo.keys.F2';

  /**
   * Konstante für Sondertasten (F3 Taste).
   * @var const
   */
  const KEY_F3 = 'dojo.keys.F3';

  /**
   * Konstante für Sondertasten (F4 Taste).
   * @var const
   */
  const KEY_F4 = 'dojo.keys.F4';

  /**
   * Konstante für Sondertasten (F5 Taste).
   * @var const
   */
  const KEY_F5 = 'dojo.keys.F5';

  /**
   * Konstante für Sondertasten (F6 Taste).
   * @var const
   */
  const KEY_F6 = 'dojo.keys.F6';

  /**
   * Konstante für Sondertasten (F7 Taste).
   * @var const
   */
  const KEY_F7 = 'dojo.keys.F7';

  /**
   * Konstante für Sondertasten (F8 Taste).
   * @var const
   */
  const KEY_F8 = 'dojo.keys.F8';

  /**
   * Konstante für Sondertasten (F9 Taste).
   * @var const
   */
  const KEY_F9 = 'dojo.keys.F9';

  /**
   * Konstante für Sondertasten (F10 Taste).
   * @var const
   */
  const KEY_F10 = 'dojo.keys.F10';

  /**
   * Konstante für Sondertasten (F11 Taste).
   * @var const
   */
  const KEY_F11 = 'dojo.keys.F11';

  /**
   * Konstante für Sondertasten (F12 Taste).
   * @var const
   */
  const KEY_F12 = 'dojo.keys.F12';

  /**
   * Konstante für Sondertasten (F13 Taste).
   * @var const
   */
  const KEY_F13 = 'dojo.keys.F13';

  /**
   * Konstante für Sondertasten (F14 Taste).
   * @var const
   */
  const KEY_F14 = 'dojo.keys.F14';

  /**
   * Konstante für Sondertasten (F15 Taste).
   * @var const
   */
  const KEY_F15 = 'dojo.keys.F15';

  /**
   * Konstante für Sondertasten (Hilfe Taste).
   * @var const
   */
  const KEY_HELP = 'dojo.keys.HELP';

  /**
   * Konstante für Sondertasten (Pos1 Taste).
   * @var const
   */
  const KEY_HOME = 'dojo.keys.HOME';

  /**
   * Konstante für Sondertasten (Einfügen Taste).
   * @var const
   */
  const KEY_INSERT = 'dojo.keys.INSERT';

  /**
   * Konstante für Sondertasten (Cursor-links Taste).
   * @var const
   */
  const KEY_LEFT_ARROW = 'dojo.keys.LEFT_ARROW';

  /**
   * Konstante für Sondertasten (linke Windows Taste).
   * @var const
   */
  const KEY_LEFT_WINDOW = 'dojo.keys.LEFT_WINDOW';

  /**
   * Konstante für Sondertasten (Meta Taste, browser-/systemabhängig).
   * @var const
   */
  const KEY_META = 'dojo.keys.META';

  /**
   * Konstante für Sondertasten (Nummernblock Taste 0).
   * @var const
   */
  const KEY_NUMPAD_0 = 'dojo.keys.NUMPAD_0';

  /**
   * Konstante für Sondertasten (Nummernblock Taste 1).
   * @var const
   */
  const KEY_NUMPAD_1 = 'dojo.keys.NUMPAD_1';

  /**
   * Konstante für Sondertasten (Nummernblock Taste 2).
   * @var const
   */
  const KEY_NUMPAD_2 = 'dojo.keys.NUMPAD_2';

  /**
   * Konstante für Sondertasten (Nummernblock Taste 3).
   * @var const
   */
  const KEY_NUMPAD_3 = 'dojo.keys.NUMPAD_3';

  /**
   * Konstante für Sondertasten (Nummernblock Taste 4).
   * @var const
   */
  const KEY_NUMPAD_4 = 'dojo.keys.NUMPAD_4';

  /**
   * Konstante für Sondertasten (Nummernblock Taste 5).
   * @var const
   */
  const KEY_NUMPAD_5 = 'dojo.keys.NUMPAD_5';

  /**
   * Konstante für Sondertasten (Nummernblock Taste 6).
   * @var const
   */
  const KEY_NUMPAD_6 = 'dojo.keys.NUMPAD_6';

  /**
   * Konstante für Sondertasten (Nummernblock Taste 7).
   * @var const
   */
  const KEY_NUMPAD_7 = 'dojo.keys.NUMPAD_7';

  /**
   * Konstante für Sondertasten (Nummernblock Taste 8).
   * @var const
   */
  const KEY_NUMPAD_8 = 'dojo.keys.NUMPAD_8';

  /**
   * Konstante für Sondertasten (Nummernblock Taste 9).
   * @var const
   */
  const KEY_NUMPAD_9 = 'dojo.keys.NUMPAD_9';

  /**
   * Konstante für Sondertasten (Nummernblock Taste Division).
   * @var const
   */
  const KEY_NUMPAD_DIVIDE = 'dojo.keys.NUMPAD_DIVIDE';

  /**
   * Konstante für Sondertasten (Nummernblock Taste Enter).
   * @var const
   */
  const KEY_NUMPAD_ENTER = 'dojo.keys.NUMPAD_ENTER';

  /**
   * Konstante für Sondertasten (Nummernblock Taste Minus).
   * @var const
   */
  const KEY_NUMPAD_MINUS = 'dojo.keys.NUMPAD_MINUS';

  /**
   * Konstante für Sondertasten (Nummernblock Taste Multiplikation).
   * @var const
   */
  const KEY_NUMPAD_MULTIPLY = 'dojo.keys.NUMPAD_MULTIPLY';

  /**
   * Konstante für Sondertasten (Nummernblock Taste Punkt).
   * @var const
   */
  const KEY_NUMPAD_PERIOD = 'dojo.keys.NUMPAD_PERIOD';

  /**
   * Konstante für Sondertasten (Nummernblock Taste Plus).
   * @var const
   */
  const KEY_NUMPAD_PLUS = 'dojo.keys.NUMPAD_PLUS';

  /**
   * Konstante für Sondertasten (Num-Lock Taste).
   * @var const
   */
  const KEY_NUM_LOCK = 'dojo.keys.NUM_LOCK';

  /**
   * Konstante für Sondertasten (Seite-hinunter Taste).
   * @var const
   */
  const KEY_PAGE_DOWN = 'dojo.keys.PAGE_DOWN';

  /**
   * Konstante für Sondertasten (Seite-hoch Taste).
   * @var const
   */
  const KEY_PAGE_UP = 'dojo.keys.PAGE_UP';

  /**
   * Konstante für Sondertasten (Pause Taste).
   * @var const
   */
  const KEY_PAUSE = 'dojo.keys.PAUSE';

  /**
   * Konstante für Sondertasten (Cursor-rechts Taste).
   * @var const
   */
  const KEY_RIGHT_ARROW = 'dojo.keys.RIGHT_ARROW';

  /**
   * Konstante für Sondertasten (rechte Windows Taste).
   * @var const
   */
  const KEY_RIGHT_WINDOW = 'dojo.keys.RIGHT_WINDOW';

  /**
   * Konstante für Sondertasten (Rollen/Scroll-Lock Taste).
   * @var const
   */
  const KEY_SCROLL_LOCK = 'dojo.keys.SCROLL_LOCK';

  /**
   * Konstante für Sondertasten (Select Taste).
   * @var const
   */
  const KEY_SELECT = 'dojo.keys.SELECT';

  /**
   * Konstante für Sondertasten (Umschalt Taste).
   * @var const
   */
  const KEY_SHIFT = 'dojo.keys.SHIFT';

  /**
   * Konstante für Sondertasten (Leertaste).
   * @var const
   */
  const KEY_SPACE = 'dojo.keys.SPACE';

  /**
   * Konstante für Sondertasten (Tabulator Taste).
   * @var const
   */
  const KEY_TAB = 'dojo.keys.TAB';

  /**
   * Konstante für Sondertasten (Cursor-hoch Taste).
   * @var const
   */
  const KEY_UP_ARROW = 'dojo.keys.UP_ARROW';

  /**
   * Konstruktor.
   */
  public function __construct()
  {
  }

  /**
   * Liefert den Javascript Code zum Registrieren dieses Event-Handlers.
   *
   * @param GhGuiComponent $source Komponente, auf der das Event registriert werden soll
   * @param string         $event  Event-Name
   * @return string
   */
  public function getJavascript(GhGuiComponent $source, $event)
  {
    return 'dojo.connect(' . $source->getJavascriptWidgetVariable() . ',"' . GhCoreStrings::attributeValue($event) . '",' . $this->getJavascriptFunction($source, $event) . ');' . GhGui::$eol;
  }

  /**
   * Liefert den Javascript Code für die Event-Handler Javascript-Funktion.
   *
   * Diese Methode muss von abgeleiteten Klassen implementiert werden und einen
   * String der Form 'function(event){...}' zurück liefern.
   *
   * @param GhGuiComponent $source Komponente, auf der das Event registriert werden soll
   * @param string         $event  Event-Name
   * @return string
   */
  abstract public function getJavascriptFunction(GhGuiComponent $source, $event);
}