<?php
/*
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2021 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

/**
 * Formatierer für Beträge in Währungen.
 * 
 * @package GhGui
 * @subpackage formatter
 * @category PHP-GUI-Formatierer
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhGuiFormatterCurrency extends GhGuiFormatter
{
  /**
   * Anzahl der Dezimalstellen hinter dem Komma.
   * @var int
   */
  protected $_decimals = 2;

  /**
   * Dezimalzeichen.
   * @var string
   */
  protected $_decimalDelimiter = ',';

  /**
   * Text vor dem Betrag.
   * @var string
   */
  protected $_prefix = '';

  /**
   * Text nach dem Betrag.
   * @var string
   */
  protected $_suffix = '';

  /**
   * Konstruktor.
   *
   * @param int    $decimals         Dezimalstellen (Voreinstellung: 2)
   * @param string $decimalDelimiter Dezimalzeichen (Voreinstellung: Komma)
   * @param string $prefix           Text vor dem Betrag (Voreinstellung: leer)
   * @param string $suffix           Text hinter dem Betrag (Voreinstellung: leer)
   */
  public function __construct($decimals = null, $decimalDelimiter = null, $prefix = null, $suffix = null)
  {
    parent::__construct();

    if($decimals !== null)
      $this->_decimals = $decimals;

    if($decimalDelimiter !== null)
      $this->_decimalDelimiter = $decimalDelimiter;

    if($prefix !== null)
      $this->_prefix = $prefix;

    if($suffix !== null)
      $this->_suffix = $suffix;
  }

  /**
   * Liefert den Javascript Code zum Registrieren dieses Formatierers.
   *
   * @param GhGuiComponent $source Komponente, auf der der Formatierer registriert werden soll
   * @return string
   */
  public function getJavascript(GhGuiComponent $source)
  {
    $factor = pow(10, $this->_decimals);

    $javascript = 'function(data){return "' . $this->_prefix . '"+Number(Math.round(data*' . $factor . ')/' . $factor . ').toFixed(' . $this->_decimals . ').replace(/\./g,"' . $this->_decimalDelimiter . '")+"' . $this->_suffix . '";}';

    return $javascript;
  }
}