<?php
/*
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2021 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

/**
 * Formatierer für Icons.
 * 
 * @package GhGui
 * @subpackage formatter
 * @category PHP-GUI-Formatierer
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhGuiFormatterIcon extends GhGuiFormatter
{
  /**
   * Zuordnung von Werten auf Icon-Namen.
   * @var array
   */
  protected $_iconMapping;

  /**
   * Icon für Datenwerte, die nicht in der Zuordnungsliste enthalten sind.
   * @var string
   */
  protected $_defaultIcon = '';

  /**
   * Konstruktor.
   *
   * Optional kann eine Zuordnungsliste von Datenwerten auf Icon-Namen
   * angegeben werden. Wird keine Zuordnungsliste angegeben, so müssen die
   * Daten den Namen des Icons enthalten.
   *
   * Da die Zuordnung anhand der Liste zur Laufzeit in Javascript vorgenommen
   * wird, sollten bei umfangreicheren Zuordnungen besser die Icon-Namen vorher
   * in die Daten geschrieben werden und dann auf eine Zuordnungsliste
   * verzichtet werden.
   *
   * @param array  $mapping     Zuordnung von Datenwerten auf Icon-Namen
   * @param string $defaultIcon Icon für Datenwerte die nicht in der
   *   Zuordnungsliste enthalten sind
   */
  public function __construct(array $mapping = null, $defaultIcon = null)
  {
    parent::__construct();

    if($mapping !== null)
      $this->_iconMapping = $mapping;

    if($defaultIcon !== null)
      $this->_defaultIcon = $defaultIcon;
  }

  /**
   * Liefert den Javascript Code zum Registrieren dieses Formatierers.
   *
   * @param GhGuiComponent $source Komponente, auf der der Formatierer registriert werden soll
   * @return string
   */
  public function getJavascript(GhGuiComponent $source)
  {
    $iconSet = $source->getIconSet(true);
    $iconSetClass = null;

    if($iconSet)
      $iconSetClass = $iconSet->getIconSetClass();

    if(!$iconSetClass)
      return 'function(data){return "";}';

    if(is_array($this->_iconMapping))
    {
      $mapping = array();

      foreach($this->_iconMapping as $value => $icon)
        $mapping[] = GhCoreStrings::jsonProperty($value, $icon, 'string');

      return 'function(data){var mapping={' . implode(',', $mapping) . '};var icon=mapping[data];if(!icon)icon="' . $this->_defaultIcon . '";return "<img src=\""+greyhound.baseUrl+"lib/dojo/resources/blank.gif\" class=\"' . $iconSetClass . ' "+icon+"\"></img>"}';
    }
    else
      return 'function(data){return "<img src=\""+greyhound.baseUrl+"lib/dojo/resources/blank.gif\" class=\"' . $iconSetClass . ' "+data+"\"></img>";}';
  }
}