<?php
/*
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2021 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

/**
 * RPC Hilfsklasse.
 *
 * @package GhRpc
 * @category PHP-RPC-Kernklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpc
{
  /**
   * Autoload-Verzeichnisse.
   * Diese Liste wird beim Erzeugen der Klasse automatisch befüllt und kann
   * über die Methode addAutoLoadPath() ergänzt werden, um eigene Verzeichnisse
   * zum Autoloader hinzuzufügen.
   * @var array
   */
  static protected $_autoLoadPaths = array();

  /**
   * Autoload-Funktion für Klassen.
   *
   * @param string $class Klassenname
   */
  static public function autoLoadClass($class)
  {
    $file = strtolower($class) . '.php';
    foreach(self::$_autoLoadPaths as $path)
    {
      $filePath = $path . '/' . $file;
      if(file_exists($filePath))
      {
        require_once $filePath;
        return;
      }
    }
  }

  /**
   * Fügt einen Pfad zum Autoloader hinzu.
   *
   * @throws GhRpcException falls der übergebene Pfad nicht existiert
   *
   * @param string $path Verzeichnispfad für den Autoloader
   */
  static public function addAutoLoadPath($path)
  {
    if(!file_exists($path))
      throw new GhRpcException('The autoload path "' . $path . '" does not exist');

    self::$_autoLoadPaths[] = rtrim($path, '/\\') . '/';
  }
}

// Initialisierung:
$ghRpcBaseDir = realpath(dirname(__FILE__)) . '/';
GhRpc::addAutoLoadPath($ghRpcBaseDir . 'core');
GhRpc::addAutoLoadPath($ghRpcBaseDir . 'exception');
GhRpc::addAutoLoadPath(dirname( $ghRpcBaseDir ) . '/ghcore');
GhRpc::addAutoLoadPath($ghRpcBaseDir . 'rpc');

// Registriert die Autoload-Funktion des GhRpc-Singletons:
spl_autoload_register(array('GhRpc', 'autoLoadClass'));
