<?php
/**
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2021 GREYHOUND Software GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */


/**
 * RPC-Unit rpc_chatslib.
 *
 * @package GhRpc
 * @subpackage rpc_chatslib
 * @category PHP-RPC-Units
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class rpc_chatslib extends GhRpcLibrary
{
  // RpcChatOrderBy Konstanten:

  /**
   * cobName Konstante (gehört zum Enum: RpcChatOrderBy).
   */
  const cobName = 0;
  /**
   * cobMessageCount Konstante (gehört zum Enum: RpcChatOrderBy).
   */
  const cobMessageCount = 1;
  /**
   * cobCreated Konstante (gehört zum Enum: RpcChatOrderBy).
   */
  const cobCreated = 2;
  /**
   * cobModified Konstante (gehört zum Enum: RpcChatOrderBy).
   */
  const cobModified = 3;
  /**
   * cobLastMessage Konstante (gehört zum Enum: RpcChatOrderBy).
   */
  const cobLastMessage = 4;

  // RpcChatOrderDirection Konstanten:

  /**
   * codAscending Konstante (gehört zum Enum: RpcChatOrderDirection).
   */
  const codAscending = 0;
  /**
   * codDescending Konstante (gehört zum Enum: RpcChatOrderDirection).
   */
  const codDescending = 1;

  // RpcLockState Konstanten:

  /**
   * lsUnlocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsUnlocked = 0;
  /**
   * lsModified Konstante (gehört zum Enum: RpcLockState).
   */
  const lsModified = 1;
  /**
   * lsLocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsLocked = 2;

  /**
   * Hilfskonstante, die ein Set darstellt, in dem alle Enums gesetzt sind.
   * @var int
   */
  const SET_ALL = -1;


  /**
   * Erzeugt eine Instanz des RPC-Dienstes RpcChats.
   *
   * @param GhRpcClient $client Client Instanz
   *
   * @return GhRpcChatslibRpcChats
   */
  public static function newRpcChats(GhRpcClient $client)
  {
    return new GhRpcChatslibRpcChats($client);
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcLockDataItem.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcChatslibRpcLockDataItem
   */
  public static function newRpcLockDataItem($fillProperties = false)
  {
    $object = new GhRpcChatslibRpcLockDataItem();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcChatNew.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcChatslibRpcChatNew
   */
  public static function newRpcChatNew($fillProperties = false)
  {
    $object = new GhRpcChatslibRpcChatNew();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcChatExternal.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcChatslibRpcChatExternal
   */
  public static function newRpcChatExternal($fillProperties = false)
  {
    $object = new GhRpcChatslibRpcChatExternal();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcChatUser.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcChatslibRpcChatUser
   */
  public static function newRpcChatUser($fillProperties = false)
  {
    $object = new GhRpcChatslibRpcChatUser();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcLockData.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcChatslibRpcLockData
   */
  public static function newRpcLockData($fillProperties = false)
  {
    $object = new GhRpcChatslibRpcLockData();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcChatMessage.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcChatslibRpcChatMessage
   */
  public static function newRpcChatMessage($fillProperties = false)
  {
    $object = new GhRpcChatslibRpcChatMessage();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcChat.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcChatslibRpcChat
   */
  public static function newRpcChat($fillProperties = false)
  {
    $object = new GhRpcChatslibRpcChat();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }
}


/**
 * RPC-Struct RpcChatNewList.
 *
 * @package GhRpc
 * @subpackage rpc_chatslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcChatslibRpcChat extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * Users
   * @var array
   */
  public $Users;

  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * MessageCount
   * @var int
   */
  public $MessageCount;

  /**
   * Pending
   * @var int
   */
  public $Pending;

  /**
   * LockData
   * @var GhRpcChatslibRpcLockData
   */
  public $LockData;

  /**
   * Created
   * @var GhRpcDateTime
   */
  public $Created;

  /**
   * Modified
   * @var GhRpcDateTime
   */
  public $Modified;

  /**
   * LastMessage
   * @var GhRpcDateTime
   */
  public $LastMessage;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'Users' => 'array:GhRpcChatslibRpcChatUser',
    'Name' => 'string',
    'MessageCount' => 'int',
    'Pending' => 'int',
    'LockData' => 'GhRpcChatslibRpcLockData',
    'Created' => 'GhRpcDateTime',
    'Modified' => 'GhRpcDateTime',
    'LastMessage' => 'GhRpcDateTime',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcChatNewList.
 *
 * @package GhRpc
 * @subpackage rpc_chatslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcChatslibRpcChatMessage extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * UserRef
   * @var int
   */
  public $UserRef;

  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * Data
   * @var string
   */
  public $Data;

  /**
   * Created
   * @var GhRpcDateTime
   */
  public $Created;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'UserRef' => 'int',
    'Name' => 'string',
    'Data' => 'string',
    'Created' => 'GhRpcDateTime',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcChatNewList.
 *
 * @package GhRpc
 * @subpackage rpc_chatslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcChatslibRpcLockData extends GhRpcStruct
{
  /**
   * LockState
   * @var int
   */
  public $LockState;

  /**
   * UserRef
   * @var int
   */
  public $UserRef;

  /**
   * UserName
   * @var string
   */
  public $UserName;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'LockState' => 'int',
    'UserRef' => 'int',
    'UserName' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcChatNewList.
 *
 * @package GhRpc
 * @subpackage rpc_chatslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcChatslibRpcChatUser extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * Online
   * @var boolean
   */
  public $Online;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'Name' => 'string',
    'Online' => 'boolean',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcChatNewList.
 *
 * @package GhRpc
 * @subpackage rpc_chatslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcChatslibRpcChatExternal extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * UserRef
   * @var int
   */
  public $UserRef;

  /**
   * UniqueID
   * @var string
   */
  public $UniqueID;

  /**
   * Url
   * @var string
   */
  public $Url;

  /**
   * CustomName
   * @var string
   */
  public $CustomName;

  /**
   * Created
   * @var GhRpcDateTime
   */
  public $Created;

  /**
   * Expires
   * @var GhRpcDateTime
   */
  public $Expires;

  /**
   * Online
   * @var boolean
   */
  public $Online;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'UserRef' => 'int',
    'UniqueID' => 'string',
    'Url' => 'string',
    'CustomName' => 'string',
    'Created' => 'GhRpcDateTime',
    'Expires' => 'GhRpcDateTime',
    'Online' => 'boolean',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcChatNewList.
 *
 * @package GhRpc
 * @subpackage rpc_chatslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcChatslibRpcChatNew extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * Pending
   * @var int
   */
  public $Pending;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'Pending' => 'int',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcChatNewList.
 *
 * @package GhRpc
 * @subpackage rpc_chatslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcChatslibRpcLockDataItem extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * LockState
   * @var int
   */
  public $LockState;

  /**
   * UserRef
   * @var int
   */
  public $UserRef;

  /**
   * UserName
   * @var string
   */
  public $UserName;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'LockState' => 'int',
    'UserRef' => 'int',
    'UserName' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Dienst RpcChats
 *
 * @package GhRpc
 * @subpackage rpc_chatslib
 * @category PHP-RPC-Dienste
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcChatslibRpcChats extends GhRpcService
{
  /**
   * RPC-Methoden mit Parametern und Ergebnistypen.
   * @var array
   */
  protected static $_rpcMethods = array(
    'GetLockDataList' => array(
      'params' => array(
        'IDs' => 'array:int',
      ),
      'return' => 'array:GhRpcChatslibRpcLockDataItem',
    ),
    'GetLockData' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcChatslibRpcLockData',
    ),
    'UnlockList' => array(
      'params' => array(
        'IDs' => 'array:int',
      ),
      'return' => '',
    ),
    'Unlock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'LockList' => array(
      'params' => array(
        'IDs' => 'array:int',
      ),
      'return' => '',
    ),
    'Lock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'DeleteListUser' => array(
      'params' => array(
        'IDs' => 'array:int',
        'UserRef' => 'int',
      ),
      'return' => '',
    ),
    'DeleteUser' => array(
      'params' => array(
        'ID' => 'int',
        'UserRef' => 'int',
      ),
      'return' => '',
    ),
    'AddUser' => array(
      'params' => array(
        'ID' => 'int',
        'UserRef' => 'int',
      ),
      'return' => '',
    ),
    'Put' => array(
      'params' => array(
        'Chat' => 'GhRpcChatslibRpcChat',
      ),
      'return' => '',
    ),
    'NewMessage' => array(
      'params' => array(
        'ID' => 'int',
        'MessageData' => 'string',
      ),
      'return' => '',
    ),
    'New_' => array(
      'params' => array(
        'Chat' => 'GhRpcChatslibRpcChat',
      ),
      'return' => 'int',
    ),
    'ClearPendingMessages' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'GetNewChats' => array(
      'params' => array(
      ),
      'return' => 'array:GhRpcChatslibRpcChatNew',
    ),
    'GetMessageList' => array(
      'params' => array(
        'ID' => 'int',
        'Offset' => 'int',
        'MinID' => 'int',
        'ClearPending' => 'boolean',
      ),
      'return' => 'array:GhRpcChatslibRpcChatMessage',
    ),
    'GetList' => array(
      'params' => array(
        'FilterValue' => 'string',
        'Offset' => 'int',
        'OrderBy' => 'int',
        'OrderDirection' => 'int',
      ),
      'return' => 'array:GhRpcChatslibRpcChat',
    ),
    'Get' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcChatslibRpcChat',
    ),
  );


  /**
   * Ruft die RPC-Funktion RpcChats.Get auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcChatslibRpcChat
   */
  public function Get($ID = 0)
  {
    return $this->_sendRpcRequest('RpcChats.Get', array($ID), self::$_rpcMethods['Get']);
  }

  /**
   * Ruft die RPC-Funktion RpcChats.GetList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $FilterValue
   * @param int $Offset
   * @param int $OrderBy
   * @param int $OrderDirection
   *
   * @return array
   */
  public function GetList($FilterValue = '', $Offset = 0, $OrderBy = 0, $OrderDirection = 0)
  {
    return $this->_sendRpcRequest('RpcChats.GetList', array($FilterValue, $Offset, $OrderBy, $OrderDirection), self::$_rpcMethods['GetList']);
  }

  /**
   * Ruft die RPC-Funktion RpcChats.GetMessageList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param int $Offset
   * @param int $MinID
   * @param boolean $ClearPending
   *
   * @return array
   */
  public function GetMessageList($ID = 0, $Offset = 0, $MinID = 0, $ClearPending = false)
  {
    return $this->_sendRpcRequest('RpcChats.GetMessageList', array($ID, $Offset, $MinID, $ClearPending), self::$_rpcMethods['GetMessageList']);
  }

  /**
   * Ruft die RPC-Funktion RpcChats.GetNewChats auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return array
   */
  public function GetNewChats()
  {
    return $this->_sendRpcRequest('RpcChats.GetNewChats', array(), self::$_rpcMethods['GetNewChats']);
  }

  /**
   * Ruft die RPC-Funktion RpcChats.ClearPendingMessages auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function ClearPendingMessages($ID = 0)
  {
    return $this->_sendRpcRequest('RpcChats.ClearPendingMessages', array($ID), self::$_rpcMethods['ClearPendingMessages']);
  }

  /**
   * Ruft die RPC-Funktion RpcChats.New auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcChatslibRpcChat $Chat
   *
   * @return int
   */
  public function New_(GhRpcChatslibRpcChat $Chat = null)
  {
    return $this->_sendRpcRequest('RpcChats.New', array($Chat), self::$_rpcMethods['New_']);
  }

  /**
   * Ruft die RPC-Funktion RpcChats.NewMessage auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param string $MessageData
   */
  public function NewMessage($ID = 0, $MessageData = '')
  {
    return $this->_sendRpcRequest('RpcChats.NewMessage', array($ID, $MessageData), self::$_rpcMethods['NewMessage']);
  }

  /**
   * Ruft die RPC-Funktion RpcChats.Put auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcChatslibRpcChat $Chat
   */
  public function Put(GhRpcChatslibRpcChat $Chat = null)
  {
    return $this->_sendRpcRequest('RpcChats.Put', array($Chat), self::$_rpcMethods['Put']);
  }

  /**
   * Ruft die RPC-Funktion RpcChats.AddUser auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param int $UserRef
   */
  public function AddUser($ID = 0, $UserRef = 0)
  {
    return $this->_sendRpcRequest('RpcChats.AddUser', array($ID, $UserRef), self::$_rpcMethods['AddUser']);
  }

  /**
   * Ruft die RPC-Funktion RpcChats.DeleteUser auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param int $UserRef
   */
  public function DeleteUser($ID = 0, $UserRef = 0)
  {
    return $this->_sendRpcRequest('RpcChats.DeleteUser', array($ID, $UserRef), self::$_rpcMethods['DeleteUser']);
  }

  /**
   * Ruft die RPC-Funktion RpcChats.DeleteListUser auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param array $IDs
   * @param int $UserRef
   */
  public function DeleteListUser(array $IDs = array(), $UserRef = 0)
  {
    return $this->_sendRpcRequest('RpcChats.DeleteListUser', array($IDs, $UserRef), self::$_rpcMethods['DeleteListUser']);
  }

  /**
   * Ruft die RPC-Funktion RpcChats.Lock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Lock($ID = 0)
  {
    return $this->_sendRpcRequest('RpcChats.Lock', array($ID), self::$_rpcMethods['Lock']);
  }

  /**
   * Ruft die RPC-Funktion RpcChats.LockList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param array $IDs
   */
  public function LockList(array $IDs = array())
  {
    return $this->_sendRpcRequest('RpcChats.LockList', array($IDs), self::$_rpcMethods['LockList']);
  }

  /**
   * Ruft die RPC-Funktion RpcChats.Unlock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Unlock($ID = 0)
  {
    return $this->_sendRpcRequest('RpcChats.Unlock', array($ID), self::$_rpcMethods['Unlock']);
  }

  /**
   * Ruft die RPC-Funktion RpcChats.UnlockList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param array $IDs
   */
  public function UnlockList(array $IDs = array())
  {
    return $this->_sendRpcRequest('RpcChats.UnlockList', array($IDs), self::$_rpcMethods['UnlockList']);
  }

  /**
   * Ruft die RPC-Funktion RpcChats.GetLockData auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcChatslibRpcLockData
   */
  public function GetLockData($ID = 0)
  {
    return $this->_sendRpcRequest('RpcChats.GetLockData', array($ID), self::$_rpcMethods['GetLockData']);
  }

  /**
   * Ruft die RPC-Funktion RpcChats.GetLockDataList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param array $IDs
   *
   * @return array
   */
  public function GetLockDataList(array $IDs = array())
  {
    return $this->_sendRpcRequest('RpcChats.GetLockDataList', array($IDs), self::$_rpcMethods['GetLockDataList']);
  }
}
