<?php
/**
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2021 GREYHOUND Software GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */


/**
 * RPC-Unit rpc_checkingslib.
 *
 * @package GhRpc
 * @subpackage rpc_checkingslib
 * @category PHP-RPC-Units
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class rpc_checkingslib extends GhRpcLibrary
{
  // RpcCheckingExportFormat Konstanten:

  /**
   * cefCsv Konstante (gehört zum Enum: RpcCheckingExportFormat).
   */
  const cefCsv = 0;
  /**
   * cefDif Konstante (gehört zum Enum: RpcCheckingExportFormat).
   */
  const cefDif = 1;

  // RpcCheckingValuesKind Konstanten:

  /**
   * cvkAll Konstante (gehört zum Enum: RpcCheckingValuesKind).
   */
  const cvkAll = 0;
  /**
   * cvkSuccess Konstante (gehört zum Enum: RpcCheckingValuesKind).
   */
  const cvkSuccess = 1;
  /**
   * cvkWaiting Konstante (gehört zum Enum: RpcCheckingValuesKind).
   */
  const cvkWaiting = 2;

  // RpcLockState Konstanten:

  /**
   * lsUnlocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsUnlocked = 0;
  /**
   * lsModified Konstante (gehört zum Enum: RpcLockState).
   */
  const lsModified = 1;
  /**
   * lsLocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsLocked = 2;

  /**
   * Hilfskonstante, die ein Set darstellt, in dem alle Enums gesetzt sind.
   * @var int
   */
  const SET_ALL = -1;


  /**
   * Erzeugt eine Instanz des RPC-Dienstes RpcCheckings.
   *
   * @param GhRpcClient $client Client Instanz
   *
   * @return GhRpcCheckingslibRpcCheckings
   */
  public static function newRpcCheckings(GhRpcClient $client)
  {
    return new GhRpcCheckingslibRpcCheckings($client);
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcGenerateValuesResult.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcCheckingslibRpcGenerateValuesResult
   */
  public static function newRpcGenerateValuesResult($fillProperties = false)
  {
    $object = new GhRpcCheckingslibRpcGenerateValuesResult();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcExportOptions.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcCheckingslibRpcExportOptions
   */
  public static function newRpcExportOptions($fillProperties = false)
  {
    $object = new GhRpcCheckingslibRpcExportOptions();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcCheckingsValue.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcCheckingslibRpcCheckingsValue
   */
  public static function newRpcCheckingsValue($fillProperties = false)
  {
    $object = new GhRpcCheckingslibRpcCheckingsValue();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcLockData.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcCheckingslibRpcLockData
   */
  public static function newRpcLockData($fillProperties = false)
  {
    $object = new GhRpcCheckingslibRpcLockData();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcChecking.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcCheckingslibRpcChecking
   */
  public static function newRpcChecking($fillProperties = false)
  {
    $object = new GhRpcCheckingslibRpcChecking();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }
}


/**
 * RPC-Struct RpcCheckingsValueList.
 *
 * @package GhRpc
 * @subpackage rpc_checkingslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcCheckingslibRpcChecking extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * Prefix
   * @var string
   */
  public $Prefix;

  /**
   * CurrentValue
   * @var GhRpcInt64
   */
  public $CurrentValue;

  /**
   * ValueLength
   * @var int
   */
  public $ValueLength;

  /**
   * CheckSumLength
   * @var int
   */
  public $CheckSumLength;

  /**
   * LockData
   * @var GhRpcCheckingslibRpcLockData
   */
  public $LockData;

  /**
   * Created
   * @var GhRpcDateTime
   */
  public $Created;

  /**
   * Modified
   * @var GhRpcDateTime
   */
  public $Modified;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'Name' => 'string',
    'Prefix' => 'string',
    'CurrentValue' => 'GhRpcInt64',
    'ValueLength' => 'int',
    'CheckSumLength' => 'int',
    'LockData' => 'GhRpcCheckingslibRpcLockData',
    'Created' => 'GhRpcDateTime',
    'Modified' => 'GhRpcDateTime',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcCheckingsValueList.
 *
 * @package GhRpc
 * @subpackage rpc_checkingslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcCheckingslibRpcLockData extends GhRpcStruct
{
  /**
   * LockState
   * @var int
   */
  public $LockState;

  /**
   * UserRef
   * @var int
   */
  public $UserRef;

  /**
   * UserName
   * @var string
   */
  public $UserName;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'LockState' => 'int',
    'UserRef' => 'int',
    'UserName' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcCheckingsValueList.
 *
 * @package GhRpc
 * @subpackage rpc_checkingslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcCheckingslibRpcCheckingsValue extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * UserRef
   * @var int
   */
  public $UserRef;

  /**
   * UserName
   * @var string
   */
  public $UserName;

  /**
   * ItemRef
   * @var int
   */
  public $ItemRef;

  /**
   * Value
   * @var string
   */
  public $Value;

  /**
   * Created
   * @var GhRpcDateTime
   */
  public $Created;

  /**
   * Modified
   * @var GhRpcDateTime
   */
  public $Modified;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'UserRef' => 'int',
    'UserName' => 'string',
    'ItemRef' => 'int',
    'Value' => 'string',
    'Created' => 'GhRpcDateTime',
    'Modified' => 'GhRpcDateTime',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcCheckingsValueList.
 *
 * @package GhRpc
 * @subpackage rpc_checkingslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcCheckingslibRpcExportOptions extends GhRpcStruct
{
  /**
   * Format
   * @var int
   */
  public $Format;

  /**
   * OnlyMine
   * @var boolean
   */
  public $OnlyMine;

  /**
   * CsvLineDelimiter
   * @var string
   */
  public $CsvLineDelimiter;

  /**
   * CsvFieldDelimiter
   * @var string
   */
  public $CsvFieldDelimiter;

  /**
   * CsvQuoteChar
   * @var string
   */
  public $CsvQuoteChar;

  /**
   * DifPageWidth
   * @var int
   */
  public $DifPageWidth;

  /**
   * DifPageHeight
   * @var int
   */
  public $DifPageHeight;

  /**
   * DifColumns
   * @var int
   */
  public $DifColumns;

  /**
   * DifRows
   * @var int
   */
  public $DifRows;

  /**
   * DifSkipRowColumns
   * @var int
   */
  public $DifSkipRowColumns;

  /**
   * DifFontName
   * @var string
   */
  public $DifFontName;

  /**
   * DifFontSize
   * @var int
   */
  public $DifFontSize;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'Format' => 'int',
    'OnlyMine' => 'boolean',
    'CsvLineDelimiter' => 'string',
    'CsvFieldDelimiter' => 'string',
    'CsvQuoteChar' => 'string',
    'DifPageWidth' => 'int',
    'DifPageHeight' => 'int',
    'DifColumns' => 'int',
    'DifRows' => 'int',
    'DifSkipRowColumns' => 'int',
    'DifFontName' => 'string',
    'DifFontSize' => 'int',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcCheckingsValueList.
 *
 * @package GhRpc
 * @subpackage rpc_checkingslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcCheckingslibRpcGenerateValuesResult extends GhRpcStruct
{
  /**
   * FirstValue
   * @var string
   */
  public $FirstValue;

  /**
   * LastValue
   * @var string
   */
  public $LastValue;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'FirstValue' => 'string',
    'LastValue' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Dienst RpcCheckings
 *
 * @package GhRpc
 * @subpackage rpc_checkingslib
 * @category PHP-RPC-Dienste
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcCheckingslibRpcCheckings extends GhRpcService
{
  /**
   * RPC-Methoden mit Parametern und Ergebnistypen.
   * @var array
   */
  protected static $_rpcMethods = array(
    'GetLockData' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcCheckingslibRpcLockData',
    ),
    'Unlock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Lock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'PrepareExport' => array(
      'params' => array(
        'ID' => 'int',
        'FirstValue' => 'string',
        'LastValue' => 'string',
        'Options' => 'GhRpcCheckingslibRpcExportOptions',
      ),
      'return' => '',
    ),
    'Delete' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Put' => array(
      'params' => array(
        'ID' => 'int',
        'Name' => 'string',
      ),
      'return' => '',
    ),
    'New_' => array(
      'params' => array(
        'Checking' => 'GhRpcCheckingslibRpcChecking',
      ),
      'return' => 'int',
    ),
    'ValueClearance' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'ValueAssign' => array(
      'params' => array(
        'ValueRef' => 'int',
        'ItemRef' => 'int',
      ),
      'return' => '',
    ),
    'GenerateValues' => array(
      'params' => array(
        'ID' => 'int',
        'Count' => 'int',
      ),
      'return' => 'GhRpcCheckingslibRpcGenerateValuesResult',
    ),
    'GetValueList' => array(
      'params' => array(
        'ID' => 'int',
        'Kind' => 'int',
        'Offset' => 'int',
      ),
      'return' => 'array:GhRpcCheckingslibRpcCheckingsValue',
    ),
    'GetList' => array(
      'params' => array(
      ),
      'return' => 'array:GhRpcCheckingslibRpcChecking',
    ),
    'Get' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcCheckingslibRpcChecking',
    ),
  );


  /**
   * Ruft die RPC-Funktion RpcCheckings.Get auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcCheckingslibRpcChecking
   */
  public function Get($ID = 0)
  {
    return $this->_sendRpcRequest('RpcCheckings.Get', array($ID), self::$_rpcMethods['Get']);
  }

  /**
   * Ruft die RPC-Funktion RpcCheckings.GetList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return array
   */
  public function GetList()
  {
    return $this->_sendRpcRequest('RpcCheckings.GetList', array(), self::$_rpcMethods['GetList']);
  }

  /**
   * Ruft die RPC-Funktion RpcCheckings.GetValueList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param int $Kind
   * @param int $Offset
   *
   * @return array
   */
  public function GetValueList($ID = 0, $Kind = 0, $Offset = 0)
  {
    return $this->_sendRpcRequest('RpcCheckings.GetValueList', array($ID, $Kind, $Offset), self::$_rpcMethods['GetValueList']);
  }

  /**
   * Ruft die RPC-Funktion RpcCheckings.GenerateValues auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param int $Count
   *
   * @return GhRpcCheckingslibRpcGenerateValuesResult
   */
  public function GenerateValues($ID = 0, $Count = 0)
  {
    return $this->_sendRpcRequest('RpcCheckings.GenerateValues', array($ID, $Count), self::$_rpcMethods['GenerateValues']);
  }

  /**
   * Ruft die RPC-Funktion RpcCheckings.ValueAssign auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ValueRef
   * @param int $ItemRef
   */
  public function ValueAssign($ValueRef = 0, $ItemRef = 0)
  {
    return $this->_sendRpcRequest('RpcCheckings.ValueAssign', array($ValueRef, $ItemRef), self::$_rpcMethods['ValueAssign']);
  }

  /**
   * Ruft die RPC-Funktion RpcCheckings.ValueClearance auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function ValueClearance($ID = 0)
  {
    return $this->_sendRpcRequest('RpcCheckings.ValueClearance', array($ID), self::$_rpcMethods['ValueClearance']);
  }

  /**
   * Ruft die RPC-Funktion RpcCheckings.New auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcCheckingslibRpcChecking $Checking
   *
   * @return int
   */
  public function New_(GhRpcCheckingslibRpcChecking $Checking = null)
  {
    return $this->_sendRpcRequest('RpcCheckings.New', array($Checking), self::$_rpcMethods['New_']);
  }

  /**
   * Ruft die RPC-Funktion RpcCheckings.Put auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param string $Name
   */
  public function Put($ID = 0, $Name = '')
  {
    return $this->_sendRpcRequest('RpcCheckings.Put', array($ID, $Name), self::$_rpcMethods['Put']);
  }

  /**
   * Ruft die RPC-Funktion RpcCheckings.Delete auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Delete($ID = 0)
  {
    return $this->_sendRpcRequest('RpcCheckings.Delete', array($ID), self::$_rpcMethods['Delete']);
  }

  /**
   * Ruft die RPC-Funktion RpcCheckings.PrepareExport auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param string $FirstValue
   * @param string $LastValue
   * @param GhRpcCheckingslibRpcExportOptions $Options
   */
  public function PrepareExport($ID = 0, $FirstValue = '', $LastValue = '', GhRpcCheckingslibRpcExportOptions $Options = null)
  {
    return $this->_sendRpcRequest('RpcCheckings.PrepareExport', array($ID, $FirstValue, $LastValue, $Options), self::$_rpcMethods['PrepareExport']);
  }

  /**
   * Ruft die RPC-Funktion RpcCheckings.Lock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Lock($ID = 0)
  {
    return $this->_sendRpcRequest('RpcCheckings.Lock', array($ID), self::$_rpcMethods['Lock']);
  }

  /**
   * Ruft die RPC-Funktion RpcCheckings.Unlock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Unlock($ID = 0)
  {
    return $this->_sendRpcRequest('RpcCheckings.Unlock', array($ID), self::$_rpcMethods['Unlock']);
  }

  /**
   * Ruft die RPC-Funktion RpcCheckings.GetLockData auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcCheckingslibRpcLockData
   */
  public function GetLockData($ID = 0)
  {
    return $this->_sendRpcRequest('RpcCheckings.GetLockData', array($ID), self::$_rpcMethods['GetLockData']);
  }
}
