<?php
/**
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2022 GREYHOUND Software GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */


/**
 * RPC-Unit rpc_classificatorslib.
 *
 * @package GhRpc
 * @subpackage rpc_classificatorslib
 * @category PHP-RPC-Units
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class rpc_classificatorslib extends GhRpcLibrary
{
  // RpcClassificatorField Konstanten:

  /**
   * cfNone Konstante (gehört zum Enum: RpcClassificatorField).
   */
  const cfNone = 0;
  /**
   * cfUserField Konstante (gehört zum Enum: RpcClassificatorField).
   */
  const cfUserField = 1;
  /**
   * cfGroup Konstante (gehört zum Enum: RpcClassificatorField).
   */
  const cfGroup = 2;
  /**
   * cfUser Konstante (gehört zum Enum: RpcClassificatorField).
   */
  const cfUser = 3;
  /**
   * cfTopic Konstante (gehört zum Enum: RpcClassificatorField).
   */
  const cfTopic = 4;
  /**
   * cfColor Konstante (gehört zum Enum: RpcClassificatorField).
   */
  const cfColor = 5;

  // RpcClassificatorKind Konstanten:

  /**
   * ckL2rlr Konstante (gehört zum Enum: RpcClassificatorKind).
   */
  const ckL2rlr = 0;
  /**
   * ckL2l2lsvc Konstante (gehört zum Enum: RpcClassificatorKind).
   */
  const ckL2l2lsvc = 1;

  // RpcLockState Konstanten:

  /**
   * lsUnlocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsUnlocked = 0;
  /**
   * lsModified Konstante (gehört zum Enum: RpcLockState).
   */
  const lsModified = 1;
  /**
   * lsLocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsLocked = 2;

  /**
   * Hilfskonstante, die ein Set darstellt, in dem alle Enums gesetzt sind.
   * @var int
   */
  const SET_ALL = -1;


  /**
   * Erzeugt eine Instanz des RPC-Dienstes RpcClassificators.
   *
   * @param GhRpcClient $client Client Instanz
   *
   * @return GhRpcClassificatorslibRpcClassificators
   */
  public static function newRpcClassificators(GhRpcClient $client)
  {
    return new GhRpcClassificatorslibRpcClassificators($client);
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcLockData.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcClassificatorslibRpcLockData
   */
  public static function newRpcLockData($fillProperties = false)
  {
    $object = new GhRpcClassificatorslibRpcLockData();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcClassificator.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcClassificatorslibRpcClassificator
   */
  public static function newRpcClassificator($fillProperties = false)
  {
    $object = new GhRpcClassificatorslibRpcClassificator();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }
}


/**
 * RPC-Struct RpcClassificatorList.
 *
 * @package GhRpc
 * @subpackage rpc_classificatorslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcClassificatorslibRpcClassificator extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * Kind
   * @var int
   */
  public $Kind;

  /**
   * Stopwords
   * @var boolean
   */
  public $Stopwords;

  /**
   * Cost
   * @var int
   */
  public $Cost;

  /**
   * MinDf
   * @var double
   */
  public $MinDf;

  /**
   * MaxDf
   * @var double
   */
  public $MaxDf;

  /**
   * MaxTerms
   * @var int
   */
  public $MaxTerms;

  /**
   * MaxSize
   * @var int
   */
  public $MaxSize;

  /**
   * RegEx
   * @var string
   */
  public $RegEx;

  /**
   * CompleteEmails
   * @var boolean
   */
  public $CompleteEmails;

  /**
   * Field
   * @var int
   */
  public $Field;

  /**
   * UserField
   * @var string
   */
  public $UserField;

  /**
   * TrainFilterRef
   * @var int
   */
  public $TrainFilterRef;

  /**
   * CheckFilterRef
   * @var int
   */
  public $CheckFilterRef;

  /**
   * TrainData
   * @var string
   */
  public $TrainData;

  /**
   * CheckData
   * @var string
   */
  public $CheckData;

  /**
   * LockData
   * @var GhRpcClassificatorslibRpcLockData
   */
  public $LockData;

  /**
   * Created
   * @var GhRpcDateTime
   */
  public $Created;

  /**
   * Modified
   * @var GhRpcDateTime
   */
  public $Modified;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'Name' => 'string',
    'Kind' => 'int',
    'Stopwords' => 'boolean',
    'Cost' => 'int',
    'MinDf' => 'double',
    'MaxDf' => 'double',
    'MaxTerms' => 'int',
    'MaxSize' => 'int',
    'RegEx' => 'string',
    'CompleteEmails' => 'boolean',
    'Field' => 'int',
    'UserField' => 'string',
    'TrainFilterRef' => 'int',
    'CheckFilterRef' => 'int',
    'TrainData' => 'binary',
    'CheckData' => 'binary',
    'LockData' => 'GhRpcClassificatorslibRpcLockData',
    'Created' => 'GhRpcDateTime',
    'Modified' => 'GhRpcDateTime',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcClassificatorList.
 *
 * @package GhRpc
 * @subpackage rpc_classificatorslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcClassificatorslibRpcLockData extends GhRpcStruct
{
  /**
   * LockState
   * @var int
   */
  public $LockState;

  /**
   * UserRef
   * @var int
   */
  public $UserRef;

  /**
   * UserName
   * @var string
   */
  public $UserName;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'LockState' => 'int',
    'UserRef' => 'int',
    'UserName' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Dienst RpcClassificators
 *
 * @package GhRpc
 * @subpackage rpc_classificatorslib
 * @category PHP-RPC-Dienste
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcClassificatorslibRpcClassificators extends GhRpcService
{
  /**
   * RPC-Methoden mit Parametern und Ergebnistypen.
   * @var array
   */
  protected static $_rpcMethods = array(
    'GetLockData' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcClassificatorslibRpcLockData',
    ),
    'Unlock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Lock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'GetFilterData' => array(
      'params' => array(
        'Field' => 'int',
        'UserField' => 'string',
        'FilterRef' => 'int',
        'CompleteEmails' => 'boolean',
      ),
      'return' => 'binary',
    ),
    'Import' => array(
      'params' => array(
        'XmlData' => 'binary',
      ),
      'return' => 'int',
    ),
    'Export' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'binary',
    ),
    'Check' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'string',
    ),
    'CrossValidation' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'double',
    ),
    'Train' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Delete' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Put' => array(
      'params' => array(
        'Classificator' => 'GhRpcClassificatorslibRpcClassificator',
      ),
      'return' => '',
    ),
    'New_' => array(
      'params' => array(
        'Classificator' => 'GhRpcClassificatorslibRpcClassificator',
      ),
      'return' => 'int',
    ),
    'GetList' => array(
      'params' => array(
      ),
      'return' => 'array:GhRpcClassificatorslibRpcClassificator',
    ),
    'Get' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcClassificatorslibRpcClassificator',
    ),
  );


  /**
   * Ruft die RPC-Funktion RpcClassificators.Get auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcClassificatorslibRpcClassificator
   */
  public function Get($ID = 0)
  {
    return $this->_sendRpcRequest('RpcClassificators.Get', array($ID), self::$_rpcMethods['Get']);
  }

  /**
   * Ruft die RPC-Funktion RpcClassificators.GetList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return array
   */
  public function GetList()
  {
    return $this->_sendRpcRequest('RpcClassificators.GetList', array(), self::$_rpcMethods['GetList']);
  }

  /**
   * Ruft die RPC-Funktion RpcClassificators.New auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcClassificatorslibRpcClassificator $Classificator
   *
   * @return int
   */
  public function New_(GhRpcClassificatorslibRpcClassificator $Classificator = null)
  {
    return $this->_sendRpcRequest('RpcClassificators.New', array($Classificator), self::$_rpcMethods['New_']);
  }

  /**
   * Ruft die RPC-Funktion RpcClassificators.Put auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcClassificatorslibRpcClassificator $Classificator
   */
  public function Put(GhRpcClassificatorslibRpcClassificator $Classificator = null)
  {
    return $this->_sendRpcRequest('RpcClassificators.Put', array($Classificator), self::$_rpcMethods['Put']);
  }

  /**
   * Ruft die RPC-Funktion RpcClassificators.Delete auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Delete($ID = 0)
  {
    return $this->_sendRpcRequest('RpcClassificators.Delete', array($ID), self::$_rpcMethods['Delete']);
  }

  /**
   * Ruft die RPC-Funktion RpcClassificators.Train auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Train($ID = 0)
  {
    return $this->_sendRpcRequest('RpcClassificators.Train', array($ID), self::$_rpcMethods['Train']);
  }

  /**
   * Ruft die RPC-Funktion RpcClassificators.CrossValidation auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return double
   */
  public function CrossValidation($ID = 0)
  {
    return $this->_sendRpcRequest('RpcClassificators.CrossValidation', array($ID), self::$_rpcMethods['CrossValidation']);
  }

  /**
   * Ruft die RPC-Funktion RpcClassificators.Check auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return string
   */
  public function Check($ID = 0)
  {
    return $this->_sendRpcRequest('RpcClassificators.Check', array($ID), self::$_rpcMethods['Check']);
  }

  /**
   * Ruft die RPC-Funktion RpcClassificators.Export auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return string
   */
  public function Export($ID = 0)
  {
    return $this->_sendRpcRequest('RpcClassificators.Export', array($ID), self::$_rpcMethods['Export']);
  }

  /**
   * Ruft die RPC-Funktion RpcClassificators.Import auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $XmlData
   *
   * @return int
   */
  public function Import($XmlData = '')
  {
    return $this->_sendRpcRequest('RpcClassificators.Import', array($XmlData), self::$_rpcMethods['Import']);
  }

  /**
   * Ruft die RPC-Funktion RpcClassificators.GetFilterData auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $Field
   * @param string $UserField
   * @param int $FilterRef
   * @param boolean $CompleteEmails
   *
   * @return string
   */
  public function GetFilterData($Field = 0, $UserField = '', $FilterRef = 0, $CompleteEmails = false)
  {
    return $this->_sendRpcRequest('RpcClassificators.GetFilterData', array($Field, $UserField, $FilterRef, $CompleteEmails), self::$_rpcMethods['GetFilterData']);
  }

  /**
   * Ruft die RPC-Funktion RpcClassificators.Lock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Lock($ID = 0)
  {
    return $this->_sendRpcRequest('RpcClassificators.Lock', array($ID), self::$_rpcMethods['Lock']);
  }

  /**
   * Ruft die RPC-Funktion RpcClassificators.Unlock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Unlock($ID = 0)
  {
    return $this->_sendRpcRequest('RpcClassificators.Unlock', array($ID), self::$_rpcMethods['Unlock']);
  }

  /**
   * Ruft die RPC-Funktion RpcClassificators.GetLockData auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcClassificatorslibRpcLockData
   */
  public function GetLockData($ID = 0)
  {
    return $this->_sendRpcRequest('RpcClassificators.GetLockData', array($ID), self::$_rpcMethods['GetLockData']);
  }
}
