<?php
/**
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2021 GREYHOUND Software GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */


/**
 * RPC-Unit rpc_deviceslib.
 *
 * @package GhRpc
 * @subpackage rpc_deviceslib
 * @category PHP-RPC-Units
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class rpc_deviceslib extends GhRpcLibrary
{
  // RpcDeviceKind Konstanten:

  /**
   * dkWindowsMobile Konstante (gehört zum Enum: RpcDeviceKind).
   */
  const dkWindowsMobile = 0;
  /**
   * dkIos Konstante (gehört zum Enum: RpcDeviceKind).
   */
  const dkIos = 1;
  /**
   * dkAndroid Konstante (gehört zum Enum: RpcDeviceKind).
   */
  const dkAndroid = 2;

  // RpcLockState Konstanten:

  /**
   * lsUnlocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsUnlocked = 0;
  /**
   * lsModified Konstante (gehört zum Enum: RpcLockState).
   */
  const lsModified = 1;
  /**
   * lsLocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsLocked = 2;

  // RpcDeviceState Konstanten:

  /**
   * dsInactive Konstante (gehört zum Enum: RpcDeviceState).
   */
  const dsInactive = 0;
  /**
   * dsActive Konstante (gehört zum Enum: RpcDeviceState).
   */
  const dsActive = 1;

  /**
   * Hilfskonstante, die ein Set darstellt, in dem alle Enums gesetzt sind.
   * @var int
   */
  const SET_ALL = -1;


  /**
   * Erzeugt eine Instanz des RPC-Dienstes RpcDevices.
   *
   * @param GhRpcClient $client Client Instanz
   *
   * @return GhRpcDeviceslibRpcDevices
   */
  public static function newRpcDevices(GhRpcClient $client)
  {
    return new GhRpcDeviceslibRpcDevices($client);
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcLockData.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcDeviceslibRpcLockData
   */
  public static function newRpcLockData($fillProperties = false)
  {
    $object = new GhRpcDeviceslibRpcLockData();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcDevice.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcDeviceslibRpcDevice
   */
  public static function newRpcDevice($fillProperties = false)
  {
    $object = new GhRpcDeviceslibRpcDevice();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }
}


/**
 * RPC-Struct RpcDeviceList.
 *
 * @package GhRpc
 * @subpackage rpc_deviceslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcDeviceslibRpcDevice extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * UserRef
   * @var int
   */
  public $UserRef;

  /**
   * Username
   * @var string
   */
  public $Username;

  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * State
   * @var int
   */
  public $State;

  /**
   * DeviceId
   * @var string
   */
  public $DeviceId;

  /**
   * Kind
   * @var int
   */
  public $Kind;

  /**
   * Identifier
   * @var string
   */
  public $Identifier;

  /**
   * Args
   * @var string
   */
  public $Args;

  /**
   * LockData
   * @var GhRpcDeviceslibRpcLockData
   */
  public $LockData;

  /**
   * Created
   * @var GhRpcDateTime
   */
  public $Created;

  /**
   * Modified
   * @var GhRpcDateTime
   */
  public $Modified;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'UserRef' => 'int',
    'Username' => 'string',
    'Name' => 'string',
    'State' => 'int',
    'DeviceId' => 'string',
    'Kind' => 'int',
    'Identifier' => 'string',
    'Args' => 'string',
    'LockData' => 'GhRpcDeviceslibRpcLockData',
    'Created' => 'GhRpcDateTime',
    'Modified' => 'GhRpcDateTime',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcDeviceList.
 *
 * @package GhRpc
 * @subpackage rpc_deviceslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcDeviceslibRpcLockData extends GhRpcStruct
{
  /**
   * LockState
   * @var int
   */
  public $LockState;

  /**
   * UserRef
   * @var int
   */
  public $UserRef;

  /**
   * UserName
   * @var string
   */
  public $UserName;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'LockState' => 'int',
    'UserRef' => 'int',
    'UserName' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Dienst RpcDevices
 *
 * @package GhRpc
 * @subpackage rpc_deviceslib
 * @category PHP-RPC-Dienste
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2021 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcDeviceslibRpcDevices extends GhRpcService
{
  /**
   * RPC-Methoden mit Parametern und Ergebnistypen.
   * @var array
   */
  protected static $_rpcMethods = array(
    'GetLockData' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcDeviceslibRpcLockData',
    ),
    'Unlock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Lock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Unregister' => array(
      'params' => array(
        'DeviceId' => 'string',
      ),
      'return' => '',
    ),
    'Register' => array(
      'params' => array(
        'Device' => 'GhRpcDeviceslibRpcDevice',
      ),
      'return' => 'int',
    ),
    'Delete' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Put' => array(
      'params' => array(
        'Device' => 'GhRpcDeviceslibRpcDevice',
      ),
      'return' => '',
    ),
    'New_' => array(
      'params' => array(
        'Device' => 'GhRpcDeviceslibRpcDevice',
      ),
      'return' => 'int',
    ),
    'GetCompleteList' => array(
      'params' => array(
      ),
      'return' => 'array:GhRpcDeviceslibRpcDevice',
    ),
    'GetList' => array(
      'params' => array(
      ),
      'return' => 'array:GhRpcDeviceslibRpcDevice',
    ),
    'Get' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcDeviceslibRpcDevice',
    ),
  );


  /**
   * Ruft die RPC-Funktion RpcDevices.Get auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcDeviceslibRpcDevice
   */
  public function Get($ID = 0)
  {
    return $this->_sendRpcRequest('RpcDevices.Get', array($ID), self::$_rpcMethods['Get']);
  }

  /**
   * Ruft die RPC-Funktion RpcDevices.GetList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return array
   */
  public function GetList()
  {
    return $this->_sendRpcRequest('RpcDevices.GetList', array(), self::$_rpcMethods['GetList']);
  }

  /**
   * Ruft die RPC-Funktion RpcDevices.GetCompleteList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return array
   */
  public function GetCompleteList()
  {
    return $this->_sendRpcRequest('RpcDevices.GetCompleteList', array(), self::$_rpcMethods['GetCompleteList']);
  }

  /**
   * Ruft die RPC-Funktion RpcDevices.New auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcDeviceslibRpcDevice $Device
   *
   * @return int
   */
  public function New_(GhRpcDeviceslibRpcDevice $Device = null)
  {
    return $this->_sendRpcRequest('RpcDevices.New', array($Device), self::$_rpcMethods['New_']);
  }

  /**
   * Ruft die RPC-Funktion RpcDevices.Put auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcDeviceslibRpcDevice $Device
   */
  public function Put(GhRpcDeviceslibRpcDevice $Device = null)
  {
    return $this->_sendRpcRequest('RpcDevices.Put', array($Device), self::$_rpcMethods['Put']);
  }

  /**
   * Ruft die RPC-Funktion RpcDevices.Delete auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Delete($ID = 0)
  {
    return $this->_sendRpcRequest('RpcDevices.Delete', array($ID), self::$_rpcMethods['Delete']);
  }

  /**
   * Ruft die RPC-Funktion RpcDevices.Register auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcDeviceslibRpcDevice $Device
   *
   * @return int
   */
  public function Register(GhRpcDeviceslibRpcDevice $Device = null)
  {
    return $this->_sendRpcRequest('RpcDevices.Register', array($Device), self::$_rpcMethods['Register']);
  }

  /**
   * Ruft die RPC-Funktion RpcDevices.Unregister auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $DeviceId
   */
  public function Unregister($DeviceId = '')
  {
    return $this->_sendRpcRequest('RpcDevices.Unregister', array($DeviceId), self::$_rpcMethods['Unregister']);
  }

  /**
   * Ruft die RPC-Funktion RpcDevices.Lock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Lock($ID = 0)
  {
    return $this->_sendRpcRequest('RpcDevices.Lock', array($ID), self::$_rpcMethods['Lock']);
  }

  /**
   * Ruft die RPC-Funktion RpcDevices.Unlock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Unlock($ID = 0)
  {
    return $this->_sendRpcRequest('RpcDevices.Unlock', array($ID), self::$_rpcMethods['Unlock']);
  }

  /**
   * Ruft die RPC-Funktion RpcDevices.GetLockData auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcDeviceslibRpcLockData
   */
  public function GetLockData($ID = 0)
  {
    return $this->_sendRpcRequest('RpcDevices.GetLockData', array($ID), self::$_rpcMethods['GetLockData']);
  }
}
