<?php
/**
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2022 GREYHOUND Software GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */


/**
 * RPC-Unit rpc_infolib.
 *
 * @package GhRpc
 * @subpackage rpc_infolib
 * @category PHP-RPC-Units
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class rpc_infolib extends GhRpcLibrary
{
  // RpcItemCounterDirection Konstanten:

  /**
   * icdIncoming Konstante (gehört zum Enum: RpcItemCounterDirection).
   */
  const icdIncoming = 0;
  /**
   * icdOutgoing Konstante (gehört zum Enum: RpcItemCounterDirection).
   */
  const icdOutgoing = 1;

  // RpcItemCounterKind Konstanten:

  /**
   * ickEMail Konstante (gehört zum Enum: RpcItemCounterKind).
   */
  const ickEMail = 0;
  /**
   * ickFax Konstante (gehört zum Enum: RpcItemCounterKind).
   */
  const ickFax = 1;
  /**
   * ickLetter Konstante (gehört zum Enum: RpcItemCounterKind).
   */
  const ickLetter = 2;
  /**
   * ickMessenger Konstante (gehört zum Enum: RpcItemCounterKind).
   */
  const ickMessenger = 3;

  // RpcItemCountKind Konstanten:

  /**
   * ickTotal Konstante (gehört zum Enum: RpcItemCountKind).
   */
  const ickTotal = 0;
  /**
   * ickRead Konstante (gehört zum Enum: RpcItemCountKind).
   */
  const ickRead = 1;

  // RpcStatusFlag Konstanten:

  /**
   * sfRunning Konstante (gehört zum Enum: RpcStatusFlag).
   */
  const sfRunning = 0;
  /**
   * sfStopped Konstante (gehört zum Enum: RpcStatusFlag).
   */
  const sfStopped = 1;
  /**
   * sfFailure Konstante (gehört zum Enum: RpcStatusFlag).
   */
  const sfFailure = 2;

  // RpcWorkSpace Konstanten:

  /**
   * wsSystem Konstante (gehört zum Enum: RpcWorkSpace).
   */
  const wsSystem = 0;
  /**
   * wsPersonal Konstante (gehört zum Enum: RpcWorkSpace).
   */
  const wsPersonal = 1;

  /**
   * Hilfskonstante, die ein Set darstellt, in dem alle Enums gesetzt sind.
   * @var int
   */
  const SET_ALL = -1;


  /**
   * Erzeugt eine Instanz des RPC-Dienstes RpcInfo.
   *
   * @param GhRpcClient $client Client Instanz
   *
   * @return GhRpcInfolibRpcInfo
   */
  public static function newRpcInfo(GhRpcClient $client)
  {
    return new GhRpcInfolibRpcInfo($client);
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcDbStatus.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcInfolibRpcDbStatus
   */
  public static function newRpcDbStatus($fillProperties = false)
  {
    $object = new GhRpcInfolibRpcDbStatus();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcDbProcess.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcInfolibRpcDbProcess
   */
  public static function newRpcDbProcess($fillProperties = false)
  {
    $object = new GhRpcInfolibRpcDbProcess();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcDbVariable.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcInfolibRpcDbVariable
   */
  public static function newRpcDbVariable($fillProperties = false)
  {
    $object = new GhRpcInfolibRpcDbVariable();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcStatistic.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcInfolibRpcStatistic
   */
  public static function newRpcStatistic($fillProperties = false)
  {
    $object = new GhRpcInfolibRpcStatistic();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcServerCounter.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcInfolibRpcServerCounter
   */
  public static function newRpcServerCounter($fillProperties = false)
  {
    $object = new GhRpcInfolibRpcServerCounter();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcAddOn.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcInfolibRpcAddOn
   */
  public static function newRpcAddOn($fillProperties = false)
  {
    $object = new GhRpcInfolibRpcAddOn();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcServerSettings.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcInfolibRpcServerSettings
   */
  public static function newRpcServerSettings($fillProperties = false)
  {
    $object = new GhRpcInfolibRpcServerSettings();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcQueueRule.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcInfolibRpcQueueRule
   */
  public static function newRpcQueueRule($fillProperties = false)
  {
    $object = new GhRpcInfolibRpcQueueRule();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcQueueStatus.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcInfolibRpcQueueStatus
   */
  public static function newRpcQueueStatus($fillProperties = false)
  {
    $object = new GhRpcInfolibRpcQueueStatus();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcServerStatus.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcInfolibRpcServerStatus
   */
  public static function newRpcServerStatus($fillProperties = false)
  {
    $object = new GhRpcInfolibRpcServerStatus();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcItemCount.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcInfolibRpcItemCount
   */
  public static function newRpcItemCount($fillProperties = false)
  {
    $object = new GhRpcInfolibRpcItemCount();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcRight.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcInfolibRpcRight
   */
  public static function newRpcRight($fillProperties = false)
  {
    $object = new GhRpcInfolibRpcRight();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcServerInfo.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcInfolibRpcServerInfo
   */
  public static function newRpcServerInfo($fillProperties = false)
  {
    $object = new GhRpcInfolibRpcServerInfo();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }
}


/**
 * RPC-Struct RpcDbStatusList.
 *
 * @package GhRpc
 * @subpackage rpc_infolib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcInfolibRpcServerInfo extends GhRpcStruct
{
  /**
   * OnlineSince
   * @var GhRpcDateTime
   */
  public $OnlineSince;

  /**
   * ServerTime
   * @var GhRpcDateTime
   */
  public $ServerTime;

  /**
   * Version
   * @var string
   */
  public $Version;

  /**
   * Connections
   * @var int
   */
  public $Connections;

  /**
   * MaxConnections
   * @var int
   */
  public $MaxConnections;

  /**
   * HttpPort
   * @var int
   */
  public $HttpPort;

  /**
   * RpcpPort
   * @var int
   */
  public $RpcpPort;

  /**
   * KeepAlive
   * @var boolean
   */
  public $KeepAlive;

  /**
   * Compress
   * @var boolean
   */
  public $Compress;

  /**
   * UseRpcps
   * @var boolean
   */
  public $UseRpcps;

  /**
   * UseSSL
   * @var boolean
   */
  public $UseSSL;

  /**
   * MethodCount
   * @var int
   */
  public $MethodCount;

  /**
   * Win32ClientVersion
   * @var string
   */
  public $Win32ClientVersion;

  /**
   * CPU
   * @var string
   */
  public $CPU;

  /**
   * CPUUsage
   * @var int
   */
  public $CPUUsage;

  /**
   * OS
   * @var string
   */
  public $OS;

  /**
   * TotalPhysicalMemory
   * @var GhRpcInt64
   */
  public $TotalPhysicalMemory;

  /**
   * AvailablePhysicalMemory
   * @var GhRpcInt64
   */
  public $AvailablePhysicalMemory;

  /**
   * TotalVirtualMemory
   * @var GhRpcInt64
   */
  public $TotalVirtualMemory;

  /**
   * AvailableVirtualMemory
   * @var GhRpcInt64
   */
  public $AvailableVirtualMemory;

  /**
   * ProcessUsedMemory
   * @var GhRpcInt64
   */
  public $ProcessUsedMemory;

  /**
   * ProcessReservedMemory
   * @var GhRpcInt64
   */
  public $ProcessReservedMemory;

  /**
   * DatabaseSize
   * @var GhRpcInt64
   */
  public $DatabaseSize;

  /**
   * Hostname
   * @var string
   */
  public $Hostname;

  /**
   * IPAddress
   * @var string
   */
  public $IPAddress;

  /**
   * DiskSize
   * @var GhRpcInt64
   */
  public $DiskSize;

  /**
   * DiskFree
   * @var GhRpcInt64
   */
  public $DiskFree;

  /**
   * ServerTimeZone
   * @var string
   */
  public $ServerTimeZone;

  /**
   * BiggestDatabaseTableSize
   * @var GhRpcInt64
   */
  public $BiggestDatabaseTableSize;

  /**
   * Edition
   * @var int
   */
  public $Edition;

  /**
   * GatewayPop3Port
   * @var int
   */
  public $GatewayPop3Port;

  /**
   * GatewaySmtpPort
   * @var int
   */
  public $GatewaySmtpPort;

  /**
   * AccessPop3Port
   * @var int
   */
  public $AccessPop3Port;

  /**
   * AccessSmtpPort
   * @var int
   */
  public $AccessSmtpPort;

  /**
   * UsedCuls
   * @var int
   */
  public $UsedCuls;

  /**
   * MaxCuls
   * @var int
   */
  public $MaxCuls;

  /**
   * PublicHost
   * @var string
   */
  public $PublicHost;

  /**
   * PublicUrl
   * @var string
   */
  public $PublicUrl;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'OnlineSince' => 'GhRpcDateTime',
    'ServerTime' => 'GhRpcDateTime',
    'Version' => 'string',
    'Connections' => 'int',
    'MaxConnections' => 'int',
    'HttpPort' => 'int',
    'RpcpPort' => 'int',
    'KeepAlive' => 'boolean',
    'Compress' => 'boolean',
    'UseRpcps' => 'boolean',
    'UseSSL' => 'boolean',
    'MethodCount' => 'int',
    'Win32ClientVersion' => 'string',
    'CPU' => 'string',
    'CPUUsage' => 'int',
    'OS' => 'string',
    'TotalPhysicalMemory' => 'GhRpcInt64',
    'AvailablePhysicalMemory' => 'GhRpcInt64',
    'TotalVirtualMemory' => 'GhRpcInt64',
    'AvailableVirtualMemory' => 'GhRpcInt64',
    'ProcessUsedMemory' => 'GhRpcInt64',
    'ProcessReservedMemory' => 'GhRpcInt64',
    'DatabaseSize' => 'GhRpcInt64',
    'Hostname' => 'string',
    'IPAddress' => 'string',
    'DiskSize' => 'GhRpcInt64',
    'DiskFree' => 'GhRpcInt64',
    'ServerTimeZone' => 'string',
    'BiggestDatabaseTableSize' => 'GhRpcInt64',
    'Edition' => 'int',
    'GatewayPop3Port' => 'int',
    'GatewaySmtpPort' => 'int',
    'AccessPop3Port' => 'int',
    'AccessSmtpPort' => 'int',
    'UsedCuls' => 'int',
    'MaxCuls' => 'int',
    'PublicHost' => 'string',
    'PublicUrl' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcDbStatusList.
 *
 * @package GhRpc
 * @subpackage rpc_infolib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcInfolibRpcRight extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * ParentRef
   * @var int
   */
  public $ParentRef;

  /**
   * Key
   * @var string
   */
  public $Key;

  /**
   * WorkSpaces
   * @var int
   */
  public $WorkSpaces;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'ParentRef' => 'int',
    'Key' => 'string',
    'WorkSpaces' => 'int',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcDbStatusList.
 *
 * @package GhRpc
 * @subpackage rpc_infolib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcInfolibRpcItemCount extends GhRpcStruct
{
  /**
   * TotalCount
   * @var string
   */
  public $TotalCount;

  /**
   * TotalCountUniqueID
   * @var string
   */
  public $TotalCountUniqueID;

  /**
   * TotalCountReset
   * @var boolean
   */
  public $TotalCountReset;

  /**
   * ReadCount
   * @var string
   */
  public $ReadCount;

  /**
   * ReadCountUniqueID
   * @var string
   */
  public $ReadCountUniqueID;

  /**
   * ReadCountReset
   * @var boolean
   */
  public $ReadCountReset;

  /**
   * Modified
   * @var GhRpcDateTime
   */
  public $Modified;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'TotalCount' => 'binary',
    'TotalCountUniqueID' => 'string',
    'TotalCountReset' => 'boolean',
    'ReadCount' => 'binary',
    'ReadCountUniqueID' => 'string',
    'ReadCountReset' => 'boolean',
    'Modified' => 'GhRpcDateTime',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcDbStatusList.
 *
 * @package GhRpc
 * @subpackage rpc_infolib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcInfolibRpcServerStatus extends GhRpcStruct
{
  /**
   * MySqlServer
   * @var int
   */
  public $MySqlServer;

  /**
   * AppServer
   * @var int
   */
  public $AppServer;

  /**
   * QueueServer
   * @var int
   */
  public $QueueServer;

  /**
   * CommServer
   * @var int
   */
  public $CommServer;

  /**
   * GatewayServer
   * @var int
   */
  public $GatewayServer;

  /**
   * AccessServer
   * @var int
   */
  public $AccessServer;

  /**
   * SyncServer
   * @var int
   */
  public $SyncServer;

  /**
   * CommServerLastAction
   * @var string
   */
  public $CommServerLastAction;

  /**
   * QueueServerLastAction
   * @var string
   */
  public $QueueServerLastAction;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'MySqlServer' => 'int',
    'AppServer' => 'int',
    'QueueServer' => 'int',
    'CommServer' => 'int',
    'GatewayServer' => 'int',
    'AccessServer' => 'int',
    'SyncServer' => 'int',
    'CommServerLastAction' => 'string',
    'QueueServerLastAction' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcDbStatusList.
 *
 * @package GhRpc
 * @subpackage rpc_infolib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcInfolibRpcQueueStatus extends GhRpcStruct
{
  /**
   * ActionSpamCount
   * @var int
   */
  public $ActionSpamCount;

  /**
   * ActionOcrCount
   * @var int
   */
  public $ActionOcrCount;

  /**
   * ActionHtmlInlineCount
   * @var int
   */
  public $ActionHtmlInlineCount;

  /**
   * ActionWorkflowCount
   * @var int
   */
  public $ActionWorkflowCount;

  /**
   * ActionIndexAddCount
   * @var int
   */
  public $ActionIndexAddCount;

  /**
   * ActionIndexDeleteCount
   * @var int
   */
  public $ActionIndexDeleteCount;

  /**
   * QueueRules
   * @var array
   */
  public $QueueRules;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ActionSpamCount' => 'int',
    'ActionOcrCount' => 'int',
    'ActionHtmlInlineCount' => 'int',
    'ActionWorkflowCount' => 'int',
    'ActionIndexAddCount' => 'int',
    'ActionIndexDeleteCount' => 'int',
    'QueueRules' => 'array:GhRpcInfolibRpcQueueRule',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcDbStatusList.
 *
 * @package GhRpc
 * @subpackage rpc_infolib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcInfolibRpcQueueRule extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * ItemCount
   * @var int
   */
  public $ItemCount;

  /**
   * FilterCount
   * @var int
   */
  public $FilterCount;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'Name' => 'string',
    'ItemCount' => 'int',
    'FilterCount' => 'int',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcDbStatusList.
 *
 * @package GhRpc
 * @subpackage rpc_infolib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcInfolibRpcServerSettings extends GhRpcStruct
{
  /**
   * CountryPrefix
   * @var string
   */
  public $CountryPrefix;

  /**
   * ElementsPerPage
   * @var int
   */
  public $ElementsPerPage;

  /**
   * ElementsPerList
   * @var int
   */
  public $ElementsPerList;

  /**
   * EventsPerPage
   * @var int
   */
  public $EventsPerPage;

  /**
   * EventsPerDay
   * @var int
   */
  public $EventsPerDay;

  /**
   * MaxSearchResults
   * @var int
   */
  public $MaxSearchResults;

  /**
   * UseItemCount
   * @var boolean
   */
  public $UseItemCount;

  /**
   * AllowDelete
   * @var boolean
   */
  public $AllowDelete;

  /**
   * CurrencyCode
   * @var string
   */
  public $CurrencyCode;

  /**
   * HasChatBot
   * @var boolean
   */
  public $HasChatBot;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'CountryPrefix' => 'string',
    'ElementsPerPage' => 'int',
    'ElementsPerList' => 'int',
    'EventsPerPage' => 'int',
    'EventsPerDay' => 'int',
    'MaxSearchResults' => 'int',
    'UseItemCount' => 'boolean',
    'AllowDelete' => 'boolean',
    'CurrencyCode' => 'string',
    'HasChatBot' => 'boolean',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcDbStatusList.
 *
 * @package GhRpc
 * @subpackage rpc_infolib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcInfolibRpcAddOn extends GhRpcStruct
{
  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * Version
   * @var string
   */
  public $Version;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'Name' => 'string',
    'Version' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcDbStatusList.
 *
 * @package GhRpc
 * @subpackage rpc_infolib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcInfolibRpcServerCounter extends GhRpcStruct
{
  /**
   * Kind
   * @var int
   */
  public $Kind;

  /**
   * Direction
   * @var int
   */
  public $Direction;

  /**
   * Count
   * @var GhRpcInt64
   */
  public $Count;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'Kind' => 'int',
    'Direction' => 'int',
    'Count' => 'GhRpcInt64',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcDbStatusList.
 *
 * @package GhRpc
 * @subpackage rpc_infolib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcInfolibRpcStatistic extends GhRpcStruct
{
  /**
   * Year
   * @var int
   */
  public $Year;

  /**
   * Month
   * @var int
   */
  public $Month;

  /**
   * Kind
   * @var string
   */
  public $Kind;

  /**
   * Count
   * @var int
   */
  public $Count;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'Year' => 'int',
    'Month' => 'int',
    'Kind' => 'string',
    'Count' => 'int',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcDbStatusList.
 *
 * @package GhRpc
 * @subpackage rpc_infolib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcInfolibRpcDbVariable extends GhRpcStruct
{
  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * Session
   * @var string
   */
  public $Session;

  /**
   * Global
   * @var string
   */
  public $Global;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'Name' => 'string',
    'Session' => 'string',
    'Global' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcDbStatusList.
 *
 * @package GhRpc
 * @subpackage rpc_infolib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcInfolibRpcDbProcess extends GhRpcStruct
{
  /**
   * Id
   * @var int
   */
  public $Id;

  /**
   * User
   * @var string
   */
  public $User;

  /**
   * Host
   * @var string
   */
  public $Host;

  /**
   * Db
   * @var string
   */
  public $Db;

  /**
   * Command
   * @var string
   */
  public $Command;

  /**
   * Time
   * @var int
   */
  public $Time;

  /**
   * State
   * @var string
   */
  public $State;

  /**
   * Info
   * @var string
   */
  public $Info;

  /**
   * Progress
   * @var double
   */
  public $Progress;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'Id' => 'int',
    'User' => 'string',
    'Host' => 'string',
    'Db' => 'string',
    'Command' => 'string',
    'Time' => 'int',
    'State' => 'string',
    'Info' => 'string',
    'Progress' => 'double',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcDbStatusList.
 *
 * @package GhRpc
 * @subpackage rpc_infolib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcInfolibRpcDbStatus extends GhRpcStruct
{
  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * Value
   * @var string
   */
  public $Value;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'Name' => 'string',
    'Value' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Dienst RpcInfo
 *
 * @package GhRpc
 * @subpackage rpc_infolib
 * @category PHP-RPC-Dienste
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcInfolibRpcInfo extends GhRpcService
{
  /**
   * RPC-Methoden mit Parametern und Ergebnistypen.
   * @var array
   */
  protected static $_rpcMethods = array(
    'GetDbStatusList' => array(
      'params' => array(
      ),
      'return' => 'array:GhRpcInfolibRpcDbStatus',
    ),
    'GetDbProcessList' => array(
      'params' => array(
      ),
      'return' => 'array:GhRpcInfolibRpcDbProcess',
    ),
    'GetDbVariableList' => array(
      'params' => array(
      ),
      'return' => 'array:GhRpcInfolibRpcDbVariable',
    ),
    'GetServicePin' => array(
      'params' => array(
      ),
      'return' => 'string',
    ),
    'GetStatisticList' => array(
      'params' => array(
        'StartDate' => 'GhRpcDateTime',
        'EndDate' => 'GhRpcDateTime',
      ),
      'return' => 'array:GhRpcInfolibRpcStatistic',
    ),
    'GetServerCounterList' => array(
      'params' => array(
      ),
      'return' => 'array:GhRpcInfolibRpcServerCounter',
    ),
    'ConvertCurrency' => array(
      'params' => array(
        'FromCode' => 'string',
        'ToCode' => 'string',
        'Amount' => 'double',
        'Date' => 'GhRpcDateTime',
      ),
      'return' => 'double',
    ),
    'TrainAutoClassification' => array(
      'params' => array(
      ),
      'return' => '',
    ),
    'TrainSpamFilter' => array(
      'params' => array(
      ),
      'return' => '',
    ),
    'GetAddOnList' => array(
      'params' => array(
      ),
      'return' => 'array:GhRpcInfolibRpcAddOn',
    ),
    'GetAddOn' => array(
      'params' => array(
        'Name' => 'string',
      ),
      'return' => 'binary',
    ),
    'UpdateAddOns' => array(
      'params' => array(
      ),
      'return' => '',
    ),
    'GetServerSettings' => array(
      'params' => array(
      ),
      'return' => 'GhRpcInfolibRpcServerSettings',
    ),
    'GetQueueStatus' => array(
      'params' => array(
      ),
      'return' => 'GhRpcInfolibRpcQueueStatus',
    ),
    'GetServerStatus' => array(
      'params' => array(
      ),
      'return' => 'GhRpcInfolibRpcServerStatus',
    ),
    'GetItemCount' => array(
      'params' => array(
        'TotalCountUniqueID' => 'string',
        'ReadCountUniqueID' => 'string',
        'MinModified' => 'GhRpcDateTime',
      ),
      'return' => 'GhRpcInfolibRpcItemCount',
    ),
    'SendAndReceiveNow' => array(
      'params' => array(
      ),
      'return' => '',
    ),
    'ReindexAllItems' => array(
      'params' => array(
      ),
      'return' => '',
    ),
    'InvalidateAllCaches' => array(
      'params' => array(
      ),
      'return' => '',
    ),
    'CountNamedCul' => array(
      'params' => array(
        'ClientName' => 'string',
      ),
      'return' => '',
    ),
    'CountCul' => array(
      'params' => array(
      ),
      'return' => '',
    ),
    'GetRightList' => array(
      'params' => array(
      ),
      'return' => 'array:GhRpcInfolibRpcRight',
    ),
    'GetVariables' => array(
      'params' => array(
      ),
      'return' => 'array:string',
    ),
    'GetServerInfo' => array(
      'params' => array(
        'AdvancedFields' => 'boolean',
      ),
      'return' => 'GhRpcInfolibRpcServerInfo',
    ),
  );


  /**
   * Ruft die RPC-Funktion RpcInfo.GetServerInfo auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param boolean $AdvancedFields
   *
   * @return GhRpcInfolibRpcServerInfo
   */
  public function GetServerInfo($AdvancedFields = false)
  {
    return $this->_sendRpcRequest('RpcInfo.GetServerInfo', array($AdvancedFields), self::$_rpcMethods['GetServerInfo']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.GetVariables auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return array
   */
  public function GetVariables()
  {
    return $this->_sendRpcRequest('RpcInfo.GetVariables', array(), self::$_rpcMethods['GetVariables']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.GetRightList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return array
   */
  public function GetRightList()
  {
    return $this->_sendRpcRequest('RpcInfo.GetRightList', array(), self::$_rpcMethods['GetRightList']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.CountCul auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   */
  public function CountCul()
  {
    return $this->_sendRpcRequest('RpcInfo.CountCul', array(), self::$_rpcMethods['CountCul']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.CountNamedCul auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $ClientName
   */
  public function CountNamedCul($ClientName = '')
  {
    return $this->_sendRpcRequest('RpcInfo.CountNamedCul', array($ClientName), self::$_rpcMethods['CountNamedCul']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.InvalidateAllCaches auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   */
  public function InvalidateAllCaches()
  {
    return $this->_sendRpcRequest('RpcInfo.InvalidateAllCaches', array(), self::$_rpcMethods['InvalidateAllCaches']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.ReindexAllItems auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   */
  public function ReindexAllItems()
  {
    return $this->_sendRpcRequest('RpcInfo.ReindexAllItems', array(), self::$_rpcMethods['ReindexAllItems']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.SendAndReceiveNow auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   */
  public function SendAndReceiveNow()
  {
    return $this->_sendRpcRequest('RpcInfo.SendAndReceiveNow', array(), self::$_rpcMethods['SendAndReceiveNow']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.GetItemCount auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $TotalCountUniqueID
   * @param string $ReadCountUniqueID
   * @param GhRpcDateTime $MinModified
   *
   * @return GhRpcInfolibRpcItemCount
   */
  public function GetItemCount($TotalCountUniqueID = '', $ReadCountUniqueID = '', GhRpcDateTime $MinModified = null)
  {
    return $this->_sendRpcRequest('RpcInfo.GetItemCount', array($TotalCountUniqueID, $ReadCountUniqueID, $MinModified), self::$_rpcMethods['GetItemCount']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.GetServerStatus auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return GhRpcInfolibRpcServerStatus
   */
  public function GetServerStatus()
  {
    return $this->_sendRpcRequest('RpcInfo.GetServerStatus', array(), self::$_rpcMethods['GetServerStatus']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.GetQueueStatus auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return GhRpcInfolibRpcQueueStatus
   */
  public function GetQueueStatus()
  {
    return $this->_sendRpcRequest('RpcInfo.GetQueueStatus', array(), self::$_rpcMethods['GetQueueStatus']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.GetServerSettings auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return GhRpcInfolibRpcServerSettings
   */
  public function GetServerSettings()
  {
    return $this->_sendRpcRequest('RpcInfo.GetServerSettings', array(), self::$_rpcMethods['GetServerSettings']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.UpdateAddOns auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   */
  public function UpdateAddOns()
  {
    return $this->_sendRpcRequest('RpcInfo.UpdateAddOns', array(), self::$_rpcMethods['UpdateAddOns']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.GetAddOn auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Name
   *
   * @return string
   */
  public function GetAddOn($Name = '')
  {
    return $this->_sendRpcRequest('RpcInfo.GetAddOn', array($Name), self::$_rpcMethods['GetAddOn']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.GetAddOnList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return array
   */
  public function GetAddOnList()
  {
    return $this->_sendRpcRequest('RpcInfo.GetAddOnList', array(), self::$_rpcMethods['GetAddOnList']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.TrainSpamFilter auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   */
  public function TrainSpamFilter()
  {
    return $this->_sendRpcRequest('RpcInfo.TrainSpamFilter', array(), self::$_rpcMethods['TrainSpamFilter']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.TrainAutoClassification auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   */
  public function TrainAutoClassification()
  {
    return $this->_sendRpcRequest('RpcInfo.TrainAutoClassification', array(), self::$_rpcMethods['TrainAutoClassification']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.ConvertCurrency auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $FromCode
   * @param string $ToCode
   * @param double $Amount
   * @param GhRpcDateTime $Date
   *
   * @return double
   */
  public function ConvertCurrency($FromCode = '', $ToCode = '', $Amount = 0, GhRpcDateTime $Date = null)
  {
    return $this->_sendRpcRequest('RpcInfo.ConvertCurrency', array($FromCode, $ToCode, $Amount, $Date), self::$_rpcMethods['ConvertCurrency']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.GetServerCounterList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return array
   */
  public function GetServerCounterList()
  {
    return $this->_sendRpcRequest('RpcInfo.GetServerCounterList', array(), self::$_rpcMethods['GetServerCounterList']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.GetStatisticList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcDateTime $StartDate
   * @param GhRpcDateTime $EndDate
   *
   * @return array
   */
  public function GetStatisticList(GhRpcDateTime $StartDate = null, GhRpcDateTime $EndDate = null)
  {
    return $this->_sendRpcRequest('RpcInfo.GetStatisticList', array($StartDate, $EndDate), self::$_rpcMethods['GetStatisticList']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.GetServicePin auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return string
   */
  public function GetServicePin()
  {
    return $this->_sendRpcRequest('RpcInfo.GetServicePin', array(), self::$_rpcMethods['GetServicePin']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.GetDbVariableList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return array
   */
  public function GetDbVariableList()
  {
    return $this->_sendRpcRequest('RpcInfo.GetDbVariableList', array(), self::$_rpcMethods['GetDbVariableList']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.GetDbProcessList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return array
   */
  public function GetDbProcessList()
  {
    return $this->_sendRpcRequest('RpcInfo.GetDbProcessList', array(), self::$_rpcMethods['GetDbProcessList']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.GetDbStatusList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return array
   */
  public function GetDbStatusList()
  {
    return $this->_sendRpcRequest('RpcInfo.GetDbStatusList', array(), self::$_rpcMethods['GetDbStatusList']);
  }
}
