<?php
/**
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2022 GREYHOUND Software GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */


/**
 * RPC-Unit rpc_messengerslib.
 *
 * @package GhRpc
 * @subpackage rpc_messengerslib
 * @category PHP-RPC-Units
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class rpc_messengerslib extends GhRpcLibrary
{
  // RpcLogFormat Konstanten:

  /**
   * lfData Konstante (gehört zum Enum: RpcLogFormat).
   */
  const lfData = 0;
  /**
   * lfJson Konstante (gehört zum Enum: RpcLogFormat).
   */
  const lfJson = 1;

  // RpcMessengerLogLevel Konstanten:

  /**
   * mllNone Konstante (gehört zum Enum: RpcMessengerLogLevel).
   */
  const mllNone = 0;
  /**
   * mllError Konstante (gehört zum Enum: RpcMessengerLogLevel).
   */
  const mllError = 1;
  /**
   * mllWarning Konstante (gehört zum Enum: RpcMessengerLogLevel).
   */
  const mllWarning = 2;
  /**
   * mllInfo Konstante (gehört zum Enum: RpcMessengerLogLevel).
   */
  const mllInfo = 3;
  /**
   * mllDebug Konstante (gehört zum Enum: RpcMessengerLogLevel).
   */
  const mllDebug = 4;

  // RpcMessengerState Konstanten:

  /**
   * msInactive Konstante (gehört zum Enum: RpcMessengerState).
   */
  const msInactive = 0;
  /**
   * msActive Konstante (gehört zum Enum: RpcMessengerState).
   */
  const msActive = 1;

  // RpcLockState Konstanten:

  /**
   * lsUnlocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsUnlocked = 0;
  /**
   * lsModified Konstante (gehört zum Enum: RpcLockState).
   */
  const lsModified = 1;
  /**
   * lsLocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsLocked = 2;

  /**
   * Hilfskonstante, die ein Set darstellt, in dem alle Enums gesetzt sind.
   * @var int
   */
  const SET_ALL = -1;


  /**
   * Erzeugt eine Instanz des RPC-Dienstes RpcMessengers.
   *
   * @param GhRpcClient $client Client Instanz
   *
   * @return GhRpcMessengerslibRpcMessengers
   */
  public static function newRpcMessengers(GhRpcClient $client)
  {
    return new GhRpcMessengerslibRpcMessengers($client);
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcMessengerLog.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcMessengerslibRpcMessengerLog
   */
  public static function newRpcMessengerLog($fillProperties = false)
  {
    $object = new GhRpcMessengerslibRpcMessengerLog();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcLockData.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcMessengerslibRpcLockData
   */
  public static function newRpcLockData($fillProperties = false)
  {
    $object = new GhRpcMessengerslibRpcLockData();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcMessenger.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcMessengerslibRpcMessenger
   */
  public static function newRpcMessenger($fillProperties = false)
  {
    $object = new GhRpcMessengerslibRpcMessenger();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }
}


/**
 * RPC-Struct RpcMessengerLogList.
 *
 * @package GhRpc
 * @subpackage rpc_messengerslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcMessengerslibRpcMessenger extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * State
   * @var int
   */
  public $State;

  /**
   * Identifier
   * @var string
   */
  public $Identifier;

  /**
   * URL
   * @var string
   */
  public $URL;

  /**
   * Timeout
   * @var int
   */
  public $Timeout;

  /**
   * Settings
   * @var string
   */
  public $Settings;

  /**
   * Token
   * @var string
   */
  public $Token;

  /**
   * LogLevel
   * @var int
   */
  public $LogLevel;

  /**
   * MaxTaskInterval
   * @var int
   */
  public $MaxTaskInterval;

  /**
   * Connector
   * @var string
   */
  public $Connector;

  /**
   * Message
   * @var string
   */
  public $Message;

  /**
   * Picture
   * @var string
   */
  public $Picture;

  /**
   * Created
   * @var GhRpcDateTime
   */
  public $Created;

  /**
   * Modified
   * @var GhRpcDateTime
   */
  public $Modified;

  /**
   * LockData
   * @var GhRpcMessengerslibRpcLockData
   */
  public $LockData;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'Name' => 'string',
    'State' => 'int',
    'Identifier' => 'string',
    'URL' => 'string',
    'Timeout' => 'int',
    'Settings' => 'string',
    'Token' => 'string',
    'LogLevel' => 'int',
    'MaxTaskInterval' => 'int',
    'Connector' => 'string',
    'Message' => 'string',
    'Picture' => 'binary',
    'Created' => 'GhRpcDateTime',
    'Modified' => 'GhRpcDateTime',
    'LockData' => 'GhRpcMessengerslibRpcLockData',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcMessengerLogList.
 *
 * @package GhRpc
 * @subpackage rpc_messengerslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcMessengerslibRpcLockData extends GhRpcStruct
{
  /**
   * LockState
   * @var int
   */
  public $LockState;

  /**
   * UserRef
   * @var int
   */
  public $UserRef;

  /**
   * UserName
   * @var string
   */
  public $UserName;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'LockState' => 'int',
    'UserRef' => 'int',
    'UserName' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcMessengerLogList.
 *
 * @package GhRpc
 * @subpackage rpc_messengerslib
 * @category PHP-RPC-Datenklassen
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcMessengerslibRpcMessengerLog extends GhRpcStruct
{
  /**
   * Timestamp
   * @var GhRpcDateTime
   */
  public $Timestamp;

  /**
   * Level
   * @var int
   */
  public $Level;

  /**
   * Source
   * @var string
   */
  public $Source;

  /**
   * Content
   * @var string
   */
  public $Content;

  /**
   * Data
   * @var string
   */
  public $Data;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'Timestamp' => 'GhRpcDateTime',
    'Level' => 'int',
    'Source' => 'string',
    'Content' => 'string',
    'Data' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Dienst RpcMessengers
 *
 * @package GhRpc
 * @subpackage rpc_messengerslib
 * @category PHP-RPC-Dienste
 *
 * @author GREYHOUND Software GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2022 GREYHOUND Software GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcMessengerslibRpcMessengers extends GhRpcService
{
  /**
   * RPC-Methoden mit Parametern und Ergebnistypen.
   * @var array
   */
  protected static $_rpcMethods = array(
    'PutBlockedContacts' => array(
      'params' => array(
        'ID' => 'int',
        'Identifiers' => 'array:string',
      ),
      'return' => '',
    ),
    'GetBlockedContacts' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'array:string',
    ),
    'GetLockData' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcMessengerslibRpcLockData',
    ),
    'Unlock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Lock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Delete' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Put' => array(
      'params' => array(
        'Messenger' => 'GhRpcMessengerslibRpcMessenger',
      ),
      'return' => '',
    ),
    'New_' => array(
      'params' => array(
        'Messenger' => 'GhRpcMessengerslibRpcMessenger',
      ),
      'return' => 'int',
    ),
    'GetLogMessages' => array(
      'params' => array(
        'ID' => 'int',
        'Limit' => 'int',
        'Format' => 'int',
      ),
      'return' => 'array:GhRpcMessengerslibRpcMessengerLog',
    ),
    'GetList' => array(
      'params' => array(
      ),
      'return' => 'array:GhRpcMessengerslibRpcMessenger',
    ),
    'Get' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcMessengerslibRpcMessenger',
    ),
  );


  /**
   * Ruft die RPC-Funktion RpcMessengers.Get auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcMessengerslibRpcMessenger
   */
  public function Get($ID = 0)
  {
    return $this->_sendRpcRequest('RpcMessengers.Get', array($ID), self::$_rpcMethods['Get']);
  }

  /**
   * Ruft die RPC-Funktion RpcMessengers.GetList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return array
   */
  public function GetList()
  {
    return $this->_sendRpcRequest('RpcMessengers.GetList', array(), self::$_rpcMethods['GetList']);
  }

  /**
   * Ruft die RPC-Funktion RpcMessengers.GetLogMessages auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param int $Limit
   * @param int $Format
   *
   * @return array
   */
  public function GetLogMessages($ID = 0, $Limit = 0, $Format = 0)
  {
    return $this->_sendRpcRequest('RpcMessengers.GetLogMessages', array($ID, $Limit, $Format), self::$_rpcMethods['GetLogMessages']);
  }

  /**
   * Ruft die RPC-Funktion RpcMessengers.New auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcMessengerslibRpcMessenger $Messenger
   *
   * @return int
   */
  public function New_(GhRpcMessengerslibRpcMessenger $Messenger = null)
  {
    return $this->_sendRpcRequest('RpcMessengers.New', array($Messenger), self::$_rpcMethods['New_']);
  }

  /**
   * Ruft die RPC-Funktion RpcMessengers.Put auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcMessengerslibRpcMessenger $Messenger
   */
  public function Put(GhRpcMessengerslibRpcMessenger $Messenger = null)
  {
    return $this->_sendRpcRequest('RpcMessengers.Put', array($Messenger), self::$_rpcMethods['Put']);
  }

  /**
   * Ruft die RPC-Funktion RpcMessengers.Delete auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Delete($ID = 0)
  {
    return $this->_sendRpcRequest('RpcMessengers.Delete', array($ID), self::$_rpcMethods['Delete']);
  }

  /**
   * Ruft die RPC-Funktion RpcMessengers.Lock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Lock($ID = 0)
  {
    return $this->_sendRpcRequest('RpcMessengers.Lock', array($ID), self::$_rpcMethods['Lock']);
  }

  /**
   * Ruft die RPC-Funktion RpcMessengers.Unlock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Unlock($ID = 0)
  {
    return $this->_sendRpcRequest('RpcMessengers.Unlock', array($ID), self::$_rpcMethods['Unlock']);
  }

  /**
   * Ruft die RPC-Funktion RpcMessengers.GetLockData auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcMessengerslibRpcLockData
   */
  public function GetLockData($ID = 0)
  {
    return $this->_sendRpcRequest('RpcMessengers.GetLockData', array($ID), self::$_rpcMethods['GetLockData']);
  }

  /**
   * Ruft die RPC-Funktion RpcMessengers.GetBlockedContacts auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return array
   */
  public function GetBlockedContacts($ID = 0)
  {
    return $this->_sendRpcRequest('RpcMessengers.GetBlockedContacts', array($ID), self::$_rpcMethods['GetBlockedContacts']);
  }

  /**
   * Ruft die RPC-Funktion RpcMessengers.PutBlockedContacts auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param array $Identifiers
   */
  public function PutBlockedContacts($ID = 0, array $Identifiers = array())
  {
    return $this->_sendRpcRequest('RpcMessengers.PutBlockedContacts', array($ID, $Identifiers), self::$_rpcMethods['PutBlockedContacts']);
  }
}
