/*
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2013 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */
dojo.provide("greyhound.dojo.ComboTree");

dojo.require("dijit._HasDropDown");
dojo.require("dijit.form.TextBox");
dojo.require("dijit.Tree");

dojo.declare("greyhound.dojo.ComboTree", [dijit.form.TextBox, dijit._HasDropDown],
{
  templateString: dojo.cache("dijit.form", "templates/DropDownBox.html"),
  hasDownArrow: true,
  _stopClickEvents: false,
  forceWidth: true,
  showRoot: true,
  autoExpand: false,
  model: null,
  getIconClass: null,
  updateValueNode: null,
  updateValueItemProperty: null,
  maxHeight: 300,

  constructor: function(args)
  {
    this.inherited(arguments);

    this.model = args.model;

    if(args.showRoot != undefined)
      this.showRoot = args.showRoot;

    if(args.autoExpand != undefined)
      this.autoExpand = args.autoExpand;

    if(args.getIconClass != undefined)
      this.getIconClass = args.getIconClass;

    if(args.updateValueNode)
      this.updateValueNode = dojo.byId(args.updateValueNode);

    if(args.updateValueItemProperty)
      this.updateValueItemProperty = args.updateValueItemProperty;
  },

  postCreate: function()
  {
    this.inherited(arguments);

    if(this.srcNodeRef && this.srcNodeRef.nodeName == 'INPUT')
      this.originalInputNode = this.srcNodeRef;

    // make textbox readonly until search-as-you-type has been implemented:
    this.textbox.readOnly = true;

    var treeConfig = {
      model: this.model,
      showRoot: this.showRoot,
      autoExpand: this.autoExpand,
      persist: false,
      'class': "GhGuiComboTree"
    };

    if(this.getIconClass != undefined)
      treeConfig.getIconClass = this.getIconClass;

    this.dropDown = new dijit.Tree(treeConfig);
    this.dropDown.startup();
    this.connect(this.dropDown, 'onClick', this.onTreeSelect);
    this.connect(this, 'openDropDown', this.onOpenDropDown);

    var maxHeight = dijit.getViewport().h;

    if(maxHeight < this.maxHeight)
      this.maxHeight = maxHeight;

    if(this.updateValueNode && this.updateValueItemProperty)
    {
      var value = dojo.byId(this.updateValueNode).value;
      var path = this.getItemPathByProperty(this.updateValueItemProperty, value);

      if(path)
      {
        this.dropDown.set('path', path);
        var item = this.getItemByProperty('id', path[ path.length - 1 ]);

        if(item)
          this.textbox.value = this.model.getLabel(item);
      }
    }
  },

  onTreeSelect: function(item, node, event)
  {
    this.textbox.value = item.label;
    this.closeDropDown(true);

    if(this.updateValueNode && this.updateValueItemProperty)
    {
      // apparently this.updateValueNode is not a node anymore but just the id, so we need to resolve it again:
      var updateNode = dojo.byId(this.updateValueNode);

      if(updateNode)
        updateNode.value = String(item[ this.updateValueItemProperty ]);
    }

    this.onSelected(item, node, event);
  },

  onSelected: function(item, node, event)
  {
    // this method is just here so it can be overloaded by an event handler
  },

  getItemByProperty: function(property, value)
  {
    return greyhound.dojo.getTreeItem(this.dropDown, property, value);
  },

  getItemPathByProperty: function(property, value)
  {
    return greyhound.dojo.getTreePath(this.dropDown, property, value);
  },

  onOpenDropDown: function()
  {
    // fix the drop-down size to fit into the visible area:
    var dropDownBox = dojo.marginBox(this.dropDown.domNode);
    var dropDownPosition = dojo.position(this.dropDown.domNode);
    var viewport = dijit.getViewport();

    if(dropDownPosition.y + dropDownPosition.h > viewport.h)
    {
      dropDownBox.h = viewport.h - dropDownPosition.y;
      dojo.marginBox(this.dropDown.domNode, dropDownBox);
    }

    this.dropDown.domNode.style.maxHeight = (viewport.h - dropDownPosition.y) + 'px';
    this.dropDown.domNode.style.overflowY = 'auto';
  }
});
