/*
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2013 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

dojo.provide("greyhound.dojo.Editor");

dojo.require("dijit.layout.ContentPane");

dojo.declare("greyhound.dojo.Editor", [dijit.layout.ContentPane],
{
  textAreaId: null,
  ckEditor: null,
  initialSize: null,
  instanceReady: false,
  plainText: false,
  toolbar: null,
  config: null,
  externalPlugins: null,
  ghGuiBaseUrl: null,

  postCreate: function()
  {
    this.inherited(arguments);

    var config = {
      fullPage: true,
      skin: "greyhound," + CKEDITOR.basePath + "../greyhound/ckeditor/skins/greyhound/",
      toolbarCanCollapse: false,
      extraPlugins: "docprops"
    };

    if(this.toolbar)
      config.toolbar = this.toolbar;

    if(this.plainText)
    {
      config.forcePasteAsPlainText = true;
      config.enterMode = CKEDITOR.ENTER_BR;
      config.shiftEnterMode = CKEDITOR.ENTER_BR;
      config.forceEnterMode = true;
    }

    if(this.config)
      dojo.mixin(config, this.config);

    if(this.externalPlugins && this.externalPlugins.length)
    {
      for(var i=0; i<this.externalPlugins.length; i++)
        CKEDITOR.plugins.addExternal(this.externalPlugins[i][0], this.externalPlugins[i][1], this.externalPlugins[i][2]);
    }

    this.ckEditor = CKEDITOR.replace(this.textAreaId, config);

    this.ckEditor.dojoWidget = this;
    this.ckEditor.ghGuiBaseUrl = this.ghGuiBaseUrl;

    this.ckEditor.on("instanceReady", function(e)
      {
        e.editor.dojoWidget.instanceReady = true;

        if(e.editor.dojoWidget.initialSize)
          e.editor.resize(e.editor.dojoWidget.initialSize.w, e.editor.dojoWidget.initialSize.h);
      }
    );

    dojo.connect(this, "resize", function(dim)
      {
        if(dim == undefined || dim.w == undefined || dim.h == undefined)
        {
          if(!this.domNode || !this.domNode.parentNode)
            return;

          dim = dojo.contentBox(this.domNode.parentNode);
        }

        if(this.instanceReady)
          this.ckEditor.resize(dim.w - 2, dim.h - 2);
        else
          this.initialSize = dim;
      }
    );
  },

  /**
   * Fügt Text bzw. HTML an der aktuellen Cursorposition im Editor ein.
   *
   * @param string text der einzufügende Text
   */
  insertHtml: function(text)
  {
    if(this.ckEditor)
      this.ckEditor.insertHtml(text);
  },

  /**
   * Fügt CSS Style-Angaben in den Seitenkopf des Editors ein.
   *
   * @param string style Style-Angaben
   */
  insertStyle: function(style)
  {
    if(!this.ckEditor || !style || style.length < 1)
      return;

    var text = this.ckEditor.getData();

    // Wenn noch kein style-Tag existiert wird eins vor dem schließenden Head-Tag eingefügt:
    if(!text.match(/<style[^>]*>[\s\S]*<\/\s*style>[\s\S]*<\/\s*head>/mig))
      text = text.replace(/([\s\S]*)(<\/\s*head>[\s\S]*)/mig, "$1\r\n<style type=\"text/css\">\r\n</style>\r\n$2");

    // Die Styles werden in dem ersten gefundenen Style-Tag eingefügt:
    var replacedText = text.replace(/(<style[^>]*>)([\s\S]*(?=-->)|[\s\S]*)(-->[\s\r\n]*)?(<\/style>)/mig, "$1\r\n$2\r\n" + style + "\r\n$3\r\n$4");

    if(text != replacedText)
      this.ckEditor.setData(replacedText);
  }
});
