/*
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2013 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

dojo.provide("greyhound.dojo.FileChooser");

dojo.require("dijit._HasDropDown");
dojo.require("dijit.form.TextBox");
dojo.require("dojox.html.entities");

/**
 * Dateiauswahl-Widget zum Auswählen/Hochladen von Dateien.
 *
 * Das Widget platziert über dem Drop-Down Button einen Bereich mit derselben Größe
 * wie das Button. In diesem Bereich werden File-Input-Elemente eingefügt,
 * die eine Transparenz von 100% haben. Über dem Button liegt also ein durchsichtiges
 * File-Input-Element. Beim Anklicken wird nicht der Drop-Down-Button, sondern das
 * darüber liegende File-Input-Element angeklickt, welches die Dateiauswahl des Browsers
 * anzeigt.
 * Dieser Umweg ist notwendig, da die Browser in der aktuellen Version starke
 * Einschränkungen beim Zugriff per Javascript auf File-Input-Elemente haben.
 * So führt beispielsweise das Absenden eines Formulars, in dem auf einem
 * File-Input-Element per Javascript die Methode "click()" aufgerufen wurde,
 * zu einem "Access denied" Fehler im Internet Explorer 8 oder neuer.
 */
dojo.declare("greyhound.dojo.FileChooser", [dijit.form.TextBox, dijit._HasDropDown],
{
  templateString: "<div class=\"dijit dijitReset dijitInlineTable dijitLeft\" id=\"widget_${id}\" role=\"combobox\"><div class='dijitReset dijitRight dijitButtonNode dijitArrowButton dijitDownArrowButton dijitArrowButtonContainer' dojoAttachPoint=\"_buttonNode, _popupStateNode\" role=\"presentation\"><input class=\"dijitReset dijitInputField dijitArrowButtonInner\" value=\"&#9660; \" type=\"text\" tabIndex=\"-1\" readonly=\"readonly\" role=\"presentation\" ${_buttonInputDisabled} /></div><div class='dijitReset dijitValidationContainer'><input class=\"dijitReset dijitInputField dijitValidationIcon dijitValidationInner\" value=\"&#935; \" type=\"text\" tabIndex=\"-1\" readonly=\"readonly\" role=\"presentation\" /></div><div class=\"dijitReset dijitInputField dijitInputContainer\"><div class='dijitReset dijitInputInner GhGuiFileChooserCaption' ${!nameAttrSetting} dojoAttachPoint=\"textbox,focusNode\" aria-haspopup=\"true\" /></div></div>",
  hasDownArrow: true,
  _stopClickEvents: false,
  forceWidth: true,
  formId: null, // DOM ID des Formulars in dem dieses Widget enthalten ist
  form: null, // Formular-Widget in dem dieses Widget enthalten ist
  hiddenFields: null, // HTML-Knoten für die "versteckten" Datei-Input-Elemente
  nextFileNode: null, // Input-Element zum Auswählen der nächsten, hinzuzufügenden Datei
  nextFileNodeHandler: null, // Event-Handler für ausgewählte neue Datei
  name: null,
  dontToggle: false, // verhindert, dass sich beim Klicken des Hinzufügen-Buttons das Drop-Down öffnet
  maxNrFiles: 1,
  captionNoFiles: "Datei hinzufügen",
  captionSingleFile: "#FILENAMES#",
  captionMultipleFiles: "#NRFILES# Dateien: #FILENAMES#",

  /**
   * Initialisiert das Widget.
   */
  postCreate: function()
  {
    this.inherited(arguments);

    this.connect(this.textbox, "onclick", this._onTextClick);

    var hiddenFieldsContainer = dojo.create("div", {'class': "GhGuiFileChooserInputWrapper"}, this._buttonNode);
    this.hiddenFields = dojo.create("div", {'class': "GhGuiFileChooserInputWrapperInner"}, hiddenFieldsContainer);
    this.nextFileNode = dojo.create("input", {type: "file", name: this.name, 'class': "GhGuiFileChooserInput"}, this.hiddenFields);
    this.nextFileNodeHandler = this.connect(this.nextFileNode, "onchange", this._fileAdded);

    if(this.formId)
    {
      this.form = dijit.byId(this.formId);

      if(this.form)
        this.connect(this.form, "onSubmit", this._onSubmit);
    }

    this.textbox.readOnly = true;
    this.textbox.name = null;
    this.textbox.innerHTML = this.captionNoFiles;

    this.dropDown = new dijit.layout.ContentPane({'class': "GhGuiFileChooserDropDown"});
    this.dropDown.startup();

    // Workaround: das Drop-Down hat ansonsten beim ersten Aufklappen eine falsche Größe:
    this.openDropDown();
    this.closeDropDown();
  },

  /**
   * Setzt die Mindestbreite des Drop-Downs auf die Breite des FileChoosers.
   * @param object dim Größe
   */
  resize: function(dim)
  {
    this.inherited(arguments);

    var size = dojo.marginBox(this.domNode);

    if(size && size.w)
    {
      this.dropDown.domNode.style.minWidth = (size.w - 4) + "px";
    }
  },

  /**
   * Click-Event-Handler für den Textbereich.
   * Zeigt das Drop-Down oder den Dateiauswahl-Dialog, je nachdem ob die Dateiliste leer ist.
   *
   * @param Event e
   */
  _onTextClick: function(e)
  {
    if(this.disabled || this.readOnly)
      return;

    if(this.hiddenFields.children.length > 1)
      this.toggleDropDown();
    else
      this.closeDropDown();
  },

  /**
   * Mouse-Down-Event-Handler für das Drop-Down-Button.
   *
   * @param Event e
   */
  _onDropDownMouseDown: function(e)
  {
    // Verhindert, dass beim Klicken des Hinzufügen-Buttons das Drop-Down geöffnet wird:
    this.dontToggle = true;

    this.inherited(arguments);

    this.dontToggle = false;
  },

  /**
   * Verhindert, dass beim Klicken des Hinzufügen-Buttons das Drop-Down geöffnet wird.
   */
  toggleDropDown: function()
  {
    if(this.dontToggle)
      return;

    this.inherited(arguments);
  },

  /**
   * Entfernt eine Datei und aktualisiert die Dateiliste.
   *
   * @param Event e
   */
  _removeFile: function(e)
  {
    // Der Index der zu entfernenden Datei steht im "rel" Attribut des Anchors:
    if(e && e.target && e.target.rel != undefined)
    {
      var index = parseInt(e.target.rel);

      if(this.hiddenFields.children.length > index)
      {
        var inputNode = this.hiddenFields.children[index];

        if(inputNode && inputNode != this.nextFileNode)
        {
          this.hiddenFields.removeChild(inputNode);
          this._updateFileList();
        }
      }
    }

    if(this.hiddenFields.children.length == 1)
      this.closeDropDown();

    // Sprungziel bei a-Tags unterbinden:
    return false;
  },

  /**
   * Fügt ein neues Input-Element hinzu und aktualisiert die Dateiliste.
   */
  _fileAdded: function()
  {
    if(!this.nextFileNode.value)
      return;

    // Falls dieselbe Datei (derselbe Dateipfad) bereits hinzugefügt wurde wird sie nicht erneut hinzugefügt:
    for(var i=0; i<this.hiddenFields.children.length; i++)
    {
      var inputNode = this.hiddenFields.children[i];

      if(inputNode == this.nextFileNode)
        continue;

      if(this.hiddenFields.children[i].value == this.nextFileNode.value)
        return;
    }

    // Maximale Anzahl hinzufügbarer Dateien gewährleisten (älteste entfernen):
    if(this.maxNrFiles > 0)
    {
      while(this.hiddenFields.children.length > this.maxNrFiles)
        this.hiddenFields.removeChild(this.hiddenFields.firstChild);
    }

    // Klick-Handler von dem Input-Element entfernen, in welchem die Datei ausgewählt wurde:
    if(this.nextFileNodeHandler)
      this.disconnect(this.nextFileNodeHandler);

    // Neues Input-Element für die nächste Datei-Auswahl hinzufügen:
    this.nextFileNode = dojo.create("input", {type: "file", name: this.name, 'class': "GhGuiFileChooserInput"}, this.hiddenFields);
    this.nextFileNodeHandler = this.connect(this.nextFileNode, "onchange", this._fileAdded);

    // Dateiliste aktualisieren:
    this._updateFileList();
  },

  /**
   * Aktualisiert die Liste der hinzugefügten Dateien im Drop-Down.
   */
  _updateFileList: function()
  {
    var nrFiles = 0;
    var fileNames = "";

    // Liste leeren:
    this.dropDown.domNode.innerHTML = "";

    for(var i=0; i<this.hiddenFields.children.length; i++)
    {
      var inputNode = this.hiddenFields.children[i];

      // Input-Element für die nächste Datei-Auswahl ignorieren:
      if(inputNode == this.nextFileNode)
        continue;

      // Pfad und Dateiname bestimmen:
      var path = inputNode.value;
      var fileName = path;
      var separatorPos = fileName.lastIndexOf("\\");

      if(separatorPos > -1)
        fileName = fileName.substr(separatorPos + 1);
      else
      {
        separatorPos = fileName.lastIndexOf("/");

        if(separatorPos > -1)
          fileName = fileName.substr(separatorPos + 1);
      }

      fileName = dojox.html.entities.encode(fileName);

      if(fileNames.length > 0)
        fileNames += ", " + fileName;
      else
        fileNames = fileName;

      // Datei zur Liste hinzufügen:
      var fileNode = dojo.create("div", {'class': "GhGuiFileChooserFile"}, this.dropDown.domNode);

      var iconClass = this.iconClass ? this.iconClass : "GhGuiFileIconDefault";
      dojo.create("div", {'class': "GhGuiFileIcon " + iconClass}, fileNode);
      var removeNode = dojo.create("a", {'class': "GhGuiFileRemove", rel: String(i), title: "Datei entfernen"}, fileNode);
      this.connect(removeNode, "onclick", this._removeFile);
      dojo.create("div", {'class': "GhGuiFileName", innerHTML: fileName}, fileNode);

      nrFiles++;
    }

    // Beschriftung der Text-Box setzen:
    if(nrFiles == 0)
    {
      this.textbox.innerHTML = this.captionNoFiles;
      this.closeDropDown();
    }
    else if(nrFiles == 1)
    {
      var caption = String(this.captionSingleFile ? this.captionSingleFile : this.captionNoFiles);
      caption = caption.replace(/#FILENAMES#/g, fileNames);
      caption = caption.replace(/#NRFILES#/g, "1");
      this.textbox.innerHTML = caption;
    }
    else
    {
      var caption = this.captionMultipleFiles;

      if(!caption)
        caption = this.captionSingleFile;

      if(!caption)
        caption = this.captionNoFiles;

      var caption = String(caption);
      caption = caption.replace(/#FILENAMES#/g, fileNames);
      caption = caption.replace(/#NRFILES#/g, String(nrFiles));
      this.textbox.innerHTML = caption;
    }
  },

  /**
   * Submit-Event-Handler für das Formular, in dem dieses Widget enthalten ist.
   *
   * @param Event e
   */
  _onSubmit: function(e)
  {
    // Das Input-Element für das Hinzufügen weiterer Dateien wird entfernt, außer, es wurde keine Datei gewählt (dann bleibt es als leere Dateiauswahl):
    if(this.nextFileNode && this.hiddenFields.children.length > 1)
    {
      this.hiddenFields.removeChild(this.nextFileNode);
      this.nextFileNode = null;
    }
  }
});
